@@ -226,11 +226,11 @@ int main (int argc, char *argv[])
   std::string recovery = "ns3::TcpClassicRecovery";
 
 
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.AddValue ("transport_prot", "Transport protocol to use: TcpNewReno, "
                 "TcpHybla, TcpHighSpeed, TcpHtcp, TcpVegas, TcpScalable, TcpVeno, "
                 "TcpBic, TcpYeah, TcpIllinois, TcpWestwood, TcpWestwoodPlus, TcpLedbat, "
-		"TcpLp", transport_prot);
+		"TcpLp, TcpDctcp", transport_prot);
   cmd.AddValue ("error_p", "Packet error rate", error_p);
   cmd.AddValue ("bandwidth", "Bottleneck bandwidth", bandwidth);
   cmd.AddValue ("delay", "Bottleneck delay", delay);
@@ -276,7 +276,7 @@ int main (int argc, char *argv[])
   double start_time = 0.1;
   double stop_time = start_time + duration;
 
-  // 4 MB of TCP buffer
+  // 2 MB of TCP buffer
   Config::SetDefault ("ns3::TcpSocket::RcvBufSize", UintegerValue (1 << 21));
   Config::SetDefault ("ns3::TcpSocket::SndBufSize", UintegerValue (1 << 21));
   Config::SetDefault ("ns3::TcpSocketBase::Sack", BooleanValue (sack));
