@@ -153,10 +153,13 @@ HybridBuildingsPropagationLossModel::GetLoss (Ptr<MobilityModel> a, Ptr<Mobility
   NS_ASSERT_MSG ((a1 != 0) && (b1 != 0), "HybridBuildingsPropagationLossModel only works with MobilityBuildingInfo");
 
   double loss = 0.0;
+  bool isAIndoor = a1->IsIndoor ();
+  bool isBIndoor = b1->IsIndoor ();
 
-  if (a1->IsOutdoor ())
+
+  if (!isAIndoor) // a is outdoor
     {
-      if (b1->IsOutdoor ())
+      if (!isBIndoor) // b is outdoor
         {
           if (distance > 1000)
             {
@@ -208,7 +211,7 @@ HybridBuildingsPropagationLossModel::GetLoss (Ptr<MobilityModel> a, Ptr<Mobility
   else
     {
       // a is indoor
-      if (b1->IsIndoor ())
+      if (isBIndoor) // b is indoor
         {
           if (a1->GetBuilding () == b1->GetBuilding ())
             {
@@ -247,8 +250,8 @@ HybridBuildingsPropagationLossModel::GetLoss (Ptr<MobilityModel> a, Ptr<Mobility
               loss = ItuR1411 (a, b) + ExternalWallLoss (a1)  + HeightLoss (a1);
               NS_LOG_INFO (this << " I-O (<1000)  ITUR1411 + BEL + HG: " << loss);
             }
-        } // end b1->IsIndoor ()
-    } // end a1->IsOutdoor ()
+        } // end if (isBIndoor)
+    } // end if (!isAIndoor)
 
   loss = std::max (loss, 0.0);
 
