@@ -31,6 +31,11 @@ namespace ns3 {
  *
  * \brief Store and load simulation attribute configuration
  *
+ * ns-3 Objects and their attribute values (default, and per-instance values)
+ * are stored in a specialized internal database.  The config-store module
+ * permits these values to be imported and exported to formats of
+ * different types (e.g. XML files, raw text files, or a GTK-based UI).
+ *
  * While it is possible to generate a sample config file and lightly
  * edit it to change a couple of values, there are cases where this
  * process will not work because the same value on the same object
@@ -54,33 +59,65 @@ namespace ns3 {
 class ConfigStore : public ObjectBase
 {
 public:
+/**
+ * \enum Mode for ConfigStore operation
+ * \brief store / load mode
+ */
   enum Mode {
     LOAD,
     SAVE,
     NONE
   };
+/**
+ * \enum FileFormat for ConfigStore operation
+ * \brief file format
+ */
+  /// store format
   enum FileFormat {
     XML,
     RAW_TEXT
   };
+
+  /**
+   * \brief Get the type ID.
+   * \return the object TypeId
+   */
   static TypeId GetTypeId (void);
   virtual TypeId GetInstanceTypeId (void) const;
 
   ConfigStore ();
   ~ConfigStore ();
 
+  /**
+   * Set the mode of operation
+   * \param mode mode of operation
+   */
   void SetMode (enum Mode mode);
+  /**
+   * Set the file format
+   * \param format the file format
+   */
   void SetFileFormat (enum FileFormat format);
+  /**
+   * Set the filename
+   * \param filename the file name
+   */
   void SetFilename (std::string filename);
 
+  /**
+   * Configure the default values
+   */
   void ConfigureDefaults (void);
+  /**
+   * Configure the attribute values
+   */
   void ConfigureAttributes (void);
 
 private:
-  enum Mode m_mode;
-  enum FileFormat m_fileFormat;
-  std::string m_filename;
-  FileConfig *m_file;
+  enum Mode m_mode; ///< store mode
+  enum FileFormat m_fileFormat; ///< store format
+  std::string m_filename; ///< store file name
+  FileConfig *m_file; ///< configuration file
 };
 
 /**
