@@ -1,6 +1,6 @@
 /* -*- Mode:C++; c-file-style:"gnu"; indent-tabs-mode:nil; -*- */
 /*
- * Copyright (c) 2010 INRIA 
+ * Copyright (c) 2010 INRIA
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -40,7 +40,7 @@ namespace ns3 {
 class int64x64_t
 {
   /// High bit of fractional part
-  static const uint64_t    HPCAIRO_MASK_HI_BIT = (((uint64_t)1)<<63);
+  static const uint64_t    HPCAIRO_MASK_HI_BIT = (((uint64_t)1) << 63);
   /// Mask for fraction part
   static const uint64_t    HP_MASK_LO = 0xffffffffffffffffULL;
   /**
@@ -65,7 +65,8 @@ public:
    * specifically the double implementation.  To handle this,
    * we expose the underlying implementation type here.
    */
-  enum impl_type {
+  enum impl_type
+  {
     int128_impl,  //!< Native int128_t implementation.
     cairo_impl,   //!< cairo wideint implementation
     ld_impl,      //!< long double implementation
@@ -112,8 +113,8 @@ public:
     const cairo_uint64_t lo = (cairo_uint64_t)flo;
     if (flo >= HP_MAX_64)
       {
-	// conversion to uint64 rolled over
-	++hi;
+        // conversion to uint64 rolled over
+        ++hi;
       }
     _v.hi = hi;
     _v.lo = lo;
@@ -176,11 +177,13 @@ public:
    * \param [in] o Value to copy.
    */
   inline int64x64_t (const int64x64_t & o)
-    : _v (o._v) {}
+    : _v (o._v)
+  {}
   /**
    * Assignment.
    *
    * \param [in] o Value to assign to this int64x64_t.
+   * \returns a copy of \pname{o}
    */
   inline int64x64_t & operator = (const int64x64_t & o)
   {
@@ -249,24 +252,48 @@ public:
   static int64x64_t Invert (const uint64_t v);
 
 private:
+
+  /**
+   * \name Arithmetic Operators
+   * Arithmetic operators for int64x64_t.
+   */
+  /**
+   * @{
+   *  Arithmetic operator.
+   *  \param [in] lhs Left hand argument
+   *  \param [in] rhs Right hand argument
+   *  \return The result of the operator.
+   */
   friend bool         operator == (const int64x64_t & lhs, const int64x64_t & rhs);
 
   friend bool         operator <  (const int64x64_t & lhs, const int64x64_t & rhs);
   friend bool         operator >  (const int64x64_t & lhs, const int64x64_t & rhs);
-  
+
   friend int64x64_t & operator += (      int64x64_t & lhs, const int64x64_t & rhs);
   friend int64x64_t & operator -= (      int64x64_t & lhs, const int64x64_t & rhs);
   friend int64x64_t & operator *= (      int64x64_t & lhs, const int64x64_t & rhs);
   friend int64x64_t & operator /= (      int64x64_t & lhs, const int64x64_t & rhs);
+  /**@}*/
 
+  /**
+   * \name Unary Operators
+   * Unary operators for int64x64_t.
+   */
+  /**
+   * @{
+   *  Unary operator.
+   *  \param [in] lhs Left hand argument
+   *  \return The result of the operator.
+   */
   friend int64x64_t   operator -  (const int64x64_t & lhs);
   friend int64x64_t   operator !  (const int64x64_t & lhs);
+  /**@}*/
 
   /**
    * Implement `*=`.
    *
    * \param [in] o The other factor.
-   */   
+   */
   void Mul (const int64x64_t & o);
   /**
    * Implement `/=`.
@@ -326,6 +353,9 @@ private:
 /**
  * \ingroup highprec
  * Equality operator.
+ * \param [in] lhs Left hand argument
+ * \param [in] rhs Right hand argument
+ * \return The result of the operator.
  */
 inline bool operator == (const int64x64_t & lhs, const int64x64_t & rhs)
 {
@@ -334,6 +364,9 @@ inline bool operator == (const int64x64_t & lhs, const int64x64_t & rhs)
 /**
  * \ingroup highprec
  * Less than operator
+ * \param [in] lhs Left hand argument
+ * \param [in] rhs Right hand argument
+ * \return The result of the operator.
  */
 inline bool operator < (const int64x64_t & lhs, const int64x64_t & rhs)
 {
@@ -342,6 +375,9 @@ inline bool operator < (const int64x64_t & lhs, const int64x64_t & rhs)
 /**
  * \ingroup highprec
  * Greater operator
+ * \param [in] lhs Left hand argument
+ * \param [in] rhs Right hand argument
+ * \return The result of the operator.
  */
 inline bool operator > (const int64x64_t & lhs, const int64x64_t & rhs)
 {
@@ -351,24 +387,33 @@ inline bool operator > (const int64x64_t & lhs, const int64x64_t & rhs)
 /**
  * \ingroup highprec
  * Compound addition operator
+ * \param [in] lhs Left hand argument
+ * \param [in] rhs Right hand argument
+ * \return The result of the operator.
  */
 inline int64x64_t & operator += (int64x64_t & lhs, const int64x64_t & rhs)
 {
-  lhs._v = _cairo_int128_add( lhs._v, rhs._v );
+  lhs._v = _cairo_int128_add ( lhs._v, rhs._v );
   return lhs;
 }
 /**
  * \ingroup highprec
  * Compound subtraction operator
+ * \param [in] lhs Left hand argument
+ * \param [in] rhs Right hand argument
+ * \return The result of the operator.
  */
 inline int64x64_t & operator -= (int64x64_t & lhs, const int64x64_t & rhs)
 {
-  lhs._v = _cairo_int128_sub( lhs._v, rhs._v );
+  lhs._v = _cairo_int128_sub ( lhs._v, rhs._v );
   return lhs;
 }
 /**
  * \ingroup highprec
  * Compound multiplication operator
+ * \param [in] lhs Left hand argument
+ * \param [in] rhs Right hand argument
+ * \return The result of the operator.
  */
 inline int64x64_t & operator *= (int64x64_t & lhs, const int64x64_t & rhs)
 {
@@ -378,6 +423,9 @@ inline int64x64_t & operator *= (int64x64_t & lhs, const int64x64_t & rhs)
 /**
  * \ingroup highprec
  * Compound division operator
+ * \param [in] lhs Left hand argument
+ * \param [in] rhs Right hand argument
+ * \return The result of the operator.
  */
 inline int64x64_t & operator /= (int64x64_t & lhs, const int64x64_t & rhs)
 {
@@ -388,6 +436,8 @@ inline int64x64_t & operator /= (int64x64_t & lhs, const int64x64_t & rhs)
 /**
  * \ingroup highprec
  * Unary plus operator
+ * \param [in] lhs Left hand argument
+ * \return The result of the operator.
  */
 inline int64x64_t operator + (const int64x64_t & lhs)
 {
@@ -396,6 +446,8 @@ inline int64x64_t operator + (const int64x64_t & lhs)
 /**
  * \ingroup highprec
  * Unary negation operator (change sign operator)
+ * \param [in] lhs Left hand argument
+ * \return The result of the operator.
  */
 inline int64x64_t operator - (const int64x64_t & lhs)
 {
@@ -406,6 +458,8 @@ inline int64x64_t operator - (const int64x64_t & lhs)
 /**
  * \ingroup highprec
  * Logical not operator
+ * \param [in] lhs Left hand argument
+ * \return The result of the operator.
  */
 inline int64x64_t operator ! (const int64x64_t & lhs)
 {
