@@ -35,7 +35,7 @@
   std::clog << msg
   This expression is required for forms like NS_LOG_LOGIC (... << std::endl ...)
 
-  
+
   ns3::ParameterLogger (std::clog) << msg
   This expression is required for NS_LOG_FUNCTION (... << vector ...)
 
@@ -45,7 +45,7 @@
     note: in expansion of macro NS_LOG_LOGIC (std::endl...
     error: no match for operator<< (operand types are ns3::ParameterLogger
     and <unresolved overloaded function type>)
-    
+
     note: candidate: template<class T> ns3::ParameterLogger&
       ns3::ParameterLogger::operator<<(T)
     note:   template argument deduction/substitution failed
@@ -63,16 +63,14 @@
  * \ingroup logging
  * Empty logging macro implementation, used when logging is disabled.
  */
-#define NS_LOG_NOOP_INTERNAL(msg)               \
-  do                                            \
-    if (false)                                  \
-    {                                           \
-      std::clog << msg;                         \
-    }                                           \
-  while (false)
+#define NS_LOG_NOOP_INTERNAL(msg)                \
+  do if (false)                                  \
+    {                                            \
+      std::clog << msg;                          \
+    }  while (false)
 
 #define NS_LOG(level, msg) \
-        NS_LOG_NOOP_INTERNAL (msg)
+  NS_LOG_NOOP_INTERNAL (msg)
 
 #define NS_LOG_FUNCTION_NOARGS()
 
@@ -80,19 +78,17 @@
  * \ingroup logging
  * Empty logging macro implementation, used when logging is disabled.
  */
-#define NS_LOG_NOOP_FUNC_INTERNAL(msg)          \
-  do                                            \
-    if (false)                                  \
-    {                                           \
-      ns3::ParameterLogger (std::clog) << msg;  \
-    }                                           \
-  while (false)
+#define NS_LOG_NOOP_FUNC_INTERNAL(msg)           \
+  do if (false)                                  \
+    {                                            \
+      ns3::ParameterLogger (std::clog) << msg;   \
+    } while (false)
 
 #define NS_LOG_FUNCTION(parameters) \
-        NS_LOG_NOOP_FUNC_INTERNAL (parameters)
+  NS_LOG_NOOP_FUNC_INTERNAL (parameters)
 
 #define NS_LOG_UNCOND(msg) \
-        NS_LOG_NOOP_INTERNAL (msg)
+  NS_LOG_NOOP_INTERNAL (msg)
 
 
 #endif /* !NS3_LOG_ENABLE */
