@@ -67,10 +67,10 @@ namespace ns3 {
  * functions and their goal is just is save you a small
  * bit of typing.
  *
- * \tparam T \explicit The underlying type.
+ * \tparam T \explicit The type of the underlying object.
  */
 template <typename T>
-class Ptr 
+class Ptr
 {
 private:
 
@@ -78,15 +78,16 @@ private:
   T *m_ptr;
 
   /** Helper to test for null pointer. */
-  class Tester {
+  class Tester
+  {
   private:
     /** Disable delete (by virtue that this is unimplemented). */
     void operator delete (void *);
   };
-  
+
   /** Interoperate with const instances. */
   friend class Ptr<const T>;
-  
+
   /**
    * Get a permanent pointer to the underlying object.
    *
@@ -94,11 +95,12 @@ private:
    * to returning to the caller so the caller is
    * responsible for calling Unref himself.
    *
+   * \tparam U \deduced The actual type of the argument and return pointer.
    * \param [in] p Smart pointer
    * \return The pointer managed by this smart pointer.
    */
   template <typename U>
-  friend U *GetPointer (const Ptr<U> &p);
+  friend U * GetPointer (const Ptr<U> &p);
   /**
    * Get a temporary pointer to the underlying object.
    *
@@ -106,15 +108,16 @@ private:
    * to returning to the caller so the caller is not
    * responsible for calling Unref himself.
    *
+   * \tparam U \deduced The actual type of the argument and return pointer.
    * \param [in] p Smart pointer
    * \return The pointer managed by this smart pointer.
    */
   template <typename U>
-  friend U *PeekPointer (const Ptr<U> &p);
+  friend U * PeekPointer (const Ptr<U> &p);
 
   /** Mark this as a a reference by incrementing the reference count. */
   inline void Acquire (void) const;
-  
+
 public:
   /** Create an empty smart pointer */
   Ptr ();
@@ -147,11 +150,11 @@ public:
   /**
    * Copy, removing \c const qualifier.
    *
-   * \tparam U \deduced The underlying type of the \c const object.
+   * \tparam U \deduced The type underlying the Ptr being copied.
    * \param [in] o The Ptr to copy.
    */
   template <typename U>
-  Ptr (Ptr<U> const &o); 
+  Ptr (Ptr<U> const &o);
   /** Destructor. */
   ~Ptr ();
   /**
@@ -210,143 +213,27 @@ public:
  * Create class instances by constructors with varying numbers
  * of arguments and return them by Ptr.
  *
- * These methods work for any class \c T.
+ * This template work for any class \c T derived from ns3::SimpleRefCount
  *
  * \see CreateObject for methods to create derivatives of ns3::Object
  */
 /** @{ */
-/**
- * \tparam T \explicit The type of class object to create.
- * \return A Ptr to the newly created \c T.
- */
-template <typename T>
-Ptr<T> Create (void);
-
 /**
  * \tparam T  \explicit The type of class object to create.
- * \tparam T1 \deduced The type of the first constructor argument.
- * \param  [in] a1 The first constructor argument.
+ * \tparam Ts \deduced Types of the constructor arguments.
+ * \param  [in] args Constructor arguments.
  * \return A Ptr to the newly created \c T.
  */
 template <typename T,
-          typename T1>
-Ptr<T> Create (T1 a1);
+          typename... Ts>
+Ptr<T> Create (Ts... args);
 
-/**
- * \tparam T  \explicit The type of class object to create.
- * \tparam T1 \deduced The type of the first constructor argument.
- * \tparam T2 \deduced The type of the second constructor argument.
- * \param  [in] a1 The first constructor argument.
- * \param  [in] a2 The second constructor argument.
- * \return A Ptr to the newly created \c T.
- */
-template <typename T,
-          typename T1, typename T2>
-Ptr<T> Create (T1 a1, T2 a2);
-
-/**
- * \tparam T  \explicit The type of class object to create.
- * \tparam T1 \deduced The type of the first constructor argument.
- * \tparam T2 \deduced The type of the second constructor argument.
- * \tparam T3 \deduced The type of the third constructor argument.
- * \param  [in] a1 The first constructor argument.
- * \param  [in] a2 The second constructor argument.
- * \param  [in] a3 The third constructor argument.
- * \return A Ptr to the newly created \c T.
- */
-template <typename T,
-          typename T1, typename T2,
-          typename T3>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3);
-
-/**
- * \tparam T  \explicit The type of class object to create.
- * \tparam T1 \deduced The type of the first constructor argument.
- * \tparam T2 \deduced The type of the second constructor argument.
- * \tparam T3 \deduced The type of the third constructor argument.
- * \tparam T4 \deduced The type of the fourth constructor argument.
- * \param  [in] a1 The first constructor argument.
- * \param  [in] a2 The second constructor argument.
- * \param  [in] a3 The third constructor argument.
- * \param  [in] a4 The fourth constructor argument.
- * \return A Ptr to the newly created \c T.
- */
-template <typename T,
-          typename T1, typename T2,
-          typename T3, typename T4>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4);
-
-/**
- * \tparam T  \explicit The type of class object to create.
- * \tparam T1 \deduced The type of the first constructor argument.
- * \tparam T2 \deduced The type of the second constructor argument.
- * \tparam T3 \deduced The type of the third constructor argument.
- * \tparam T4 \deduced The type of the fourth constructor argument.
- * \tparam T5 \deduced The type of the fifth constructor argument.
- * \param  [in] a1 The first constructor argument.
- * \param  [in] a2 The second constructor argument.
- * \param  [in] a3 The third constructor argument.
- * \param  [in] a4 The fourth constructor argument.
- * \param  [in] a5 The fifth constructor argument.
- * \return A Ptr to the newly created \c T.
- */
-template <typename T,
-          typename T1, typename T2,
-          typename T3, typename T4,
-          typename T5>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4, T5 a5);
-
-/**
- * \tparam T  \explicit The type of class object to create.
- * \tparam T1 \deduced The type of the first constructor argument.
- * \tparam T2 \deduced The type of the second constructor argument.
- * \tparam T3 \deduced The type of the third constructor argument.
- * \tparam T4 \deduced The type of the fourth constructor argument.
- * \tparam T5 \deduced The type of the fifth constructor argument.
- * \tparam T6 \deduced The type of the sixth constructor argument.
- * \param  [in] a1 The first constructor argument.
- * \param  [in] a2 The second constructor argument.
- * \param  [in] a3 The third constructor argument.
- * \param  [in] a4 The fourth constructor argument.
- * \param  [in] a5 The fifth constructor argument.
- * \param  [in] a6 The sixth constructor argument.
- * \return A Ptr to the newly created \c T.
- */
-template <typename T,
-          typename T1, typename T2,
-          typename T3, typename T4,
-          typename T5, typename T6>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4, T5 a5, T6 a6);
-
-/**
- * \tparam T  \explicit The type of class object to create.
- * \tparam T1 \deduced The type of the first constructor argument.
- * \tparam T2 \deduced The type of the second constructor argument.
- * \tparam T3 \deduced The type of the third constructor argument.
- * \tparam T4 \deduced The type of the fourth constructor argument.
- * \tparam T5 \deduced The type of the fifth constructor argument.
- * \tparam T6 \deduced The type of the sixth constructor argument.
- * \tparam T7 \deduced The type of the seventh constructor argument.
- * \param  [in] a1 The first constructor argument.
- * \param  [in] a2 The second constructor argument.
- * \param  [in] a3 The third constructor argument.
- * \param  [in] a4 The fourth constructor argument.
- * \param  [in] a5 The fifth constructor argument.
- * \param  [in] a6 The sixth constructor argument.
- * \param  [in] a7 The seventh constructor argument.
- * \return A Ptr to the newly created \c T.
- */
-template <typename T,
-          typename T1, typename T2,
-          typename T3, typename T4,
-          typename T5, typename T6,
-          typename T7>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4, T5 a5, T6 a6, T7 a7);
 /** @}*/
 
 /**
  * \ingroup ptr
  * Output streamer.
+ * \tparam T \deduced The type of the underlying Object.
  * \param [in,out] os The output stream.
  * \param [in] p The Ptr.
  * \returns The stream.
@@ -421,6 +308,7 @@ bool operator != (Ptr<T1> const &lhs, Ptr<T2> const &rhs);
  * \ingroup ptr
  * Comparison operator applied to the underlying pointers.
  *
+ * \tparam T \deduced The type of the operands.
  * \param [in] lhs The left operand.
  * \param [in] rhs The right operand.
  * \return The comparison on the underlying pointers.
@@ -435,7 +323,7 @@ bool operator > (const Ptr<T> &lhs, const Ptr<T> &rhs);
 template <typename T>
 bool operator >= (const Ptr<T> &lhs, const Ptr<T> &rhs);
 /** @} */
-  
+
 /**
  * Return a copy of \c p with its stored pointer const casted from
  * \c T2 to \c T1.
@@ -448,7 +336,7 @@ bool operator >= (const Ptr<T> &lhs, const Ptr<T> &rhs);
 template <typename T1, typename T2>
 Ptr<T1> const_pointer_cast (Ptr<T2> const&p);
 
-// Duplicate of struct CallbackTraits<T> as defined in callback.h  
+// Duplicate of struct CallbackTraits<T> as defined in callback.h
 template <typename T>
 struct CallbackTraits;
 
@@ -460,7 +348,7 @@ struct CallbackTraits;
  *
  * This is the specialization for Ptr types.
  *
- * \tparam T \deduced The base object type.
+ * \tparam T \deduced The type of the underlying object.
  */
 template <typename T>
 struct CallbackTraits<Ptr<T> >
@@ -487,7 +375,7 @@ struct EventMemberImplObjTraits;
  *
  * This is the specialization for Ptr types.
  *
- * \tparam T \explicit The class type.
+ * \tparam T \deduced The type of the underlying object.
  */
 template <typename T>
 struct EventMemberImplObjTraits<Ptr<T> >
@@ -496,7 +384,8 @@ struct EventMemberImplObjTraits<Ptr<T> >
    * \param [in] p Object pointer
    * \return A reference to the object pointed to by p
    */
-  static T &GetReference (Ptr<T> p) {
+  static T & GetReference (Ptr<T> p)
+  {
     return *PeekPointer (p);
   }
 };
@@ -512,52 +401,10 @@ namespace ns3 {
  *  friend non-member function implementations
  ************************************************/
 
-template <typename T>
-Ptr<T> Create (void)
+template <typename T, typename... Ts>
+Ptr<T> Create (Ts... args)
 {
-  return Ptr<T> (new T (), false);
-}
-
-template <typename T, typename T1>
-Ptr<T> Create (T1 a1)
-{
-  return Ptr<T> (new T (a1), false);
-}
-
-template <typename T, typename T1, typename T2>
-Ptr<T> Create (T1 a1, T2 a2)
-{
-  return Ptr<T> (new T (a1, a2), false);
-}
-
-template <typename T, typename T1, typename T2, typename T3>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3)
-{
-  return Ptr<T> (new T (a1, a2, a3), false);
-}
-
-template <typename T, typename T1, typename T2, typename T3, typename T4>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4)
-{
-  return Ptr<T> (new T (a1, a2, a3, a4), false);
-}
-
-template <typename T, typename T1, typename T2, typename T3, typename T4, typename T5>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4, T5 a5)
-{
-  return Ptr<T> (new T (a1, a2, a3, a4, a5), false);
-}
-
-template <typename T, typename T1, typename T2, typename T3, typename T4, typename T5, typename T6>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4, T5 a5, T6 a6)
-{
-  return Ptr<T> (new T (a1, a2, a3, a4, a5, a6), false);
-}
-
-template <typename T, typename T1, typename T2, typename T3, typename T4, typename T5, typename T6, typename T7>
-Ptr<T> Create (T1 a1, T2 a2, T3 a3, T4 a4, T5 a5, T6 a6, T7 a7)
-{
-  return Ptr<T> (new T (a1, a2, a3, a4, a5, a6, a7), false);
+  return Ptr<T> (new T (args...), false);
 }
 
 template <typename U>
@@ -581,42 +428,42 @@ std::ostream &operator << (std::ostream &os, const Ptr<T> &p)
 }
 
 template <typename T1, typename T2>
-bool 
+bool
 operator == (Ptr<T1> const &lhs, T2 const *rhs)
 {
   return PeekPointer (lhs) == rhs;
 }
 
 template <typename T1, typename T2>
-bool 
+bool
 operator == (T1 const *lhs, Ptr<T2> &rhs)
 {
   return lhs == PeekPointer (rhs);
 }
 
 template <typename T1, typename T2>
-bool 
+bool
 operator != (Ptr<T1> const &lhs, T2 const *rhs)
 {
   return PeekPointer (lhs) != rhs;
 }
 
 template <typename T1, typename T2>
-bool 
+bool
 operator != (T1 const *lhs, Ptr<T2> &rhs)
 {
   return lhs != PeekPointer (rhs);
 }
 
 template <typename T1, typename T2>
-bool 
+bool
 operator == (Ptr<T1> const &lhs, Ptr<T2> const &rhs)
 {
   return PeekPointer (lhs) == PeekPointer (rhs);
 }
 
 template <typename T1, typename T2>
-bool 
+bool
 operator != (Ptr<T1> const &lhs, Ptr<T2> const &rhs)
 {
   return PeekPointer (lhs) != PeekPointer (rhs);
@@ -680,6 +527,7 @@ StaticCast (Ptr<T2> const&p)
 /**
  * Return a deep copy of a Ptr.
  *
+ * \tparam T \deduced The type of the underlying object.
  * \param [in] object The object Ptr to copy.
  * \returns The copy.
  */
@@ -704,7 +552,7 @@ Ptr<T> Copy (Ptr<const T> object)
  ***************************************************/
 
 template <typename T>
-void 
+void
 Ptr<T>::Acquire (void) const
 {
   if (m_ptr != 0)
@@ -716,8 +564,7 @@ Ptr<T>::Acquire (void) const
 template <typename T>
 Ptr<T>::Ptr ()
   : m_ptr (0)
-{
-}
+{}
 
 template <typename T>
 Ptr<T>::Ptr (T *ptr)
@@ -737,7 +584,7 @@ Ptr<T>::Ptr (T *ptr, bool ref)
 }
 
 template <typename T>
-Ptr<T>::Ptr (Ptr const&o) 
+Ptr<T>::Ptr (Ptr const&o)
   : m_ptr (PeekPointer (o))
 {
   Acquire ();
@@ -751,9 +598,9 @@ Ptr<T>::Ptr (Ptr<U> const &o)
 }
 
 template <typename T>
-Ptr<T>::~Ptr () 
+Ptr<T>::~Ptr ()
 {
-  if (m_ptr != 0) 
+  if (m_ptr != 0)
     {
       m_ptr->Unref ();
     }
@@ -761,13 +608,13 @@ Ptr<T>::~Ptr ()
 
 template <typename T>
 Ptr<T> &
-Ptr<T>::operator = (Ptr const& o) 
+Ptr<T>::operator = (Ptr const& o)
 {
   if (&o == this)
     {
       return *this;
     }
-  if (m_ptr != 0) 
+  if (m_ptr != 0)
     {
       m_ptr->Unref ();
     }
@@ -778,8 +625,9 @@ Ptr<T>::operator = (Ptr const& o)
 
 template <typename T>
 T *
-Ptr<T>::operator -> () 
+Ptr<T>::operator -> ()
 {
+  NS_ASSERT_MSG (m_ptr, "Attempted to dereference zero pointer");
   return m_ptr;
 }
 
@@ -787,6 +635,7 @@ template <typename T>
 T *
 Ptr<T>::operator -> () const
 {
+  NS_ASSERT_MSG (m_ptr, "Attempted to dereference zero pointer");
   return m_ptr;
 }
 
@@ -794,6 +643,7 @@ template <typename T>
 T &
 Ptr<T>::operator * () const
 {
+  NS_ASSERT_MSG (m_ptr, "Attempted to dereference zero pointer");
   return *m_ptr;
 }
 
@@ -801,12 +651,13 @@ template <typename T>
 T &
 Ptr<T>::operator * ()
 {
+  NS_ASSERT_MSG (m_ptr, "Attempted to dereference zero pointer");
   return *m_ptr;
 }
 
 template <typename T>
-bool 
-Ptr<T>::operator! () 
+bool
+Ptr<T>::operator! ()
 {
   return m_ptr == 0;
 }
@@ -814,7 +665,7 @@ Ptr<T>::operator! ()
 template <typename T>
 Ptr<T>::operator Tester * () const
 {
-  if (m_ptr == 0) 
+  if (m_ptr == 0)
     {
       return 0;
     }
