@@ -53,22 +53,22 @@ namespace ns3 {
  *   this marks a change in policy starting with ns-3.4.
  * - In ns-3.14 and earlier, ns-3 simulations used a different wrapper
  *   class called ns3::RandomVariable.  This implementation is documented
- *   above under Legacy Random Variables. As of ns-3.15, this class has 
- *   been replaced by ns3::RandomVariableStream; the underlying 
+ *   above under Legacy Random Variables. As of ns-3.15, this class has
+ *   been replaced by ns3::RandomVariableStream; the underlying
  *   pseudo-random number generator has not changed.
  * - To obtain randomness across multiple simulation runs, you must
  *   either set the seed differently or set the run number differently.
  *   To set a seed, call ns3::RngSeedManager::SetSeed() at the beginning
- *   of the program; to set a run number with the same seed, call 
+ *   of the program; to set a run number with the same seed, call
  *   ns3::RngSeedManager::SetRun() at the beginning of the program.
- * - Each RandomVariableStream used in ns-3 has a virtual random number 
- *   generator associated with it; all random variables use either 
- *   a fixed or random seed based on the use of the global seed. 
- * - If you intend to perform multiple runs of the same scenario, 
- *   with different random numbers, please be sure to read the manual 
+ * - Each RandomVariableStream used in ns-3 has a virtual random number
+ *   generator associated with it; all random variables use either
+ *   a fixed or random seed based on the use of the global seed.
+ * - If you intend to perform multiple runs of the same scenario,
+ *   with different random numbers, please be sure to read the manual
  *   section on how to perform independent replications.
  */
-  
+
 class RngStream;
 
 /**
@@ -109,7 +109,7 @@ public:
   /**
    * \brief Destructor.
    */
-  virtual ~RandomVariableStream();
+  virtual ~RandomVariableStream ();
 
   /**
    * \brief Specifies the stream number for the RngStream.
@@ -123,19 +123,19 @@ public:
    * \return The stream number for the RngStream.
    * -1 means this stream was allocated automatically.
    */
-  int64_t GetStream(void) const;
+  int64_t GetStream (void) const;
 
   /**
    * \brief Specify whether antithetic values should be generated.
    * \param [in] isAntithetic If \c true antithetic value will be generated.
    */
-  void SetAntithetic(bool isAntithetic);
+  void SetAntithetic (bool isAntithetic);
 
   /**
    * \brief Check if antithetic values will be generated.
    * \return \c true if antithetic values will be generated.
    */
-  bool IsAntithetic(void) const;
+  bool IsAntithetic (void) const;
 
   /**
    * \brief Get the next random value as a double drawn from the distribution.
@@ -154,7 +154,7 @@ protected:
    * \brief Get the pointer to the underlying RngStream.
    * \return The underlying RngStream
    */
-  RngStream *Peek(void) const;
+  RngStream * Peek (void) const;
 
 private:
   /**
@@ -189,7 +189,7 @@ private:
 
 };  // class RandomVariableStream
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The uniform distribution Random Number Generator (RNG).
@@ -208,11 +208,11 @@ private:
  * \code
  *   double min = 0.0;
  *   double max = 10.0;
- *  
+ *
  *   Ptr<UniformRandomVariable> x = CreateObject<UniformRandomVariable> ();
  *   x->SetAttribute ("Min", DoubleValue (min));
  *   x->SetAttribute ("Max", DoubleValue (max));
- * 
+ *
  *   // The values returned by a uniformly distributed random
  *   // variable should always be within the range
  *   //
@@ -271,7 +271,7 @@ public:
 
   /**
    * \brief Get the next random value, as an unsigned integer in the
-   * specified range \f$[min, max]/f$.
+   * specified range \f$[min, max]\f$.
    *
    * \note The upper limit is included in the output range.
    *
@@ -294,7 +294,7 @@ public:
    * \note The upper limit is included in the output range.
    */
   virtual uint32_t GetInteger (void);
-  
+
 private:
   /** The lower bound on values that can be returned by this RNG stream. */
   double m_min;
@@ -304,7 +304,7 @@ private:
 
 };  // class UniformRandomVariable
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The Random Number Generator (RNG) that returns a constant.
@@ -360,7 +360,7 @@ private:
 
 };  // class ConstantRandomVariable
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The Random Number Generator (RNG) that returns a pattern of
@@ -465,7 +465,7 @@ private:
 
 };  // class SequentialRandomVariable
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The exponential distribution Random Number Generator (RNG).
@@ -515,11 +515,11 @@ private:
  * \code
  *   double mean = 3.14;
  *   double bound = 0.0;
- *  
+ *
  *   Ptr<ExponentialRandomVariable> x = CreateObject<ExponentialRandomVariable> ();
  *   x->SetAttribute ("Mean", DoubleValue (mean));
  *   x->SetAttribute ("Bound", DoubleValue (bound));
- * 
+ *
  *   // The expected value for the mean of the values returned by an
  *   // exponentially distributed random variable is equal to mean.
  *   double value = x->GetValue ();
@@ -530,7 +530,7 @@ private:
  * The antithetic value is calculated from
  *
  *   \f[
- *       x' = - mean * \log(1 - u), 
+ *       x' = - mean * \log(1 - u),
  *   \f]
  *
  * where again \f$u\f$ is a uniform random variable on \f$[0,1)\f$.
@@ -596,7 +596,7 @@ private:
 
 };  // class ExponentialRandomVariable
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The Pareto distribution Random Number Generator (RNG).
@@ -622,11 +622,11 @@ private:
  * \code
  *   double scale = 5.0;
  *   double shape = 2.0;
- * 
+ *
  *   Ptr<ParetoRandomVariable> x = CreateObject<ParetoRandomVariable> ();
  *   x->SetAttribute ("Scale", DoubleValue (scale));
  *   x->SetAttribute ("Shape", DoubleValue (shape));
- * 
+ *
  *   // The expected value for the mean of the values returned by a
  *   // Pareto distributed random variable is
  *   //
@@ -652,13 +652,6 @@ public:
    */
   ParetoRandomVariable ();
 
-  /**
-   * \brief Returns the mean parameter for the Pareto distribution returned by this RNG stream.
-   * \return The mean parameter for the Pareto distribution returned by this RNG stream.
-   */
-  NS_DEPRECATED
-  double GetMean (void) const;
-
   /**
    * \brief Returns the scale parameter for the Pareto distribution returned by this RNG stream.
    * \return The scale parameter for the Pareto distribution returned by this RNG stream.
@@ -693,7 +686,7 @@ public:
    *    \f]
    *
    * is a value that would be returned normally.
-   *    
+   *
    * The value returned in the antithetic case, \f$x'\f$, is
    * calculated as
    *
@@ -746,11 +739,11 @@ public:
    *    \f]
    *
    * is a value that would be returned normally, where
-   *     
+   *
    *    \f[
    *         scale  =  mean * (shape - 1.0) / shape  .
    *    \f]
-   *    
+   *
    * The value returned in the antithetic case, \f$x'\f$, is
    * calculated as
    *
@@ -807,7 +800,7 @@ private:
 
 };  // class ParetoRandomVariable
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The Weibull distribution Random Number Generator (RNG) that allows stream numbers to be set deterministically.
@@ -831,20 +824,20 @@ private:
  * \code
  *   double scale = 5.0;
  *   double shape = 1.0;
- * 
+ *
  *   Ptr<WeibullRandomVariable> x = CreateObject<WeibullRandomVariable> ();
  *   x->SetAttribute ("Scale", DoubleValue (scale));
  *   x->SetAttribute ("Shape", DoubleValue (shape));
- * 
+ *
  *   // The expected value for the mean of the values returned by a
  *   // Weibull distributed random variable is
  *   //
  *   //     E[value]  =  scale * Gamma(1 + 1 / shape)  ,
- *   //               
- *   // where Gamma() is the Gamma function.  Note that 
- *   //               
+ *   //
+ *   // where Gamma() is the Gamma function.  Note that
+ *   //
  *   //     Gamma(n)  =  (n - 1)!
- *   //               
+ *   //
  *   // if n is a positive integer.
  *   //
  *   // For this example,
@@ -857,7 +850,7 @@ private:
  *   // which means
  *   //
  *   //     E[value]  =  scale  .
- *   //               
+ *   //
  *   double value = x->GetValue ();
  * \endcode
  */
@@ -1013,7 +1006,7 @@ private:
 
 };  // class WeibullRandomVariable
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The normal (Gaussian) distribution Random Number Generator
@@ -1037,11 +1030,11 @@ private:
  * \code
  *   double mean = 5.0;
  *   double variance = 2.0;
- *   
+ *
  *   Ptr<NormalRandomVariable> x = CreateObject<NormalRandomVariable> ();
  *   x->SetAttribute ("Mean", DoubleValue (mean));
  *   x->SetAttribute ("Variance", DoubleValue (variance));
- *   
+ *
  *   // The expected value for the mean of the values returned by a
  *   // normally distributed random variable is equal to mean.
  *   double value = x->GetValue ();
@@ -1252,7 +1245,7 @@ private:
 
 };  // class NormalRandomVariable
 
-  
+
 /**
  * \ingroup randomvariable
  * \brief The log-normal distribution Random Number Generator
@@ -1281,13 +1274,13 @@ private:
  * \code
  *   double mu = 5.0;
  *   double sigma = 2.0;
- *   
+ *
  *   Ptr<LogNormalRandomVariable> x = CreateObject<LogNormalRandomVariable> ();
  *   x->SetAttribute ("Mu", DoubleValue (mu));
  *   x->SetAttribute ("Sigma", DoubleValue (sigma));
- *   
+ *
  *   // The expected value for the mean of the values returned by a
- *   // log-normally distributed random variable is equal to 
+ *   // log-normally distributed random variable is equal to
  *   //
  *   //                             2
  *   //                   mu + sigma  / 2
@@ -1472,7 +1465,7 @@ private:
   double m_sigma;
 
 };  // class LogNormalRandomVariable
-  
+
 
 /**
  * \ingroup randomvariable
@@ -1492,13 +1485,13 @@ private:
  * \code
  *   double alpha = 5.0;
  *   double beta = 2.0;
- *   
+ *
  *   Ptr<GammaRandomVariable> x = CreateObject<GammaRandomVariable> ();
  *   x->SetAttribute ("Alpha", DoubleValue (alpha));
  *   x->SetAttribute ("Beta", DoubleValue (beta));
- *   
+ *
  *   // The expected value for the mean of the values returned by a
- *   // gammaly distributed random variable is equal to 
+ *   // gammaly distributed random variable is equal to
  *   //
  *   //     E[value]  =  alpha * beta  .
  *   //
@@ -1645,7 +1638,7 @@ private:
   double m_next;
 
 };  // class GammaRandomVariable
-  
+
 
 /**
  * \ingroup randomvariable
@@ -1669,13 +1662,13 @@ private:
  * \code
  *   uint32_t k = 5;
  *   double lambda = 2.0;
- *   
+ *
  *   Ptr<ErlangRandomVariable> x = CreateObject<ErlangRandomVariable> ();
  *   x->SetAttribute ("K", IntegerValue (k));
  *   x->SetAttribute ("Lambda", DoubleValue (lambda));
- *   
+ *
  *   // The expected value for the mean of the values returned by a
- *   // Erlangly distributed random variable is equal to 
+ *   // Erlangly distributed random variable is equal to
  *   //
  *   //     E[value]  =  k * lambda  .
  *   //
@@ -1782,7 +1775,7 @@ private:
    * over [0,1] and
    *
    *    \f[
-   *         x = - mean * \log(u) 
+   *         x = - mean * \log(u)
    *    \f]
    *
    * is a value that would be returned normally, then \f$(1 - u\f$) is
@@ -1790,7 +1783,7 @@ private:
    * returned in the antithetic case, \f$x'\f$, is calculated as
    *
    *    \f[
-   *         x' = - mean * \log(1 - u), 
+   *         x' = - mean * \log(1 - u),
    *    \f]
    *
    * which now involves the log of the distance \f$u\f$ is from the 1.
@@ -1804,7 +1797,7 @@ private:
   double m_lambda;
 
 };  // class ErlangRandomVariable
-  
+
 
 /**
  * \ingroup randomvariable
@@ -1823,12 +1816,12 @@ private:
  *   double mean = 5.0;
  *   double min = 2.0;
  *   double max = 10.0;
- *   
+ *
  *   Ptr<TriangularRandomVariable> x = CreateObject<TriangularRandomVariable> ();
  *   x->SetAttribute ("Mean", DoubleValue (mean));
  *   x->SetAttribute ("Min", DoubleValue (min));
  *   x->SetAttribute ("Max", DoubleValue (max));
- *   
+ *
  *   // The expected value for the mean of the values returned by a
  *   // triangularly distributed random variable is equal to mean.
  *   double value = x->GetValue ();
@@ -2037,7 +2030,7 @@ private:
   double m_max;
 
 };  // class TriangularRandomVariable
-  
+
 
 /**
  * \ingroup randomvariable
@@ -2061,29 +2054,29 @@ private:
  * \code
  *   uint32_t n = 1;
  *   double alpha = 2.0;
- *   
+ *
  *   Ptr<ZipfRandomVariable> x = CreateObject<ZipfRandomVariable> ();
  *   x->SetAttribute ("N", IntegerValue (n));
  *   x->SetAttribute ("Alpha", DoubleValue (alpha));
- *   
+ *
  *   // The expected value for the mean of the values returned by a
- *   // Zipfly distributed random variable is equal to 
+ *   // Zipfly distributed random variable is equal to
  *   //
  *   //                   H
  *   //                    N, alpha - 1
  *   //     E[value]  =  ---------------
  *   //                     H
  *   //                      N, alpha
- *   //                          
+ *   //
  *   // where
  *   //
- *   //                    N   
- *   //                   ---    
+ *   //                    N
+ *   //                   ---
  *   //                   \     -alpha
  *   //     H          =  /    m        .
  *   //      N, alpha     ---
- *   //                   m=1    
- *   //                 
+ *   //                   m=1
+ *   //
  *   // For this test,
  *   //
  *   //                      -(alpha - 1)
@@ -2093,7 +2086,7 @@ private:
  *   //                     1
  *   //
  *   //               =  1  .
- *   //               
+ *   //
  *   double value = x->GetValue ();
  * \endcode
  */
@@ -2196,7 +2189,7 @@ private:
   double m_c;
 
 };  // class ZipfRandomVariable
-  
+
 
 /**
  * \ingroup randomvariable
@@ -2217,23 +2210,23 @@ private:
  * Here is an example of how to use this class:
  * \code
  *   double alpha = 2.0;
- *   
+ *
  *   Ptr<ZetaRandomVariable> x = CreateObject<ZetaRandomVariable> ();
  *   x->SetAttribute ("Alpha", DoubleValue (alpha));
- *   
+ *
  *   // The expected value for the mean of the values returned by a
- *   // zetaly distributed random variable is equal to 
+ *   // zetaly distributed random variable is equal to
  *   //
  *   //                   zeta(alpha - 1)
  *   //     E[value]  =  ---------------   for alpha > 2 ,
  *   //                     zeta(alpha)
- *   //                          
+ *   //
  *   // where zeta(alpha) is the Riemann zeta function.
- *   //                 
+ *   //
  *   // There are no simple analytic forms for the Riemann zeta
  *   // function, which is the reason the known mean of the values
  *   // cannot be calculated in this example.
- *   //               
+ *   //
  *   double value = x->GetValue ();
  * \endcode
  */
@@ -2325,7 +2318,7 @@ private:
   double m_b;
 
 };  // class ZetaRandomVariable
-  
+
 
 /**
  * \ingroup randomvariable
@@ -2345,7 +2338,7 @@ private:
  * Here is an example of how to use this class:
  * \code
  *   Ptr<DeterministicRandomVariable> s = CreateObject<DeterministicRandomVariable> ();
- * 
+ *
  *   // The following array should give the sequence
  *   //
  *   //    4, 4, 7, 7, 10, 10 .
@@ -2353,7 +2346,7 @@ private:
  *   double array [] = { 4, 4, 7, 7, 10, 10};
  *   uint64_t count = 6;
  *   s->SetValueArray (array, count);
- * 
+ *
  *   double value = x->GetValue ();
  * \endcode
  */
@@ -2406,38 +2399,83 @@ private:
   double* m_data;
 
 };  // class DeterministicRandomVariable
-  
+
 
 /**
  * \ingroup randomvariable
- * \brief The Random Number Generator (RNG) that has a specified empirical distribution.
+ * \brief The Random Number Generator (RNG) that has a specified
+ * empirical distribution.
  *
  * Defines a random variable  that has a specified, empirical
- * distribution.  The distribution is specified by a
- * series of calls to the CDF member function, specifying a
- * value and the probability that the function value is less than
- * the specified value.  When values are requested,
- * a uniform random variable is used to select a probability,
- * and the return value is interpreted linearly between the
- * two appropriate points in the CDF.  The method is known
+ * distribution.  The cumulative probability distribution function (CDF)
+ * is specified by a
+ * series of calls to the CDF() member function, specifying a
+ * value and the probability that the distribution is less than
+ * the specified value.  When random values are requested,
+ * a uniform random variable `r` is used to select a probability,
+ * and the return value is chosen from the largest input value with CDF
+ * less than the random value. The method is known
  * as inverse transform sampling:
  * (http://en.wikipedia.org/wiki/Inverse_transform_sampling).
  *
- * Here is an example of how to use this class:
- * \code
- *   // Create the RNG with a uniform distribution between 0 and 10.
- *   Ptr<EmpiricalRandomVariable> x = CreateObject<EmpiricalRandomVariable> ();
- *   x->CDF ( 0.0,  0.0);
- *   x->CDF ( 5.0,  0.5);
- *   x->CDF (10.0,  1.0);
+ * This generator has two modes: *sampling* and *interpolating*.
+ * In *sampling* mode this random variable generator
+ * treats the CDF as an exact histogram and returns
+ * one of the histogram inputs exactly.  This is appropriate
+ * when the configured CDF represents the exact probability
+ * distribution, for a categorical variable, for example.
+ *
+ * In *interpolating* mode this random variable generator linearly
+ * interpolates between the CDF values defining the histogram bins.
+ * This is appropriate when the configured CDF is an approximation
+ * to a continuous underlying probability distribution.
+ *
+ * For historical reasons the default is interpolating.
+ * To switch modes use the \c Interpolate Attribute, or call SetInterpolate().
+ * You can change modes at any time.
+ *
+ * If you find yourself switching frequently it could be simpler to
+ * set the mode to sampling, then use the GetValue() function for
+ * sampled values, and Interpolate() function for interpolated values.
+ *
+ * The CDF need not start with a probability of zero,
+ * nor end with a probability of 1.0.  If the selected uniform
+ * random value `r` is less than the first CDF point, that point
+ * is selected. If `r` is greater than the last CDF point the last
+ * point is selected.  In either case the interpolating mode will *not*
+ * interpolate (since there is no value beyond `r` to work with), but
+ * simply return the extremal CDF value, as in sampling.
  * 
- *   // The expected value for the mean of the values returned by this
- *   // empirical distribution is the midpoint of the distribution
- *   //
- *   //     E[value]  =  5 .
- *   //                          
- *   double value = x->GetValue ();
- * \endcode
+ * Here is an example of how to use this class:
+ *
+ *    // Create the RNG with a non-uniform distribution between 0 and 10.
+ *    // in sampling mode.
+ *    Ptr<EmpiricalRandomVariable> x = CreateObject<EmpiricalRandomVariable> ();
+ *    x->SetInterpolate (false);
+ *    x->CDF ( 0.0,  0.0);
+ *    x->CDF ( 5.0,  0.25);
+ *    x->CDF (10.0,  1.0);
+ *
+ *    double value = x->GetValue ();
+ *
+ * The expected values and probabilities returned by GetValue are
+ *
+ * Value | Probability
+ * ----: | ----------:
+ *  0.0  |  0
+ *  5.0  | 25%
+ * 10.0  | 75%
+ *
+ * The only two values ever returned are 5 and 10, with unequal probability.
+ *
+ * If instead you want linear interpolation between the points of the CDF
+ * use the Interpolate() function:
+ *
+ *     double interp = x->Interpolate ();
+ *
+ * This will return continuous values on the range [0,1).
+ *
+ * See empirical-random-variable-example.cc for an example.
  */
 class EmpiricalRandomVariable : public RandomVariableStream
 {
@@ -2450,14 +2488,16 @@ public:
 
   /**
    * \brief Creates an empirical RNG that has a specified, empirical
-   * distribution.
+   * distribution, and configured for interpolating mode.
    */
-  EmpiricalRandomVariable ();
+  EmpiricalRandomVariable (void);
 
   /**
    * \brief Specifies a point in the empirical distribution
+   * \note These *MUST* be inserted in ascending order of \p c
+   *
    * \param [in] v The function value for this point
-   * \param [in] c Probability that the function is less than or equal to v
+   * \param [in] c Probability that the function is less than or equal to \p v
    */
   void CDF (double v, double c);  // Value, prob <= Value
 
@@ -2465,7 +2505,10 @@ public:
    * \brief Returns the next value in the empirical distribution.
    * \return The floating point next value in the empirical distribution.
    *
-   * Note that antithetic values are being generated if m_isAntithetic
+   * Note that this does not interpolate the CDF, but treats it as a
+   * stepwise continuous function.
+   *
+   * Also note that antithetic values are being generated if m_isAntithetic
    * is equal to true.  If \f$u\f$ is a uniform variable over [0,1]
    * and \f$x\f$ is a value that would be returned normally, then
    * \f$(1 - u\f$) is the distance that \f$u\f$ would be from \f$1\f$.
@@ -2478,7 +2521,9 @@ public:
    * \brief Returns the next value in the empirical distribution.
    * \return The integer next value in the empirical distribution.
    *
-   * Note that antithetic values are being generated if m_isAntithetic
+   * Note that this does not interpolate the CDF, but treats it as a
+   * stepwise continuous function.
+   * Also note that antithetic values are being generated if m_isAntithetic
    * is equal to true.  If \f$u\f$ is a uniform variable over [0,1]
    * and \f$x\f$ is a value that would be returned normally, then
    * \f$(1 - u\f$) is the distance that \f$u\f$ would be from \f$1\f$.
@@ -2487,34 +2532,45 @@ public:
    */
   virtual uint32_t GetInteger (void);
 
+  /**
+   * \brief Returns the next value in the empirical distribution using
+   * linear interpolation.
+   * \return The floating point next value in the empirical distribution
+   * using linear interpolation.
+   */
+    virtual double Interpolate (void);
+
+  /**
+   * \brief Switch the mode between sampling the CDF and interpolating.
+   * The default mode is sampling.
+   * \param [in] interpolate If \c true set to interpolation, otherwise sampling.
+   * \returns The previous interpolate flag value.
+   */
+  bool SetInterpolate (bool interpolate);
+
 private:
-  /** Helper to hold one point of the CDF. */
+  /** \brief Helper to hold one point of the CDF. */
   class ValueCDF
   {
-public:
-    /** Constructor. */
-    ValueCDF ();
+  public:
+    /** \brief Constructor. */
+    ValueCDF (void);
     /**
-     * Construct from values.
+     * \brief Construct from values.
      *
-     * \param [in] v The argumetn value.
-     * \param [in] c The CDF at the argument value \p v.
+     * \param [in] v The argument value.
+     * \param [in] c The CDF at the argument value \pname{v}
      */
     ValueCDF (double v, double c);
-    /**
-     * Copy constructor.
-     *
-     * \param [in] c The other ValueCDF.
-     */
-    ValueCDF (const ValueCDF& c);
 
     /** The argument value. */
     double value;
-    /** The CDF at \p value. */
+    /** The CDF at \pname{value}  */
     double    cdf;
-  };
+  };  // class ValueCDF
+
   /**
-   * Check that the CDF is valid.
+   * \brief Check that the CDF is valid.
    *
    * A valid CDF has
    *
@@ -2523,28 +2579,57 @@ public:
    *
    * It is a fatal error to fail validation.
    */
-  virtual void Validate ();
+  void Validate (void);
+   /**
+   * \brief Do the initial rng draw and check against the extrema.
+   *
+   * If the extrema apply, \c value will have the extremal value
+   * and the return will be \c true.
+   *
+   * If the extrema do not apply \c value will have the URNG value
+   * and the return will be \c false.
+   *
+   * \param [out] value The extremal value, or the URNG.
+   * \returns \c true if \p value is the extremal result,
+   *          or \c false if \p value is the URNG value.
+   */
+  bool PreSample (double & value);
   /**
-   * Linear nterpolation between two points on the CDF to estimate
+   * \brief Sample the CDF as a histogram (without interpolation).
+   * \param [in] r The CDF value at which to sample the CDF.
+   * \return The bin value corresponding to \c r.
+   */
+  double DoSampleCDF (double r);
+  /**
+   * \brief Linear interpolation between two points on the CDF to estimate
    * the value at \p r.
    *
-   * \param [in] c1 The first argument value.
-   * \param [in] c2 The secong argument value.
-   * \param [in] v1 The first CDF value.
-   * \param [in] v2 The secong CDF value.
    * \param [in] r  The argument value to interpolate to.
-   * \returns The interpolated CDF at \p r.
+   * \returns The interpolated CDF at \pname{r}
    */
-  virtual double Interpolate (double c1, double c2,
-                              double v1, double v2, double r);
-  
+  double DoInterpolate (double r);
+
+  /**
+   * \brief Comparison operator, for use by std::upper_bound
+   * \param a [in] the first value
+   * \param b [in] the second value
+   * \returns \c true if \c a.cdf < \c b.cdf
+   */
+  friend
+  bool operator < (ValueCDF a, ValueCDF b);
+
   /** \c true once the CDF has been validated. */
   bool m_validated;
   /** The vector of CDF points. */
   std::vector<ValueCDF> m_emp;
+  /**
+   * If \c true GetValue will interpolate,
+   * otherwise treat CDF as normal histogram.
+   */
+  bool m_interpolate;
 
 };  // class EmpiricalRandomVariable
-  
+
 
 } // namespace ns3
 
