@@ -55,18 +55,20 @@ NS_LOG_COMPONENT_DEFINE ("Simulator");
 
 /**
  * \ingroup simulator
+ * \anchor GlobalValueSimulatorImplementationType
  * The specific simulator implementation to use.
  *
  * Must be derived from SimulatorImpl.
  */
 static GlobalValue g_simTypeImpl = GlobalValue
-  ("SimulatorImplementationType",
-   "The object class to use as the simulator implementation",
-   StringValue ("ns3::DefaultSimulatorImpl"),
-   MakeStringChecker ());
+    ("SimulatorImplementationType",
+    "The object class to use as the simulator implementation",
+    StringValue ("ns3::DefaultSimulatorImpl"),
+    MakeStringChecker ());
 
 /**
  * \ingroup scheduler
+ * \anchor GlobalValueSchedulerType
  * The specific event scheduler implementation to use.
  *
  * Must be derived from Scheduler.
@@ -81,7 +83,7 @@ static GlobalValue g_schedTypeImpl = GlobalValue ("SchedulerType",
  * \brief Get the static SimulatorImpl instance.
  * \return The SimulatorImpl instance pointer.
  */
-static SimulatorImpl **PeekImpl (void)
+static SimulatorImpl ** PeekImpl (void)
 {
   static SimulatorImpl *impl = 0;
   return &impl;
@@ -119,9 +121,9 @@ static SimulatorImpl * GetImpl (void)
 
 //
 // Note: we call LogSetTimePrinter _after_ creating the implementation
-// object because the act of creation can trigger calls to the logging 
-// framework which would call the TimePrinter function which would call 
-// Simulator::Now which would call Simulator::GetImpl, and, thus, get us 
+// object because the act of creation can trigger calls to the logging
+// framework which would call the TimePrinter function which would call
+// Simulator::Now which would call Simulator::GetImpl, and, thus, get us
 // in an infinite recursion until the stack explodes.
 //
       LogSetTimePrinter (&DefaultTimePrinter);
@@ -135,13 +137,13 @@ Simulator::Destroy (void)
 {
   NS_LOG_FUNCTION_NOARGS ();
 
-  SimulatorImpl **pimpl = PeekImpl (); 
+  SimulatorImpl **pimpl = PeekImpl ();
   if (*pimpl == 0)
     {
       return;
     }
   /* Note: we have to call LogSetTimePrinter (0) below because if we do not do
-   * this, and restart a simulation after this call to Destroy, (which is 
+   * this, and restart a simulation after this call to Destroy, (which is
    * legal), Simulator::GetImpl will trigger again an infinite recursion until
    * the stack explodes.
    */
@@ -159,14 +161,14 @@ Simulator::SetScheduler (ObjectFactory schedulerFactory)
   GetImpl ()->SetScheduler (schedulerFactory);
 }
 
-bool 
+bool
 Simulator::IsFinished (void)
 {
   NS_LOG_FUNCTION_NOARGS ();
   return GetImpl ()->IsFinished ();
 }
 
-void 
+void
 Simulator::Run (void)
 {
   NS_LOG_FUNCTION_NOARGS ();
@@ -174,7 +176,7 @@ Simulator::Run (void)
   GetImpl ()->Run ();
 }
 
-void 
+void
 Simulator::Stop (void)
 {
   NS_LOG_FUNCTION_NOARGS ();
@@ -182,7 +184,7 @@ Simulator::Stop (void)
   GetImpl ()->Stop ();
 }
 
-void 
+void
 Simulator::Stop (Time const &delay)
 {
   NS_LOG_FUNCTION (delay);
@@ -229,7 +231,7 @@ Simulator::ScheduleDestroy (const Ptr<EventImpl> &ev)
 {
   return DoScheduleDestroy (GetPointer (ev));
 }
-EventId 
+EventId
 Simulator::DoSchedule (Time const &time, EventImpl *impl)
 {
 #ifdef ENABLE_DES_METRICS
@@ -237,7 +239,7 @@ Simulator::DoSchedule (Time const &time, EventImpl *impl)
 #endif
   return GetImpl ()->Schedule (time, impl);
 }
-EventId 
+EventId
 Simulator::DoScheduleNow (EventImpl *impl)
 {
 #ifdef ENABLE_DES_METRICS
@@ -245,37 +247,13 @@ Simulator::DoScheduleNow (EventImpl *impl)
 #endif
   return GetImpl ()->ScheduleNow (impl);
 }
-EventId 
+EventId
 Simulator::DoScheduleDestroy (EventImpl *impl)
 {
   return GetImpl ()->ScheduleDestroy (impl);
 }
 
 
-EventId
-Simulator::Schedule (Time const &delay, void (*f)(void))
-{
-  return DoSchedule (delay, MakeEvent (f));
-}
-
-void
-Simulator::ScheduleWithContext (uint32_t context, Time const &delay, void (*f)(void))
-{
-  return ScheduleWithContext (context, delay, MakeEvent (f));
-}
-
-EventId
-Simulator::ScheduleNow (void (*f)(void))
-{
-  return DoScheduleNow (MakeEvent (f));
-}
-
-EventId
-Simulator::ScheduleDestroy (void (*f)(void))
-{
-  return DoScheduleDestroy (MakeEvent (f));
-}
-
 void
 Simulator::Remove (const EventId &id)
 {
@@ -296,7 +274,7 @@ Simulator::Cancel (const EventId &id)
   return GetImpl ()->Cancel (id);
 }
 
-bool 
+bool
 Simulator::IsExpired (const EventId &id)
 {
   if (*PeekImpl () == 0)
@@ -311,7 +289,7 @@ Time Now (void)
   return Time (Simulator::Now ());
 }
 
-Time 
+Time
 Simulator::GetMaximumSimulationTime (void)
 {
   NS_LOG_FUNCTION_NOARGS ();
@@ -323,11 +301,11 @@ Simulator::GetContext (void)
 {
   return GetImpl ()->GetContext ();
 }
-  
+
 uint64_t
 Simulator::GetEventCount (void)
 {
-  return GetImpl ()-> GetEventCount ();
+  return GetImpl ()->GetEventCount ();
 }
 
 uint32_t
@@ -362,9 +340,9 @@ Simulator::SetImplementation (Ptr<SimulatorImpl> impl)
   impl->SetScheduler (factory);
 //
 // Note: we call LogSetTimePrinter _after_ creating the implementation
-// object because the act of creation can trigger calls to the logging 
-// framework which would call the TimePrinter function which would call 
-// Simulator::Now which would call Simulator::GetImpl, and, thus, get us 
+// object because the act of creation can trigger calls to the logging
+// framework which would call the TimePrinter function which would call
+// Simulator::Now which would call Simulator::GetImpl, and, thus, get us
 // in an infinite recursion until the stack explodes.
 //
   LogSetTimePrinter (&DefaultTimePrinter);
