@@ -53,7 +53,7 @@ int
 main (int argc, char *argv[])
 {
 
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.Parse (argc, argv);
 
   // Here, we will explicitly create four nodes.
