@@ -60,7 +60,7 @@ NS_LOG_COMPONENT_DEFINE ("TAPPing6Example");
 int
 main (int argc, char *argv[])
 {
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.Parse (argc, argv);
   
   NS_LOG_INFO ("Ping6 Emulation Example with TAP");
