@@ -87,7 +87,7 @@ RunSimulation (void)
 
 int main (int argc, char *argv[])
 {
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.Parse (argc, argv);
   
   RunSimulation ();
