@@ -27,6 +27,8 @@
 #include "ns3/socket.h"
 #include "ns3/net-device.h"
 #include "ns3/uinteger.h"
+#include "ns3/string.h"
+#include "ns3/boolean.h"
 #include "ns3/trace-source-accessor.h"
 #include "ns3/object-vector.h"
 #include "ns3/ipv4-header.h"
@@ -69,6 +71,21 @@ Ipv4L3Protocol::GetTypeId (void)
                    TimeValue (Seconds (30)),
                    MakeTimeAccessor (&Ipv4L3Protocol::m_fragmentExpirationTimeout),
                    MakeTimeChecker ())
+    .AddAttribute ("EnableDuplicatePacketDetection",
+                   "Enable multicast duplicate packet detection based on RFC 6621",
+                   BooleanValue (false),
+                   MakeBooleanAccessor (&Ipv4L3Protocol::m_enableDpd),
+                   MakeBooleanChecker ())
+    .AddAttribute ("DuplicateExpire", "Expiration delay for duplicate cache entries",
+                   TimeValue (MilliSeconds (1)),
+                   MakeTimeAccessor (&Ipv4L3Protocol::m_expire),
+                   MakeTimeChecker ())
+    .AddAttribute ("PurgeExpiredPeriod", 
+                   "Time between purges of expired duplicate packet entries, "
+                   "0 means never purge",
+                   TimeValue (Seconds (1)),
+                   MakeTimeAccessor (&Ipv4L3Protocol::m_purge),
+                   MakeTimeChecker (Seconds (0)))
     .AddTraceSource ("Tx",
                      "Send ipv4 packet to outgoing interface.",
                      MakeTraceSourceAccessor (&Ipv4L3Protocol::m_txTrace),
@@ -97,6 +114,11 @@ Ipv4L3Protocol::GetTypeId (void)
                      "and is being forwarded to another node",
                      MakeTraceSourceAccessor (&Ipv4L3Protocol::m_unicastForwardTrace),
                      "ns3::Ipv4L3Protocol::SentTracedCallback")
+    .AddTraceSource ("MulticastForward",
+                     "A multicast IPv4 packet was received by this node "
+                     "and is being forwarded to another node",
+                     MakeTraceSourceAccessor (&Ipv4L3Protocol::m_multicastForwardTrace),
+                     "ns3::Ipv4L3Protocol::SentTracedCallback")
     .AddTraceSource ("LocalDeliver",
                      "An IPv4 packet was received by/for this node, "
                      "and it is being forward up the stack",
@@ -307,16 +329,18 @@ Ipv4L3Protocol::DoDispose (void)
       it->second = 0;
     }
 
-  for (MapFragmentsTimers_t::iterator it = m_fragmentsTimers.begin (); it != m_fragmentsTimers.end (); it++)
+  m_fragments.clear ();
+  m_timeoutEventList.clear ();
+  if (m_timeoutEvent.IsRunning ())
     {
-      if (it->second.IsRunning ())
-        {
-          it->second.Cancel ();
-        }
+      m_timeoutEvent.Cancel ();
     }
 
-  m_fragments.clear ();
-  m_fragmentsTimers.clear ();
+  if (m_cleanDpd.IsRunning ())
+    {
+      m_cleanDpd.Cancel ();
+    }
+  m_dups.clear ();
 
   Object::DoDispose ();
 }
@@ -506,7 +530,7 @@ Ipv4L3Protocol::IsDestinationAddress (Ipv4Address address, uint32_t iif) const
 #endif
       if (true)
         {
-          NS_LOG_LOGIC ("For me (Ipv4Addr multicast address");
+          NS_LOG_LOGIC ("For me (Ipv4Addr multicast address)");
           return true;
         }
     }
@@ -629,6 +653,13 @@ Ipv4L3Protocol::Receive ( Ptr<NetDevice> device, Ptr<const Packet> p, uint16_t p
       socket->ForwardUp (packet, ipHeader, ipv4Interface);
     }
 
+  if (m_enableDpd && ipHeader.GetDestination ().IsMulticast () && UpdateDuplicate (packet, ipHeader))
+    {
+      NS_LOG_LOGIC ("Dropping received packet -- duplicate.");
+      m_dropTrace (ipHeader, packet, DROP_DUPLICATE, m_node->GetObject<Ipv4> (), interface);
+      return;
+    }
+
   NS_ASSERT_MSG (m_routingProtocol != 0, "Need a routing protocol object to process packets");
   if (!m_routingProtocol->RouteInput (packet, ipHeader, device,
                                       MakeCallback (&Ipv4L3Protocol::IpForward, this),
@@ -724,73 +755,100 @@ Ipv4L3Protocol::Send (Ptr<Packet> packet,
 {
   NS_LOG_FUNCTION (this << packet << source << destination << uint32_t (protocol) << route);
 
-  Ipv4Header ipHeader;
   bool mayFragment = true;
+
+  // we need a copy of the packet with its tags in case we need to invoke recursion.
+  Ptr<Packet> pktCopyWithTags = packet->Copy ();
+
   uint8_t ttl = m_defaultTtl;
-  SocketIpTtlTag tag;
-  bool found = packet->RemovePacketTag (tag);
-  if (found)
+  SocketIpTtlTag ipTtlTag;
+  bool ipTtlTagFound = packet->RemovePacketTag (ipTtlTag);
+  if (ipTtlTagFound)
     {
-      ttl = tag.GetTtl ();
+      ttl = ipTtlTag.GetTtl ();
     }
 
   uint8_t tos = 0;
   SocketIpTosTag ipTosTag;
-  found = packet->RemovePacketTag (ipTosTag);
-  if (found)
+  bool ipTosTagFound = packet->RemovePacketTag (ipTosTag);
+  if (ipTosTagFound)
     {
       tos = ipTosTag.GetTos ();
     }
 
-  // Handle a few cases:
-  // 1) packet is destined to limited broadcast address
-  // 2) packet is destined to a subnet-directed broadcast address
-  // 3) packet is not broadcast, and is passed in with a route entry
-  // 4) packet is not broadcast, and is passed in with a route entry but route->GetGateway is not set (e.g., on-demand)
-  // 5) packet is not broadcast, and route is NULL (e.g., a raw socket call, or ICMP)
+  // can construct the header here
+  Ipv4Header ipHeader = BuildHeader (source, destination, protocol, packet->GetSize (), ttl, tos, mayFragment);
 
-  // 1) packet is destined to limited broadcast address or link-local multicast address
+  // Handle a few cases:
+  // 1) packet is passed in with a route entry
+  // 1a) packet is passed in with a route entry but route->GetGateway is not set (e.g., on-demand)
+  // 1b) packet is passed in with a route entry and valid gateway
+  // 2) packet is passed without a route and packet is destined to limited broadcast address
+  // 3) packet is passed without a route and packet is destined to a subnet-directed broadcast address
+  // 4) packet is passed without a route, packet is not broadcast (e.g., a raw socket call, or ICMP)
+
+  // 1) packet is passed in with route entry
+  if (route)
+    {
+      // 1a) route->GetGateway is not set (e.g., on-demand)
+      if (!route->GetGateway ().IsInitialized ())
+        {
+          // This could arise because the synchronous RouteOutput() call
+          // returned to the transport protocol with a source address but
+          // there was no next hop available yet (since a route may need
+          // to be queried).
+          NS_FATAL_ERROR ("Ipv4L3Protocol::Send case 1a: packet passed with a route but the Gateway address is uninitialized. This case not yet implemented.");
+        }
+
+      // 1b) with a valid gateway
+      NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 1b:  passed in with route and valid gateway");
+      int32_t interface = GetInterfaceForDevice (route->GetOutputDevice ());
+      m_sendOutgoingTrace (ipHeader, packet, interface);
+      SendRealOut (route, packet->Copy (), ipHeader);
+      return; 
+    }
+
+  // 2) packet is destined to limited broadcast address or link-local multicast address
   if (destination.IsBroadcast () || destination.IsLocalMulticast ())
     {
-      NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 1:  limited broadcast");
-      ipHeader = BuildHeader (source, destination, protocol, packet->GetSize (), ttl, tos, mayFragment);
+      NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 2:  limited broadcast - no route");
       uint32_t ifaceIndex = 0;
       for (Ipv4InterfaceList::iterator ifaceIter = m_interfaces.begin ();
            ifaceIter != m_interfaces.end (); ifaceIter++, ifaceIndex++)
         {
           Ptr<Ipv4Interface> outInterface = *ifaceIter;
-          bool sendIt = false;
-          if (source == Ipv4Address::GetAny ())
-            {
-              sendIt = true;
-            }
-          for (uint32_t index = 0; index < outInterface->GetNAddresses (); index++)
+          // ANY source matches any interface
+          bool sendIt = source.IsAny ();
+          // check if some specific address on outInterface matches
+          for (uint32_t index = 0; !sendIt && index < outInterface->GetNAddresses (); index++)
             {
               if (outInterface->GetAddress (index).GetLocal () == source)
                 {
                   sendIt = true;
                 }
             }
+
           if (sendIt)
             {
-              Ptr<Packet> packetCopy = packet->Copy ();
-
-              NS_ASSERT (packetCopy->GetSize () <= outInterface->GetDevice ()->GetMtu ());
-
-              m_sendOutgoingTrace (ipHeader, packetCopy, ifaceIndex);
-              CallTxTrace (ipHeader, packetCopy, m_node->GetObject<Ipv4> (), ifaceIndex);
-              outInterface->Send (packetCopy, ipHeader, destination);
+              // create a proxy route for this interface
+              Ptr<Ipv4Route> route = Create<Ipv4Route> ();
+              route->SetDestination (destination);
+              route->SetGateway (Ipv4Address::GetAny ());
+              route->SetSource (source);
+              route->SetOutputDevice (outInterface->GetDevice ());
+              DecreaseIdentification (source, destination, protocol);
+              Send (pktCopyWithTags, source, destination, protocol, route);
             }
         }
       return;
     }
 
-  // 2) check: packet is destined to a subnet-directed broadcast address
-  uint32_t ifaceIndex = 0;
+  // 3) check: packet is destined to a subnet-directed broadcast address
   for (Ipv4InterfaceList::iterator ifaceIter = m_interfaces.begin ();
-       ifaceIter != m_interfaces.end (); ifaceIter++, ifaceIndex++)
+       ifaceIter != m_interfaces.end (); ifaceIter++)
     {
       Ptr<Ipv4Interface> outInterface = *ifaceIter;
+      uint32_t ifaceIndex = GetInterfaceForDevice (outInterface->GetDevice ());
       for (uint32_t j = 0; j < GetNAddresses (ifaceIndex); j++)
         {
           Ipv4InterfaceAddress ifAddr = GetAddress (ifaceIndex, j);
@@ -798,42 +856,24 @@ Ipv4L3Protocol::Send (Ptr<Packet> packet,
           if (destination.IsSubnetDirectedBroadcast (ifAddr.GetMask ()) && 
               destination.CombineMask (ifAddr.GetMask ()) == ifAddr.GetLocal ().CombineMask (ifAddr.GetMask ())   )
             {
-              NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 2:  subnet directed bcast to " << ifAddr.GetLocal ());
-              ipHeader = BuildHeader (source, destination, protocol, packet->GetSize (), ttl, tos, mayFragment);
-              Ptr<Packet> packetCopy = packet->Copy ();
-              m_sendOutgoingTrace (ipHeader, packetCopy, ifaceIndex);
-              CallTxTrace (ipHeader, packetCopy, m_node->GetObject<Ipv4> (), ifaceIndex);
-              outInterface->Send (packetCopy, ipHeader, destination);
+              NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 3:  subnet directed bcast to " << ifAddr.GetLocal () << " - no route");
+              // create a proxy route for this interface
+              Ptr<Ipv4Route> route = Create<Ipv4Route> ();
+              route->SetDestination (destination);
+              route->SetGateway (Ipv4Address::GetAny ());
+              route->SetSource (source);
+              route->SetOutputDevice (outInterface->GetDevice ());
+              DecreaseIdentification (source, destination, protocol);
+              Send (pktCopyWithTags, source, destination, protocol, route);
               return;
             }
         }
     }
 
-  // 3) packet is not broadcast, and is passed in with a route entry
-  //    with a valid Ipv4Address as the gateway
-  if (route && route->GetGateway () != Ipv4Address ())
-    {
-      NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 3:  passed in with route");
-      ipHeader = BuildHeader (source, destination, protocol, packet->GetSize (), ttl, tos, mayFragment);
-      int32_t interface = GetInterfaceForDevice (route->GetOutputDevice ());
-      m_sendOutgoingTrace (ipHeader, packet, interface);
-      SendRealOut (route, packet->Copy (), ipHeader);
-      return; 
-    } 
-  // 4) packet is not broadcast, and is passed in with a route entry but route->GetGateway is not set (e.g., on-demand)
-  if (route && route->GetGateway () == Ipv4Address ())
-    {
-      // This could arise because the synchronous RouteOutput() call
-      // returned to the transport protocol with a source address but
-      // there was no next hop available yet (since a route may need
-      // to be queried).
-      NS_FATAL_ERROR ("Ipv4L3Protocol::Send case 4: This case not yet implemented");
-    }
-  // 5) packet is not broadcast, and route is NULL (e.g., a raw socket call)
-  NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 5:  passed in with no route " << destination);
+  // 4) packet is not broadcast, and route is NULL (e.g., a raw socket call)
+  NS_LOG_LOGIC ("Ipv4L3Protocol::Send case 4:  not broadcast and passed in with no route " << destination);
   Socket::SocketErrno errno_; 
   Ptr<NetDevice> oif (0); // unused for now
-  ipHeader = BuildHeader (source, destination, protocol, packet->GetSize (), ttl, tos, mayFragment);
   Ptr<Ipv4Route> newRoute;
   if (m_routingProtocol != 0)
     {
@@ -845,20 +885,29 @@ Ipv4L3Protocol::Send (Ptr<Packet> packet,
     }
   if (newRoute)
     {
-      int32_t interface = GetInterfaceForDevice (newRoute->GetOutputDevice ());
-      m_sendOutgoingTrace (ipHeader, packet, interface);
-      SendRealOut (newRoute, packet->Copy (), ipHeader);
+      DecreaseIdentification (source, destination, protocol);
+      Send (pktCopyWithTags, source, destination, protocol, newRoute);
     }
   else
     {
       NS_LOG_WARN ("No route to host.  Drop.");
       m_dropTrace (ipHeader, packet, DROP_NO_ROUTE, m_node->GetObject<Ipv4> (), 0);
+      DecreaseIdentification (source, destination, protocol);
     }
 }
 
-// \todo when should we set ip_id?   check whether we are incrementing
-// m_identification on packets that may later be dropped in this stack
-// and whether that deviates from Linux
+void
+Ipv4L3Protocol::DecreaseIdentification (Ipv4Address source,
+                                        Ipv4Address destination,
+                                        uint8_t protocol)
+{
+  uint64_t src = source.Get ();
+  uint64_t dst = destination.Get ();
+  uint64_t srcDst = dst | (src << 32);
+  std::pair<uint64_t, uint8_t> key = std::make_pair (srcDst, protocol);
+  m_identification[key]--;
+}
+
 Ipv4Header
 Ipv4L3Protocol::BuildHeader (
   Ipv4Address source,
@@ -924,59 +973,37 @@ Ipv4L3Protocol::SendRealOut (Ptr<Ipv4Route> route,
   Ptr<Ipv4Interface> outInterface = GetInterface (interface);
   NS_LOG_LOGIC ("Send via NetDevice ifIndex " << outDev->GetIfIndex () << " ipv4InterfaceIndex " << interface);
 
-  if (!route->GetGateway ().IsEqual (Ipv4Address ("0.0.0.0")))
+  Ipv4Address target;
+  std::string targetLabel;
+  if (route->GetGateway ().IsAny ())
     {
-      if (outInterface->IsUp ())
+      target = ipHeader.GetDestination ();
+      targetLabel = "destination";
+    }
+  else
+    {
+      target = route->GetGateway ();
+      targetLabel = "gateway";
+    }
+
+  if (outInterface->IsUp ())
+    {
+      NS_LOG_LOGIC ("Send to " << targetLabel << " " << target);
+      if ( packet->GetSize () + ipHeader.GetSerializedSize () > outInterface->GetDevice ()->GetMtu () )
         {
-          NS_LOG_LOGIC ("Send to gateway " << route->GetGateway ());
-          if ( packet->GetSize () + ipHeader.GetSerializedSize () > outInterface->GetDevice ()->GetMtu () )
+          std::list<Ipv4PayloadHeaderPair> listFragments;
+          DoFragmentation (packet, ipHeader, outInterface->GetDevice ()->GetMtu (), listFragments);
+          for ( std::list<Ipv4PayloadHeaderPair>::iterator it = listFragments.begin (); it != listFragments.end (); it++ )
             {
-              std::list<Ipv4PayloadHeaderPair> listFragments;
-              DoFragmentation (packet, ipHeader, outInterface->GetDevice ()->GetMtu (), listFragments);
-              for ( std::list<Ipv4PayloadHeaderPair>::iterator it = listFragments.begin (); it != listFragments.end (); it++ )
-                {
-                  CallTxTrace (it->second, it->first, m_node->GetObject<Ipv4> (), interface);
-                  outInterface->Send (it->first, it->second, route->GetGateway ());
-                }
-            }
-          else
-            {
-              CallTxTrace (ipHeader, packet, m_node->GetObject<Ipv4> (), interface);
-              outInterface->Send (packet, ipHeader, route->GetGateway ());
+              NS_LOG_LOGIC ("Sending fragment " << *(it->first) );
+              CallTxTrace (it->second, it->first, m_node->GetObject<Ipv4> (), interface);
+              outInterface->Send (it->first, it->second, target);
             }
         }
       else
         {
-          NS_LOG_LOGIC ("Dropping -- outgoing interface is down: " << route->GetGateway ());
-          m_dropTrace (ipHeader, packet, DROP_INTERFACE_DOWN, m_node->GetObject<Ipv4> (), interface);
-        }
-    } 
-  else 
-    {
-      if (outInterface->IsUp ())
-        {
-          NS_LOG_LOGIC ("Send to destination " << ipHeader.GetDestination ());
-          if ( packet->GetSize () + ipHeader.GetSerializedSize () > outInterface->GetDevice ()->GetMtu () )
-            {
-              std::list<Ipv4PayloadHeaderPair> listFragments;
-              DoFragmentation (packet, ipHeader, outInterface->GetDevice ()->GetMtu (), listFragments);
-              for ( std::list<Ipv4PayloadHeaderPair>::iterator it = listFragments.begin (); it != listFragments.end (); it++ )
-                {
-                  NS_LOG_LOGIC ("Sending fragment " << *(it->first) );
-                  CallTxTrace (it->second, it->first, m_node->GetObject<Ipv4> (), interface);
-                  outInterface->Send (it->first, it->second, ipHeader.GetDestination ());
-                }
-            }
-          else
-            {
-              CallTxTrace (ipHeader, packet, m_node->GetObject<Ipv4> (), interface);
-              outInterface->Send (packet, ipHeader, ipHeader.GetDestination ());
-            }
-        }
-      else
-        {
-          NS_LOG_LOGIC ("Dropping -- outgoing interface is down: " << ipHeader.GetDestination ());
-          m_dropTrace (ipHeader, packet, DROP_INTERFACE_DOWN, m_node->GetObject<Ipv4> (), interface);
+          CallTxTrace (ipHeader, packet, m_node->GetObject<Ipv4> (), interface);
+          outInterface->Send (packet, ipHeader, target);
         }
     }
 }
@@ -993,25 +1020,27 @@ Ipv4L3Protocol::IpMulticastForward (Ptr<Ipv4MulticastRoute> mrtentry, Ptr<const
 
   for (mapIter = ttlMap.begin (); mapIter != ttlMap.end (); mapIter++)
     {
-      uint32_t interfaceId = mapIter->first;
+      uint32_t interface = mapIter->first;
       //uint32_t outputTtl = mapIter->second;  // Unused for now
 
       Ptr<Packet> packet = p->Copy ();
-      Ipv4Header h = header;
-      h.SetTtl (header.GetTtl () - 1);
-      if (h.GetTtl () == 0)
+      Ipv4Header ipHeader = header;
+      ipHeader.SetTtl (header.GetTtl () - 1);
+      if (ipHeader.GetTtl () == 0)
         {
           NS_LOG_WARN ("TTL exceeded.  Drop.");
-          m_dropTrace (header, packet, DROP_TTL_EXPIRED, m_node->GetObject<Ipv4> (), interfaceId);
+          m_dropTrace (header, packet, DROP_TTL_EXPIRED, m_node->GetObject<Ipv4> (), interface);
           return;
         }
-      NS_LOG_LOGIC ("Forward multicast via interface " << interfaceId);
+      NS_LOG_LOGIC ("Forward multicast via interface " << interface);
       Ptr<Ipv4Route> rtentry = Create<Ipv4Route> ();
-      rtentry->SetSource (h.GetSource ());
-      rtentry->SetDestination (h.GetDestination ());
+      rtentry->SetSource (ipHeader.GetSource ());
+      rtentry->SetDestination (ipHeader.GetDestination ());
       rtentry->SetGateway (Ipv4Address::GetAny ());
-      rtentry->SetOutputDevice (GetNetDevice (interfaceId));
-      SendRealOut (rtentry, packet, h);
+      rtentry->SetOutputDevice (GetNetDevice (interface));
+      
+      m_multicastForwardTrace (ipHeader, packet, interface);
+      SendRealOut (rtentry, packet, ipHeader);
       continue;
     }
 }
@@ -1029,9 +1058,8 @@ Ipv4L3Protocol::IpForward (Ptr<Ipv4Route> rtentry, Ptr<const Packet> p, const Ip
   ipHeader.SetTtl (ipHeader.GetTtl () - 1);
   if (ipHeader.GetTtl () == 0)
     {
-      // Do not reply to ICMP or to multicast/broadcast IP address 
-      if (ipHeader.GetProtocol () != Icmpv4L4Protocol::PROT_NUMBER && 
-          ipHeader.GetDestination ().IsBroadcast () == false &&
+      // Do not reply to multicast/broadcast IP address
+      if (ipHeader.GetDestination ().IsBroadcast () == false &&
           ipHeader.GetDestination ().IsMulticast () == false)
         {
           Ptr<Icmpv4L4Protocol> icmp = GetIcmp ();
@@ -1478,7 +1506,7 @@ Ipv4L3Protocol::DoFragmentation (Ptr<Packet> packet, const Ipv4Header & ipv4Head
 
       NS_LOG_LOGIC ("New fragment " << *fragment);
 
-      listFragments.push_back (Ipv4PayloadHeaderPair (fragment, fragmentHeader));
+      listFragments.emplace_back (fragment, fragmentHeader);
 
       offset += currentFragmentablePartSize;
 
@@ -1495,7 +1523,7 @@ Ipv4L3Protocol::ProcessFragment (Ptr<Packet>& packet, Ipv4Header& ipHeader, uint
 
   uint64_t addressCombination = uint64_t (ipHeader.GetSource ().Get ()) << 32 | uint64_t (ipHeader.GetDestination ().Get ());
   uint32_t idProto = uint32_t (ipHeader.GetIdentification ()) << 16 | uint32_t (ipHeader.GetProtocol ());
-  std::pair<uint64_t, uint32_t> key;
+  FragmentKey_t key;
   bool ret = false;
   Ptr<Packet> p = packet->Copy ();
 
@@ -1509,9 +1537,9 @@ Ipv4L3Protocol::ProcessFragment (Ptr<Packet>& packet, Ipv4Header& ipHeader, uint
     {
       fragments = Create<Fragments> ();
       m_fragments.insert (std::make_pair (key, fragments));
-      m_fragmentsTimers[key] = Simulator::Schedule (m_fragmentExpirationTimeout,
-                                                    &Ipv4L3Protocol::HandleFragmentsTimeout, this,
-                                                    key, ipHeader, iif);
+
+      FragmentsTimeoutsListI_t iter = SetTimeout (key, ipHeader, iif);
+      fragments->SetTimeoutIter (iter);
     }
   else
     {
@@ -1525,14 +1553,9 @@ Ipv4L3Protocol::ProcessFragment (Ptr<Packet>& packet, Ipv4Header& ipHeader, uint
   if ( fragments->IsEntire () )
     {
       packet = fragments->GetPacket ();
+      m_timeoutEventList.erase (fragments->GetTimeoutIter ());
       fragments = 0;
       m_fragments.erase (key);
-      if (m_fragmentsTimers[key].IsRunning ())
-        {
-          NS_LOG_LOGIC ("Stopping WaitFragmentsTimer at " << Simulator::Now ().GetSeconds () << " due to complete packet");
-          m_fragmentsTimers[key].Cancel ();
-        }
-      m_fragmentsTimers.erase (key);
       ret = true;
     }
 
@@ -1677,7 +1700,21 @@ Ipv4L3Protocol::Fragments::GetPartialPacket () const
 }
 
 void
-Ipv4L3Protocol::HandleFragmentsTimeout (std::pair<uint64_t, uint32_t> key, Ipv4Header & ipHeader, uint32_t iif)
+Ipv4L3Protocol::Fragments::SetTimeoutIter (FragmentsTimeoutsListI_t iter)
+{
+  m_timeoutIter = iter;
+  return;
+}
+
+Ipv4L3Protocol::FragmentsTimeoutsListI_t
+Ipv4L3Protocol::Fragments::GetTimeoutIter ()
+{
+  return m_timeoutIter;
+}
+
+
+void
+Ipv4L3Protocol::HandleFragmentsTimeout (FragmentKey_t key, Ipv4Header & ipHeader, uint32_t iif)
 {
   NS_LOG_FUNCTION (this << &key << &ipHeader << iif);
 
@@ -1696,6 +1733,152 @@ Ipv4L3Protocol::HandleFragmentsTimeout (std::pair<uint64_t, uint32_t> key, Ipv4H
   it->second = 0;
 
   m_fragments.erase (key);
-  m_fragmentsTimers.erase (key);
 }
+
+bool
+Ipv4L3Protocol::UpdateDuplicate (Ptr<const Packet> p, const Ipv4Header &header)
+{
+  NS_LOG_FUNCTION (this << p << header);
+
+  // \todo RFC 6621 mandates SHA-1 hash.  For now ns3 hash should be fine.
+  uint8_t proto = header.GetProtocol ();
+  Ipv4Address src = header.GetSource ();
+  Ipv4Address dst = header.GetDestination ();
+  uint64_t id = header.GetIdentification ();
+
+  // concat hash value onto id
+  uint64_t hash = id << 32;
+  if (header.GetFragmentOffset () || !header.IsLastFragment ())
+    {
+      // use I-DPD (RFC 6621, Sec 6.2.1)
+      hash |= header.GetFragmentOffset ();
+    }
+  else
+    {
+      // use H-DPD (RFC 6621, Sec 6.2.2)
+
+      // serialize packet
+      Ptr<Packet> pkt = p->Copy ();
+      pkt->AddHeader (header);
+
+      std::ostringstream oss (std::ios_base::binary);
+      pkt->CopyData (&oss, pkt->GetSize ());
+      std::string bytes = oss.str ();
+
+      NS_ASSERT_MSG (bytes.size () >= 20, "Degenerate header serialization");
+
+      // zero out mutable fields
+      bytes[1] = 0;               // DSCP / ECN
+      bytes[6] = bytes[7] = 0;    // Flags / Fragment offset
+      bytes[8] = 0;               // TTL
+      bytes[10] = bytes[11] = 0;  // Header checksum
+      if (header.GetSerializedSize () > 20)     // assume options should be 0'd
+        {
+          std::fill_n (bytes.begin () + 20, header.GetSerializedSize () - 20, 0);
+        }
+        
+      // concat hash onto ID
+      hash |= (uint64_t)Hash32 (bytes);
+    }
+
+  // set cleanup job for new duplicate entries
+  if (!m_cleanDpd.IsRunning () && m_purge.IsStrictlyPositive ())
+    {
+      m_cleanDpd = Simulator::Schedule (m_expire, &Ipv4L3Protocol::RemoveDuplicates, this);
+    }
+
+  // assume this is a new entry
+  DupTuple_t key {hash, proto, src, dst};
+  NS_LOG_DEBUG ("Packet " << p->GetUid () << " key = (" <<
+                std::hex << std::get<0> (key) << ", " <<
+                std::dec << +std::get<1> (key) << ", " <<
+                std::get<2> (key) << ", " <<
+                std::get<3> (key) << ")");
+
+  // place a new entry, on collision the existing entry iterator is returned
+  DupMap_t::iterator iter;
+  bool inserted, isDup;
+  std::tie (iter, inserted) = m_dups.emplace (key, Seconds (0));
+  isDup = !inserted && iter->second > Simulator::Now ();
+
+  // set the expiration event
+  iter->second = Simulator::Now () + m_expire;
+  return isDup;
+}
+
+void
+Ipv4L3Protocol::RemoveDuplicates (void)
+{
+  NS_LOG_FUNCTION (this);
+
+  DupMap_t::size_type n = 0;
+  Time expire = Simulator::Now ();
+  auto iter = m_dups.cbegin ();
+  while (iter != m_dups.cend ())
+    {
+      if (iter->second < expire)
+        {
+          NS_LOG_LOGIC ("Remove key = (" <<
+                        std::hex << std::get<0> (iter->first) << ", " <<
+                        std::dec << +std::get<1> (iter->first) << ", " <<
+                        std::get<2> (iter->first) << ", " <<
+                        std::get<3> (iter->first) << ")");
+          iter = m_dups.erase (iter);
+          ++n;
+        }
+      else
+        {
+          ++iter;
+        }
+    }
+  
+  NS_LOG_DEBUG ("Purged " << n << " expired duplicate entries out of " << (n + m_dups.size ()));
+  
+  // keep cleaning up if necessary
+  if (!m_dups.empty () && m_purge.IsStrictlyPositive ())
+    {
+      m_cleanDpd = Simulator::Schedule (m_purge, &Ipv4L3Protocol::RemoveDuplicates, this);
+    }
+}
+
+Ipv4L3Protocol::FragmentsTimeoutsListI_t
+Ipv4L3Protocol::SetTimeout (FragmentKey_t key, Ipv4Header ipHeader, uint32_t iif)
+{
+  Time now = Simulator::Now () + m_fragmentExpirationTimeout;
+
+  if (m_timeoutEventList.empty ())
+    {
+      m_timeoutEvent = Simulator::Schedule (m_fragmentExpirationTimeout, &Ipv4L3Protocol::HandleTimeout, this);
+    }
+  m_timeoutEventList.emplace_back (now, key, ipHeader, iif);
+
+  Ipv4L3Protocol::FragmentsTimeoutsListI_t iter = --m_timeoutEventList.end();
+
+  return (iter);
+}
+
+void
+Ipv4L3Protocol::HandleTimeout (void)
+{
+  Time now = Simulator::Now ();
+
+  while (!m_timeoutEventList.empty () && std::get<0> (*m_timeoutEventList.begin ()) == now)
+    {
+      HandleFragmentsTimeout (std::get<1> (*m_timeoutEventList.begin ()),
+                              std::get<2> (*m_timeoutEventList.begin ()),
+                              std::get<3> (*m_timeoutEventList.begin ()));
+      m_timeoutEventList.pop_front ();
+    }
+
+  if (m_timeoutEventList.empty ())
+    {
+      return;
+    }
+
+  Time difference = std::get<0> (*m_timeoutEventList.begin ()) - now;
+  m_timeoutEvent = Simulator::Schedule (difference, &Ipv4L3Protocol::HandleTimeout, this);
+
+  return;
+}
+
 } // namespace ns3
