@@ -22,6 +22,7 @@
 #include <list>
 #include "ns3/ipv4-routing-protocol.h"
 #include "ns3/simulator.h"
+#include "ns3/nstime.h"
 
 namespace ns3 {
 
@@ -88,7 +89,7 @@ public:
   virtual void NotifyAddAddress (uint32_t interface, Ipv4InterfaceAddress address);
   virtual void NotifyRemoveAddress (uint32_t interface, Ipv4InterfaceAddress address);
   virtual void SetIpv4 (Ptr<Ipv4> ipv4);
-  virtual void PrintRoutingTable (Ptr<OutputStreamWrapper> stream) const;
+  virtual void PrintRoutingTable (Ptr<OutputStreamWrapper> stream, Time::Unit unit = Time::S) const;
 
 protected:
   virtual void DoDispose (void);
