@@ -44,6 +44,7 @@
 #include "ipv6-option.h"
 #include "icmpv6-l4-protocol.h"
 #include "ndisc-cache.h"
+#include "ipv6-raw-socket-factory-impl.h"
 
 /// Minimum IPv6 MTU, as defined by \RFC{2460}
 #define IPV6_MIN_MTU 1280
@@ -125,18 +126,21 @@ TypeId Ipv6L3Protocol::GetTypeId ()
 Ipv6L3Protocol::Ipv6L3Protocol ()
   : m_nInterfaces (0)
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   m_pmtuCache = CreateObject<Ipv6PmtuCache> ();
+  
+  Ptr<Ipv6RawSocketFactoryImpl> rawFactoryImpl = CreateObject<Ipv6RawSocketFactoryImpl> ();
+  AggregateObject (rawFactoryImpl);
 }
 
 Ipv6L3Protocol::~Ipv6L3Protocol ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 }
 
 void Ipv6L3Protocol::DoDispose ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 
   /* clear protocol and interface list */
   for (L4List_t::iterator it = m_protocols.begin (); it != m_protocols.end (); ++it)
@@ -184,7 +188,7 @@ void Ipv6L3Protocol::SetRoutingProtocol (Ptr<Ipv6RoutingProtocol> routingProtoco
 
 Ptr<Ipv6RoutingProtocol> Ipv6L3Protocol::GetRoutingProtocol () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_routingProtocol;
 }
 
@@ -234,7 +238,7 @@ Ptr<Ipv6Interface> Ipv6L3Protocol::GetInterface (uint32_t index) const
 
 uint32_t Ipv6L3Protocol::GetNInterfaces () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_nInterfaces;
 }
 
@@ -308,24 +312,7 @@ void Ipv6L3Protocol::AddAutoconfiguredAddress (uint32_t interface, Ipv6Address n
 
   if (flags & (1 << 6)) /* auto flag */
     {
-      // In case of new MacAddress types, remember to change Ipv6L3Protocol::RemoveAutoconfiguredAddress as well
-      if (Mac64Address::IsMatchingType (addr))
-        {
-          address = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredAddress (Mac64Address::ConvertFrom (addr), network));
-        }
-      else if (Mac48Address::IsMatchingType (addr))
-        {
-          address = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredAddress (Mac48Address::ConvertFrom (addr), network));
-        }
-      else if (Mac16Address::IsMatchingType (addr))
-        {
-          address = Ipv6InterfaceAddress (Ipv6Address::MakeAutoconfiguredAddress (Mac16Address::ConvertFrom (addr), network));
-        }
-      else
-        {
-          NS_FATAL_ERROR ("Unknown method to make autoconfigured address for this kind of device.");
-          return;
-        }
+      address = Ipv6Address::MakeAutoconfiguredAddress (addr, network);
 
       /* see if we have already the prefix */
       for (Ipv6AutoconfiguredPrefixListI it = m_prefixes.begin (); it != m_prefixes.end (); ++it)
@@ -363,37 +350,18 @@ void Ipv6L3Protocol::RemoveAutoconfiguredAddress (uint32_t interface, Ipv6Addres
   NS_LOG_FUNCTION (this << interface << network << mask);
   Ptr<Ipv6Interface> iface = GetInterface (interface);
   Address addr = iface->GetDevice ()->GetAddress ();
-  uint32_t max = iface->GetNAddresses ();
-  uint32_t i = 0;
-  Ipv6Address toFound;
+  
+  Ipv6Address addressToFind = Ipv6Address::MakeAutoconfiguredAddress (addr, network);
 
-  if (Mac64Address::IsMatchingType (addr))
+  for (uint32_t i = 0; i < iface->GetNAddresses (); i++)
     {
-      toFound = Ipv6Address::MakeAutoconfiguredAddress (Mac64Address::ConvertFrom (addr), network);
-    }
-  else if (Mac48Address::IsMatchingType (addr))
-    {
-      toFound = Ipv6Address::MakeAutoconfiguredAddress (Mac48Address::ConvertFrom (addr), network);
-    }
-  else if (Mac16Address::IsMatchingType (addr))
-    {
-      toFound = Ipv6Address::MakeAutoconfiguredAddress (Mac16Address::ConvertFrom (addr), network);
-    }
-  else
-    {
-      NS_FATAL_ERROR ("Unknown method to make autoconfigured address for this kind of device.");
-      return;
-    }
-
-  for (i = 0; i < max; i++)
-    {
-      if (iface->GetAddress (i).GetAddress () == toFound)
+      if (iface->GetAddress (i).GetAddress () == addressToFind)
         {
           RemoveAddress (interface, i);
           break;
         }
     }
-
+  
   /* remove from list of autoconfigured address */
   for (Ipv6AutoconfiguredPrefixListI it = m_prefixes.begin (); it != m_prefixes.end (); ++it)
     {
@@ -557,7 +525,7 @@ void Ipv6L3Protocol::SetDown (uint32_t i)
 
 void Ipv6L3Protocol::SetupLoopback ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   Ptr<Ipv6Interface> interface = CreateObject<Ipv6Interface> ();
   Ptr<LoopbackNetDevice> device = 0;
   uint32_t i = 0;
@@ -660,7 +628,7 @@ void Ipv6L3Protocol::SetIpForward (bool forward)
 
 bool Ipv6L3Protocol::GetIpForward () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_ipForward;
 }
 
@@ -684,13 +652,13 @@ void Ipv6L3Protocol::SetSendIcmpv6Redirect (bool sendIcmpv6Redirect)
 
 bool Ipv6L3Protocol::GetSendIcmpv6Redirect () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   return m_sendIcmpv6Redirect;
 }
 
 void Ipv6L3Protocol::NotifyNewAggregate ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
 
   if (m_node == 0)
     {
@@ -702,6 +670,7 @@ void Ipv6L3Protocol::NotifyNewAggregate ()
           this->SetNode (node);
         }
     }
+  
   Ipv6::NotifyNewAggregate ();
 }
 
@@ -804,7 +773,7 @@ Ptr<IpL4Protocol> Ipv6L3Protocol::GetProtocol (int protocolNumber, int32_t inter
 
 Ptr<Socket> Ipv6L3Protocol::CreateRawSocket ()
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   Ptr<Ipv6RawSocketImpl> sock = CreateObject<Ipv6RawSocketImpl> ();
   sock->SetNode (m_node);
   m_sockets.push_back (sock);
@@ -827,7 +796,7 @@ void Ipv6L3Protocol::DeleteRawSocket (Ptr<Socket> socket)
 
 Ptr<Icmpv6L4Protocol> Ipv6L3Protocol::GetIcmpv6 () const
 {
-  NS_LOG_FUNCTION_NOARGS ();
+  NS_LOG_FUNCTION (this);
   Ptr<IpL4Protocol> protocol = GetProtocol (Icmpv6L4Protocol::GetStaticProtocolNumber ());
 
   if (protocol)
@@ -1059,7 +1028,7 @@ void Ipv6L3Protocol::Receive (Ptr<NetDevice> device, Ptr<const Packet> p, uint16
             {
               Ipv6InterfaceAddress iaddr = GetAddress (j, i);
               Ipv6Address addr = iaddr.GetAddress ();
-              if (addr.IsEqual (hdr.GetDestinationAddress ()))
+              if (addr == hdr.GetDestinationAddress ())
                 {
                   if (j == interface)
                     {
@@ -1159,7 +1128,7 @@ void Ipv6L3Protocol::SendRealOut (Ptr<Ipv6Route> route, Ptr<Packet> packet, Ipv6
       ipv6Fragment->GetFragments (packet, ipHeader, targetMtu, fragments);
     }
 
-  if (!route->GetGateway ().IsEqual (Ipv6Address::GetAny ()))
+  if (route->GetGateway () != Ipv6Address::GetAny ())
     {
       if (outInterface->IsUp ())
         {
