@@ -141,9 +141,10 @@ void RipNg::DoInitialize ()
               socket->BindToNetDevice (m_ipv6->GetNetDevice (i));
               int ret = socket->Bind (local);
               NS_ASSERT_MSG (ret == 0, "Bind unsuccessful");
-              socket->ShutdownRecv ();
+              socket->SetRecvCallback (MakeCallback (&RipNg::Receive, this));
               socket->SetIpv6RecvHopLimit (true);
-              m_sendSocketList[socket] = i;
+              socket->SetRecvPktInfo (true);
+              m_unicastSocketList[socket] = i;
             }
           else if (m_ipv6->GetAddress (i, j).GetScope() == Ipv6InterfaceAddress::GLOBAL)
             {
@@ -152,17 +153,17 @@ void RipNg::DoInitialize ()
         }
     }
 
-  if (!m_recvSocket)
+  if (!m_multicastRecvSocket)
     {
       NS_LOG_LOGIC ("RIPng: adding receiving socket");
       TypeId tid = TypeId::LookupByName ("ns3::UdpSocketFactory");
       Ptr<Node> theNode = GetObject<Node> ();
-      m_recvSocket = Socket::CreateSocket (theNode, tid);
+      m_multicastRecvSocket = Socket::CreateSocket (theNode, tid);
       Inet6SocketAddress local = Inet6SocketAddress (RIPNG_ALL_NODE, RIPNG_PORT);
-      m_recvSocket->Bind (local);
-      m_recvSocket->SetRecvCallback (MakeCallback (&RipNg::Receive, this));
-      m_recvSocket->SetIpv6RecvHopLimit (true);
-      m_recvSocket->SetRecvPktInfo (true);
+      m_multicastRecvSocket->Bind (local);
+      m_multicastRecvSocket->SetRecvCallback (MakeCallback (&RipNg::Receive, this));
+      m_multicastRecvSocket->SetIpv6RecvHopLimit (true);
+      m_multicastRecvSocket->SetRecvPktInfo (true);
     }
 
 
@@ -287,7 +288,7 @@ void RipNg::NotifyInterfaceUp (uint32_t i)
 
 
   bool sendSocketFound = false;
-  for (SocketListI iter = m_sendSocketList.begin (); iter != m_sendSocketList.end (); iter++ )
+  for (SocketListI iter = m_unicastSocketList.begin (); iter != m_unicastSocketList.end (); iter++ )
     {
       if (iter->second == i)
         {
@@ -316,9 +317,10 @@ void RipNg::NotifyInterfaceUp (uint32_t i)
           Inet6SocketAddress local = Inet6SocketAddress (address.GetAddress (), RIPNG_PORT);
           socket->BindToNetDevice (m_ipv6->GetNetDevice (i));
           socket->Bind (local);
-          socket->ShutdownRecv ();
+          socket->SetRecvCallback (MakeCallback (&RipNg::Receive, this));
           socket->SetIpv6RecvHopLimit (true);
-          m_sendSocketList[socket] = i;
+          socket->SetRecvPktInfo (true);
+          m_unicastSocketList[socket] = i;
         }
       else if (address.GetScope() == Ipv6InterfaceAddress::GLOBAL)
         {
@@ -326,17 +328,17 @@ void RipNg::NotifyInterfaceUp (uint32_t i)
         }
     }
 
-  if (!m_recvSocket)
+  if (!m_multicastRecvSocket)
     {
       NS_LOG_LOGIC ("RIPng: adding receiving socket");
       TypeId tid = TypeId::LookupByName ("ns3::UdpSocketFactory");
       Ptr<Node> theNode = GetObject<Node> ();
-      m_recvSocket = Socket::CreateSocket (theNode, tid);
+      m_multicastRecvSocket = Socket::CreateSocket (theNode, tid);
       Inet6SocketAddress local = Inet6SocketAddress (RIPNG_ALL_NODE, RIPNG_PORT);
-      m_recvSocket->Bind (local);
-      m_recvSocket->SetRecvCallback (MakeCallback (&RipNg::Receive, this));
-      m_recvSocket->SetIpv6RecvHopLimit (true);
-      m_recvSocket->SetRecvPktInfo (true);
+      m_multicastRecvSocket->Bind (local);
+      m_multicastRecvSocket->SetRecvCallback (MakeCallback (&RipNg::Receive, this));
+      m_multicastRecvSocket->SetIpv6RecvHopLimit (true);
+      m_multicastRecvSocket->SetRecvPktInfo (true);
     }
 }
 
@@ -353,14 +355,14 @@ void RipNg::NotifyInterfaceDown (uint32_t interface)
         }
     }
 
-  for (SocketListI iter = m_sendSocketList.begin (); iter != m_sendSocketList.end (); iter++ )
+  for (SocketListI iter = m_unicastSocketList.begin (); iter != m_unicastSocketList.end (); iter++ )
     {
       NS_LOG_INFO ("Checking socket for interface " << interface);
       if (iter->second == interface)
         {
           NS_LOG_INFO ("Removed socket for interface " << interface);
           iter->first->Close ();
-          m_sendSocketList.erase (iter);
+          m_unicastSocketList.erase (iter);
           break;
         }
     }
@@ -538,14 +540,14 @@ void RipNg::DoDispose ()
   m_nextTriggeredUpdate = EventId ();
   m_nextUnsolicitedUpdate = EventId ();
 
-  for (SocketListI iter = m_sendSocketList.begin (); iter != m_sendSocketList.end (); iter++ )
+  for (SocketListI iter = m_unicastSocketList.begin (); iter != m_unicastSocketList.end (); iter++ )
     {
       iter->first->Close ();
     }
-  m_sendSocketList.clear ();
+  m_unicastSocketList.clear ();
 
-  m_recvSocket->Close ();
-  m_recvSocket = 0;
+  m_multicastRecvSocket->Close ();
+  m_multicastRecvSocket = 0;
 
   m_ipv6 = 0;
 
@@ -777,7 +779,7 @@ void RipNg::HandleRequests (RipNgHeader requestHdr, Ipv6Address senderAddress, u
               // we use one of the sending sockets, as they're bound to the right interface
               // and the local address might be used on different interfaces.
               Ptr<Socket> sendingSocket;
-              for (SocketListI iter = m_sendSocketList.begin (); iter != m_sendSocketList.end (); iter++ )
+              for (SocketListI iter = m_unicastSocketList.begin (); iter != m_unicastSocketList.end (); iter++ )
                 {
                   if (iter->second == incomingInterface)
                     {
@@ -857,7 +859,7 @@ void RipNg::HandleRequests (RipNgHeader requestHdr, Ipv6Address senderAddress, u
       Ptr<Socket> sendingSocket;
       if (senderAddress.IsLinkLocal ())
         {
-          for (SocketListI iter = m_sendSocketList.begin (); iter != m_sendSocketList.end (); iter++ )
+          for (SocketListI iter = m_unicastSocketList.begin (); iter != m_unicastSocketList.end (); iter++ )
             {
               if (iter->second == incomingInterface)
                 {
@@ -867,7 +869,7 @@ void RipNg::HandleRequests (RipNgHeader requestHdr, Ipv6Address senderAddress, u
         }
       else
         {
-          sendingSocket = m_recvSocket;
+          sendingSocket = m_multicastRecvSocket;
         }
 
       Ptr<Packet> p = Create<Packet> ();
@@ -1078,7 +1080,7 @@ void RipNg::DoSendRouteUpdate (bool periodic)
 {
   NS_LOG_FUNCTION (this << (periodic ? " periodic" : " triggered"));
 
-  for (SocketListI iter = m_sendSocketList.begin (); iter != m_sendSocketList.end (); iter++ )
+  for (SocketListI iter = m_unicastSocketList.begin (); iter != m_unicastSocketList.end (); iter++ )
     {
       uint32_t interface = iter->second;
 
@@ -1254,7 +1256,7 @@ void RipNg::SendRouteRequest ()
   hdr.AddRte (rte);
   p->AddHeader (hdr);
 
-  for (SocketListI iter = m_sendSocketList.begin (); iter != m_sendSocketList.end (); iter++ )
+  for (SocketListI iter = m_unicastSocketList.begin (); iter != m_unicastSocketList.end (); iter++ )
     {
       uint32_t interface = iter->second;
 
