@@ -18,6 +18,7 @@
  */
 #include "tcp-bic.h"
 #include "ns3/log.h"
+#include "ns3/simulator.h"
 
 namespace ns3 {
 
@@ -272,6 +273,14 @@ TcpBic::GetSsThresh (Ptr<const TcpSocketState> tcb, uint32_t bytesInFlight)
   return ssThresh;
 }
 
+void
+TcpBic::ReduceCwnd (Ptr<TcpSocketState> tcb)
+{
+  NS_LOG_FUNCTION (this << tcb);
+
+  tcb->m_cWnd = std::max (tcb->m_cWnd.Get () / 2, tcb->m_segmentSize);
+}
+
 Ptr<TcpCongestionOps>
 TcpBic::Fork (void)
 {
