@@ -17,7 +17,6 @@
  *
  */
 #include "tcp-congestion-ops.h"
-#include "tcp-socket-base.h"
 #include "ns3/log.h"
 
 namespace ns3 {
@@ -48,6 +47,48 @@ TcpCongestionOps::~TcpCongestionOps ()
 {
 }
 
+void
+TcpCongestionOps::IncreaseWindow (Ptr<TcpSocketState> tcb, uint32_t segmentsAcked)
+{
+  NS_LOG_FUNCTION (this << tcb << segmentsAcked);
+}
+
+void
+TcpCongestionOps::PktsAcked (Ptr<TcpSocketState> tcb, uint32_t segmentsAcked,
+                             const Time& rtt)
+{
+  NS_LOG_FUNCTION (this << tcb << segmentsAcked << rtt);
+}
+
+void
+TcpCongestionOps::CongestionStateSet (Ptr<TcpSocketState> tcb,
+                                      const TcpSocketState::TcpCongState_t newState)
+{
+  NS_LOG_FUNCTION (this << tcb << newState);
+}
+
+void
+TcpCongestionOps::CwndEvent (Ptr<TcpSocketState> tcb,
+                             const TcpSocketState::TcpCAEvent_t event)
+{
+  NS_LOG_FUNCTION (this << tcb << event);
+}
+
+bool
+TcpCongestionOps::HasCongControl () const
+{
+  return false;
+}
+
+void
+TcpCongestionOps::CongControl (Ptr<TcpSocketState> tcb,
+                               const TcpRateOps::TcpRateConnection &rc,
+                               const TcpRateOps::TcpRateSample &rs)
+{
+  NS_LOG_FUNCTION (this << tcb);
+  NS_UNUSED (rc);
+  NS_UNUSED (rs);
+}
 
 // RENO
 
@@ -209,6 +250,14 @@ TcpNewReno::GetSsThresh (Ptr<const TcpSocketState> state,
   return std::max (2 * state->m_segmentSize, bytesInFlight / 2);
 }
 
+void
+TcpNewReno::ReduceCwnd (Ptr<TcpSocketState> tcb)
+{
+  NS_LOG_FUNCTION (this << tcb);
+
+  tcb->m_cWnd = std::max (tcb->m_cWnd.Get () / 2, tcb->m_segmentSize);
+}
+
 Ptr<TcpCongestionOps>
 TcpNewReno::Fork ()
 {
