@@ -47,6 +47,8 @@ public:
   TcpHeader ();
   virtual ~TcpHeader ();
 
+  typedef std::list< Ptr<const TcpOption> > TcpOptionList; //!< List of TcpOption
+
   /**
    * \brief Print a TCP header into an output stream
    *
@@ -183,7 +185,13 @@ public:
    * \param kind the option to retrieve
    * \return Whether the header contains a specific kind of option, or 0
    */
-  Ptr<TcpOption> GetOption (uint8_t kind) const;
+  Ptr<const TcpOption> GetOption (uint8_t kind) const;
+
+  /**
+   * \brief Get the list of option in this header
+   * \return a const reference to the option list
+   */
+  const TcpOptionList& GetOptionList (void) const;
 
   /**
    * \brief Get the total length of appended options
@@ -209,7 +217,7 @@ public:
    * \param option The option to append
    * \return true if option has been appended, false otherwise
    */
-  bool AppendOption (Ptr<TcpOption> option);
+  bool AppendOption (Ptr<const TcpOption> option);
 
   /**
    * \brief Initialize the TCP checksum.
@@ -341,7 +349,6 @@ private:
   bool m_goodChecksum;    //!< Flag to indicate that checksum is correct
 
   static const uint8_t m_maxOptionsLen = 40;         //!< Maximum options length
-  typedef std::list< Ptr<TcpOption> > TcpOptionList; //!< List of TcpOption
   TcpOptionList m_options;     //!< TcpOption present in the header
   uint8_t m_optionsLen;        //!< Tcp options length.
 };
