@@ -19,12 +19,13 @@
 #ifndef TCPHYBLA_H
 #define TCPHYBLA_H
 
-#include "ns3/tcp-congestion-ops.h"
-#include "ns3/tcp-recovery-ops.h"
+#include "tcp-congestion-ops.h"
 #include "ns3/traced-value.h"
 
 namespace ns3 {
 
+class TcpSocketState;
+
 /**
  * \ingroup congestionOps
  *
