@@ -30,11 +30,12 @@
 #ifndef TCPSCALABLE_H
 #define TCPSCALABLE_H
 
-#include "ns3/tcp-congestion-ops.h"
-#include "ns3/tcp-recovery-ops.h"
+#include "tcp-congestion-ops.h"
 
 namespace ns3 {
 
+class TcpSocketState;
+
 /**
  * \ingroup congestionOps
  *
