@@ -27,11 +27,12 @@
 #ifndef TCPVENO_H
 #define TCPVENO_H
 
-#include "ns3/tcp-congestion-ops.h"
-#include "ns3/tcp-recovery-ops.h"
+#include "tcp-congestion-ops.h"
 
 namespace ns3 {
 
+class TcpSocketState;
+
 /**
  * \ingroup congestionOps
  *
