@@ -24,6 +24,7 @@
 #include "ns3/tcp-socket-base.h"
 #include "ns3/tcp-congestion-ops.h"
 #include "ns3/tcp-recovery-ops.h"
+#include "ns3/tcp-rate-ops.h"
 #include "ns3/test.h"
 
 namespace ns3 {
@@ -591,12 +592,12 @@ protected:
   void SetInitialCwnd (SocketWho who, uint32_t initialCwnd);
 
   /**
-   * \brief Forcefully set the ecn mode on
+   * \brief Forcefully set the ecn use on
    *
    * \param who socket to force
-   * \param ecnMode Mode of ECN. Currently NoEcn and ClassicEcn is supported.
+   * \param useEcn Mode of ECN. Currently Off and On are supported.
    */
-  void SetEcn (SocketWho who, TcpSocketBase::EcnMode_t ecnMode);
+  void SetUseEcn (SocketWho who, TcpSocketState::UseEcn_t useEcn);
 
   /**
    * \brief Forcefully set the initial ssth
@@ -786,6 +787,24 @@ protected:
     NS_UNUSED (newValue);
   }
 
+  /**
+   * \brief Track the rate value of TcpRateLinux.
+   * \param rate updated value of TcpRate.
+   */
+  virtual void RateUpdatedTrace (const TcpRateLinux::TcpRateConnection &rate)
+  {
+    NS_UNUSED (rate);
+  }
+
+  /**
+   * \brief Track the rate sample value of TcpRateLinux.
+   * \param sample updated value of TcpRateSample.
+   */
+  virtual void RateSampleUpdatedTrace (const TcpRateLinux::TcpRateSample &sample)
+  {
+    NS_UNUSED (sample);
+  }
+
   /**
    * \brief Socket closed normally
    * \param who the socket closed (SENDER or RECEIVER)
