@@ -111,12 +111,12 @@ int main (int argc, char *argv[])
   bool generateSpectrumTrace = false;
   bool generateRem = false;
   int32_t remRbId = -1;
-  uint8_t bandwidth = 25;
+  uint16_t bandwidth = 25;
   double distance = 1000;
   Box macroUeBox = Box (-distance * 0.5, distance * 1.5, -distance * 0.5, distance * 1.5, 1.5, 1.5);
 
   // Command line arguments
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.AddValue ("numberOfUes", "Number of UEs", numberOfRandomUes);
   cmd.AddValue ("simTime", "Total duration of the simulation (in seconds)", simTime);
   cmd.AddValue ("generateSpectrumTrace", "if true, will generate a Spectrum Analyzer trace", generateSpectrumTrace);
@@ -356,7 +356,7 @@ int main (int argc, char *argv[])
       uint32_t dlChannelId = dlChannel->GetId ();
       NS_LOG_INFO ("DL ChannelId: " << dlChannelId);
       remHelper->SetAttribute ("ChannelPath", StringValue ("/ChannelList/1"));
-      remHelper->SetAttribute ("OutputFile", StringValue ("lena-frequency-reuse.rem"));
+      remHelper->SetAttribute ("OutputFile", StringValue ("lena-distributed-ffr.rem"));
       remHelper->SetAttribute ("XMin", DoubleValue (macroUeBox.xMin));
       remHelper->SetAttribute ("XMax", DoubleValue (macroUeBox.xMax));
       remHelper->SetAttribute ("YMin", DoubleValue (macroUeBox.yMin));
