@@ -107,12 +107,12 @@ int main (int argc, char *argv[])
   bool generateSpectrumTrace = false;
   bool generateRem = false;
   int32_t remRbId = -1;
-  uint8_t bandwidth = 25;
+  uint16_t bandwidth = 25;
   double distance = 1000;
   Box macroUeBox = Box (-distance * 0.5, distance * 1.5, -distance * 0.5, distance * 1.5, 1.5, 1.5);
 
   // Command line arguments
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.AddValue ("numberOfUes", "Number of random UEs", numberOfRandomUes);
   cmd.AddValue ("simTime", "Total duration of the simulation (in seconds)", simTime);
   cmd.AddValue ("generateSpectrumTrace", "if true, will generate a Spectrum Analyzer trace", generateSpectrumTrace);
