@@ -108,7 +108,6 @@ void
 ComponentCarrierEnb::DoInitialize (void)
 {
   NS_LOG_FUNCTION (this);
-  m_isConstructed = true;
   m_phy->Initialize ();
   m_mac->Initialize ();
   m_ffrAlgorithm->Initialize ();
@@ -170,40 +169,6 @@ ComponentCarrierEnb::SetFfMacScheduler (Ptr<FfMacScheduler> s)
 {
   NS_LOG_FUNCTION (this);
   m_scheduler = s;
-} 
-
-TypeId ComponentCarrierBaseStation::GetTypeId (void)
-{
-  static TypeId
-    tid =
-    TypeId ("ns3::ComponentCarrierBaseStation")
-    .SetParent<ComponentCarrier> ()
-    .AddConstructor<ComponentCarrierBaseStation> ()
-  ;
-  return tid;
-}
-
-ComponentCarrierBaseStation::ComponentCarrierBaseStation ()
-{
-  NS_LOG_FUNCTION (this);
-}
-
-ComponentCarrierBaseStation::~ComponentCarrierBaseStation (void)
-{
-  NS_LOG_FUNCTION (this);
-}
-
-uint16_t
-ComponentCarrierBaseStation::GetCellId ()
-{
-  return m_cellId;
-}
-
-void
-ComponentCarrierBaseStation::SetCellId (uint16_t cellId)
-{
-  NS_LOG_FUNCTION (this << cellId);
-  m_cellId = cellId;
 }
 
 } // namespace ns3
