@@ -61,8 +61,7 @@ public:
   enum UlCqiFilter_t
   {
     SRS_UL_CQI,
-    PUSCH_UL_CQI,
-    ALL_UL_CQI
+    PUSCH_UL_CQI
   };
   /**
   * constructor
