@@ -286,13 +286,14 @@ public:
 
 
   /**
-   * \brief PhySpectrum generated a new UL HARQ feedback
+   * \brief Report the uplink HARQ feedback generated by LteSpectrumPhy to MAC
+   *
    * \param mes UlInfoListElement_s
    */
-  virtual void ReceiveLteUlHarqFeedback (UlInfoListElement_s mes);
+  virtual void ReportUlHarqFeedback (UlInfoListElement_s mes);
 
   /**
-   * \brief PhySpectrum generated a new UL HARQ feedback
+   * \brief Set the HARQ Phy module
    *
    * \param harq the HARQ Phy
    */
@@ -328,7 +329,7 @@ private:
    * \param ulBandwidth UL bandwidth
    * \param dlBandwidth DL bandwidth
    */
-  void DoSetBandwidth (uint8_t ulBandwidth, uint8_t dlBandwidth);
+  void DoSetBandwidth (uint16_t ulBandwidth, uint16_t dlBandwidth);
   /**
    * Set EARFCN
    *
