@@ -148,14 +148,9 @@ protected:
   /**
    * Notify transmit opportunity
    *
-   * \param bytes number of bytes
-   * \param layer the layer
-   * \param harqId the HARQ ID
-   * \param componentCarrierId component carrier ID
-   * \param rnti the RNTI
-   * \param lcid the LCID
+   * \param params LteMacSapUser::TxOpportunityParameters
    */ 
-  virtual void DoNotifyTxOpportunity (uint32_t bytes, uint8_t layer, uint8_t harqId, uint8_t componentCarrierId, uint16_t rnti, uint8_t lcid) = 0;
+  virtual void DoNotifyTxOpportunity (LteMacSapUser::TxOpportunityParameters params) = 0;
   /**
    * Notify HARQ delivery failure
    */ 
@@ -163,11 +158,9 @@ protected:
   /**
    * Receive PDU function
    *
-   * \param p the packet
-   * \param rnti the RNTI
-   * \param lcid the LCID
+   * \param params the LteMacSapUser::ReceivePduParameters
    */ 
-  virtual void DoReceivePdu (Ptr<Packet> p, uint16_t rnti, uint8_t lcid) = 0;
+  virtual void DoReceivePdu (LteMacSapUser::ReceivePduParameters params) = 0;
 
   LteMacSapUser* m_macSapUser; ///< MAC SAP user
   LteMacSapProvider* m_macSapProvider; ///< MAC SAP provider
@@ -210,9 +203,9 @@ public:
   virtual void DoDispose ();
 
   virtual void DoTransmitPdcpPdu (Ptr<Packet> p);
-  virtual void DoNotifyTxOpportunity (uint32_t bytes, uint8_t layer, uint8_t harqId, uint8_t componentCarrierId, uint16_t rnti, uint8_t lcid);
+  virtual void DoNotifyTxOpportunity (LteMacSapUser::TxOpportunityParameters txOpParams);
   virtual void DoNotifyHarqDeliveryFailure ();
-  virtual void DoReceivePdu (Ptr<Packet> p, uint16_t rnti, uint8_t lcid);
+  virtual void DoReceivePdu (LteMacSapUser::ReceivePduParameters rxPduParams);
 
 
 
