@@ -27,6 +27,7 @@
 #include "ns3/minstrel-wifi-manager.h"
 #include "ns3/mesh-wifi-interface-mac.h"
 #include "ns3/wifi-helper.h"
+#include "ns3/wifi-ack-policy-selector.h"
 
 namespace ns3
 {
@@ -119,6 +120,10 @@ MeshHelper::Default (void)
   MeshHelper helper;
   helper.SetMacType ();
   helper.SetRemoteStationManager ("ns3::ArfWifiManager");
+  helper.SetAckPolicySelectorForAc (AC_BE, "ns3::ConstantWifiAckPolicySelector");
+  helper.SetAckPolicySelectorForAc (AC_BK, "ns3::ConstantWifiAckPolicySelector");
+  helper.SetAckPolicySelectorForAc (AC_VI, "ns3::ConstantWifiAckPolicySelector");
+  helper.SetAckPolicySelectorForAc (AC_VO, "ns3::ConstantWifiAckPolicySelector");
   helper.SetSpreadInterfaceChannels (SPREAD_CHANNELS);
   return helper;
 }
@@ -165,6 +170,28 @@ MeshHelper::SetRemoteStationManager (std::string type,
   m_stationManager.Set (n6, v6);
   m_stationManager.Set (n7, v7);
 }
+void
+MeshHelper::SetAckPolicySelectorForAc (AcIndex ac, std::string type,
+                                       std::string n0, const AttributeValue &v0,
+                                       std::string n1, const AttributeValue &v1,
+                                       std::string n2, const AttributeValue &v2,
+                                       std::string n3, const AttributeValue &v3,
+                                       std::string n4, const AttributeValue &v4,
+                                       std::string n5, const AttributeValue &v5,
+                                       std::string n6, const AttributeValue &v6,
+                                       std::string n7, const AttributeValue &v7)
+{
+  m_ackPolicySelector[ac] = ObjectFactory ();
+  m_ackPolicySelector[ac].SetTypeId (type);
+  m_ackPolicySelector[ac].Set (n0, v0);
+  m_ackPolicySelector[ac].Set (n1, v1);
+  m_ackPolicySelector[ac].Set (n2, v2);
+  m_ackPolicySelector[ac].Set (n3, v3);
+  m_ackPolicySelector[ac].Set (n4, v4);
+  m_ackPolicySelector[ac].Set (n5, v5);
+  m_ackPolicySelector[ac].Set (n6, v6);
+  m_ackPolicySelector[ac].Set (n7, v7);
+}
 void 
 MeshHelper::SetStandard (enum WifiPhyStandard standard)
 {
@@ -191,6 +218,30 @@ MeshHelper::CreateInterface (const WifiPhyHelper &phyHelper, Ptr<Node> node, uin
   device->SetRemoteStationManager (manager);
   node->AddDevice (device);
   mac->SwitchFrequencyChannel (channelId);
+  // Install ack policy selector
+  PointerValue ptr;
+  Ptr<WifiAckPolicySelector> ackSelector;
+
+  mac->GetAttributeFailSafe ("BE_Txop", ptr);
+  ackSelector = m_ackPolicySelector[AC_BE].Create<WifiAckPolicySelector> ();
+  ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
+  ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
+
+  mac->GetAttributeFailSafe ("BK_Txop", ptr);
+  ackSelector = m_ackPolicySelector[AC_BK].Create<WifiAckPolicySelector> ();
+  ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
+  ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
+
+  mac->GetAttributeFailSafe ("VI_Txop", ptr);
+  ackSelector = m_ackPolicySelector[AC_VI].Create<WifiAckPolicySelector> ();
+  ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
+  ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
+
+  mac->GetAttributeFailSafe ("VO_Txop", ptr);
+  ackSelector = m_ackPolicySelector[AC_VO].Create<WifiAckPolicySelector> ();
+  ackSelector->SetQosTxop (ptr.Get<QosTxop> ());
+  ptr.Get<QosTxop> ()->SetAckPolicySelector (ackSelector);
+
   return device;
 }
 void
