@@ -206,7 +206,7 @@ IeBeaconTiming::operator== (WifiInformationElement const & a) const
         }
       return true;
     }
-  catch (std::bad_cast)
+  catch (std::bad_cast&)
     {
       return false;
     }
