@@ -87,6 +87,8 @@ PeerLink::GetTypeId ()
   return tid;
 }
 
+const char* const
+PeerLink::PeerStateNames[6] = { "IDLE", "OPN_SNT", "CNF_RCVD", "OPN_RCVD", "ESTAB", "HOLDING" };
 
 //-----------------------------------------------------------------------------
 // PeerLink public interface
@@ -105,6 +107,7 @@ PeerLink::PeerLink () :
   m_retryCounter (0),
   m_maxPacketFail (3)
 {
+  NS_LOG_FUNCTION (this);
 }
 PeerLink::~PeerLink ()
 {
@@ -112,6 +115,7 @@ PeerLink::~PeerLink ()
 void
 PeerLink::DoDispose ()
 {
+  NS_LOG_FUNCTION (this);
   m_retryTimer.Cancel ();
   m_holdingTimer.Cancel ();
   m_confirmTimer.Cancel ();
@@ -161,6 +165,7 @@ PeerLink::MLMESetSignalStatusCallback (PeerLink::SignalStatusCallback cb)
 void
 PeerLink::BeaconLoss ()
 {
+  NS_LOG_FUNCTION (this);
   StateMachine (CNCL);
 }
 void
@@ -171,9 +176,11 @@ PeerLink::TransmissionSuccess ()
 void
 PeerLink::TransmissionFailure ()
 {
+  NS_LOG_FUNCTION (this);
   m_packetFail++;
   if (m_packetFail == m_maxPacketFail)
     {
+      NS_LOG_DEBUG ("TransmissionFailure:: CNCL");
       StateMachine (CNCL);
       m_packetFail = 0;
     }
@@ -233,6 +240,7 @@ PeerLink::MLMEPeeringRequestReject ()
 void
 PeerLink::Close (uint16_t localLinkId, uint16_t peerLinkId, PmpReasonCode reason)
 {
+  NS_LOG_FUNCTION (this << localLinkId << peerLinkId << reason);
   if (peerLinkId != 0 && m_localLinkId != peerLinkId)
     {
       return;
@@ -253,6 +261,7 @@ PeerLink::Close (uint16_t localLinkId, uint16_t peerLinkId, PmpReasonCode reason
 void
 PeerLink::OpenAccept (uint16_t localLinkId, IeConfiguration conf, Mac48Address peerMp)
 {
+  NS_LOG_FUNCTION (this << localLinkId << peerMp);
   m_peerLinkId = localLinkId;
   m_configuration = conf;
   if (m_peerMeshPointAddress != Mac48Address::GetBroadcast ())
@@ -268,6 +277,7 @@ PeerLink::OpenAccept (uint16_t localLinkId, IeConfiguration conf, Mac48Address p
 void
 PeerLink::OpenReject (uint16_t localLinkId, IeConfiguration conf, Mac48Address peerMp, PmpReasonCode reason)
 {
+  NS_LOG_FUNCTION (this << localLinkId << peerMp << reason);
   if (m_peerLinkId == 0)
     {
       m_peerLinkId = localLinkId;
@@ -287,6 +297,7 @@ void
 PeerLink::ConfirmAccept (uint16_t localLinkId, uint16_t peerLinkId, uint16_t peerAid, IeConfiguration conf,
                          Mac48Address peerMp)
 {
+  NS_LOG_FUNCTION (this << localLinkId << peerLinkId << peerAid << peerMp);
   if (m_localLinkId != peerLinkId)
     {
       return;
@@ -318,6 +329,7 @@ void
 PeerLink::ConfirmReject (uint16_t localLinkId, uint16_t peerLinkId, IeConfiguration conf,
                          Mac48Address peerMp, PmpReasonCode reason)
 {
+  NS_LOG_FUNCTION (this << localLinkId << peerLinkId << peerMp << reason);
   if (m_localLinkId != peerLinkId)
     {
       return;
@@ -655,6 +667,7 @@ PeerLink::SetHoldingTimer ()
 void
 PeerLink::HoldingTimeout ()
 {
+  NS_LOG_FUNCTION (this);
   StateMachine (TOH);
 }
 void
@@ -666,12 +679,15 @@ PeerLink::SetRetryTimer ()
 void
 PeerLink::RetryTimeout ()
 {
+  NS_LOG_FUNCTION (this);
   if (m_retryCounter < m_dot11MeshMaxRetries)
     {
+      NS_LOG_LOGIC ("Retry timeout TOR1");
       StateMachine (TOR1);
     }
   else
     {
+      NS_LOG_LOGIC ("Retry timeout TOR2");
       StateMachine (TOR2);
     }
 }
