@@ -71,6 +71,7 @@ public:
   virtual void SetScheduler (ObjectFactory schedulerFactory);
   virtual uint32_t GetSystemId (void) const;
   virtual uint32_t GetContext (void) const;
+  virtual uint64_t GetEventCount (void) const;
 
   /**
    * \return singleton instance
@@ -176,6 +177,8 @@ private:
   uint32_t m_currentUid;
   uint64_t m_currentTs;
   uint32_t m_currentContext;
+  /** The event count. */
+  uint64_t m_eventCount;
   // number of events that have been inserted but not yet scheduled,
   // not counting the "destroy" events; this is used for validation
   int m_unscheduledEvents;
