@@ -101,9 +101,12 @@ public:
   /**
    * \brief Comparison operation between two Ipv6Addresses.
    *
-   * \param other the IPv6 address to which to compare thisaddress
+   * \deprecated Use the == operator (same functionality)
+   *
+   * \param other the IPv6 address to which to compare this address
    * \return true if the addresses are equal, false otherwise
    */
+  NS_DEPRECATED_3_31
   bool IsEqual (const Ipv6Address& other) const;
 
   /**
@@ -140,6 +143,17 @@ public:
    */
   Ipv4Address GetIpv4MappedAddress () const;
 
+  /**
+   * \brief Make the autoconfigured IPv6 address from a Mac address.
+   *
+   * Actually the MAC supported are: Mac8, Mac16, Mac48, and Mac64.
+   *
+   * \param addr the MAC address.
+   * \param prefix the IPv6 prefix
+   * \return autoconfigured IPv6 address
+   */
+  static Ipv6Address MakeAutoconfiguredAddress (Address addr, Ipv6Address prefix);
+
   /**
    * \brief Make the autoconfigured IPv6 address with Mac16Address.
    *
@@ -181,6 +195,16 @@ public:
    */
   static Ipv6Address MakeAutoconfiguredAddress (Mac8Address addr, Ipv6Address prefix);
 
+  /**
+   * \brief Make the autoconfigured link-local IPv6 address from a Mac address.
+   *
+   * Actually the MAC supported are: Mac8, Mac16, Mac48, and Mac64.
+   *
+   * \param mac the MAC address.
+   * \return autoconfigured link-local IPv6 address
+   */
+  static Ipv6Address MakeAutoconfiguredLinkLocalAddress (Address mac);
+
   /**
    * \brief Make the autoconfigured link-local IPv6 address with Mac16Address.
    *
@@ -256,16 +280,6 @@ public:
    */
   bool IsAllRoutersMulticast () const;
 
-  /**
-   * \brief If the IPv6 address is "all hosts multicast" (ff02::3/8).
-   *
-   * \deprecated This function is deprecated because the address has been removed from RFCs.
-   *
-   * \return true if "all hosts multicast", false otherwise
-   */
-  NS_DEPRECATED
-  bool IsAllHostsMulticast () const;
-
   /**
    * \brief If the IPv6 address is a link-local address (fe80::/64).
    * \return true if the address is link-local, false otherwise
@@ -290,13 +304,20 @@ public:
    */
   bool IsDocumentation () const;
 
+  /**
+   * \brief Compares an address and a prefix.
+   * \param prefix the prefix to compare with
+   * \return true if the address has the given prefix
+   */
+  bool HasPrefix (Ipv6Prefix const& prefix) const;
+
   /**
    * \brief Combine this address with a prefix.
    * \param prefix a IPv6 prefix
    * \return an IPv6 address that is this address combined
    * (bitwise AND) with a prefix, yielding an IPv6 network address.
    */
-  Ipv6Address CombinePrefix (Ipv6Prefix const & prefix);
+  Ipv6Address CombinePrefix (Ipv6Prefix const & prefix) const;
 
   /**
    * \brief If the Address matches the type.
@@ -323,6 +344,11 @@ public:
    */
   static Ipv6Address ConvertFrom (const Address& address);
 
+  /**
+   * \return true if address is initialized (i.e., set to something), false otherwise
+   */
+  bool IsInitialized (void) const;
+
   /**
    * \brief Get the 0 (::) Ipv6Address.
    * \return the :: Ipv6Address representation
@@ -389,6 +415,7 @@ private:
    * \brief The address representation on 128 bits (16 bytes).
    */
   uint8_t m_address[16];
+  bool m_initialized; //!< IPv6 address has been explicitly initialized to a valid value.
 
   /**
    * \brief Equal to operator.
@@ -435,16 +462,38 @@ public:
 
   /**
    * \brief Constructs an Ipv6Prefix by using the input 16 bytes.
+   *
+   * The prefix length is calculated as the minimum prefix length, i.e.,
+   * 2001:db8:cafe:: will have a 47 bit prefix length.
+   *
    * \param prefix the 128-bit prefix
    */
   Ipv6Prefix (uint8_t prefix[16]);
 
   /**
    * \brief Constructs an Ipv6Prefix by using the input string.
+   *
+   * The prefix length is calculated as the minimum prefix length, i.e.,
+   * 2001:db8:cafe:: will have a 47 bit prefix length.
+   *
    * \param prefix the 128-bit prefix
    */
   Ipv6Prefix (char const* prefix);
 
+  /**
+   * \brief Constructs an Ipv6Prefix by using the input 16 bytes.
+   * \param prefix the 128-bit prefix
+   * \param prefixLength the prefix length
+   */
+  Ipv6Prefix (uint8_t prefix[16], uint8_t prefixLength);
+
+  /**
+   * \brief Constructs an Ipv6Prefix by using the input string.
+   * \param prefix the 128-bit prefix
+   * \param prefixLength the prefix length
+   */
+  Ipv6Prefix (char const* prefix, uint8_t prefixLength);
+
   /**
    * \brief Constructs an Ipv6Prefix by using the input number of bits.
    * \param prefix number of bits of the prefix (0 - 128)
@@ -489,11 +538,27 @@ public:
    */
   uint8_t GetPrefixLength () const;
 
+  /**
+   * \brief Set prefix length.
+   * \param prefixLength the prefix length
+   */
+  void SetPrefixLength (uint8_t prefixLength);
+
+   /**
+    * \brief Get the minimum prefix length, i.e., 128 - the length of the largest sequence trailing zeroes.
+    * \return minimum prefix length
+    */
+  uint8_t GetMinimumPrefixLength () const;
+
   /**
    * \brief Comparison operation between two Ipv6Prefix.
+   *
+   * \deprecated Use the == operator (same functionality)
+   *
    * \param other the IPv6 prefix to which to compare this prefix
    * \return true if the prefixes are equal, false otherwise
    */
+  NS_DEPRECATED_3_31
   bool IsEqual (const Ipv6Prefix& other) const;
 
   /**
@@ -528,6 +593,11 @@ private:
    */
   uint8_t m_prefix[16];
 
+  /**
+   * \brief The prefix length.
+   */
+  uint8_t m_prefixLength;
+
   /**
    * \brief Equal to operator.
    *
