@@ -25,6 +25,12 @@
 using namespace ns3;
 using namespace olsr;
 
+/**
+ * \ingroup olsr-test
+ * \ingroup tests
+ *
+ * Various olsr regression tests
+ */
 class RegressionTestSuite : public TestSuite
 {
 public:
@@ -35,4 +41,7 @@ public:
     AddTestCase (new TcRegressionTest, TestCase::QUICK);
     AddTestCase (new Bug780Test, TestCase::QUICK);
   }
-} g_olsrRegressionTestSuite;
+};
+
+static RegressionTestSuite g_olsrRegressionTestSuite; //!< Static variable for test initialization
+
