@@ -25,7 +25,6 @@
 #include "ns3/trace-source-accessor.h"
 #include "ns3/uinteger.h"
 #include "ns3/pointer.h"
-#include "ns3/net-device-queue-interface.h"
 #include "point-to-point-net-device.h"
 #include "point-to-point-channel.h"
 #include "ppp-header.h"
@@ -207,40 +206,6 @@ PointToPointNetDevice::ProcessHeader (Ptr<Packet> p, uint16_t& param)
   return true;
 }
 
-void
-PointToPointNetDevice::DoInitialize (void)
-{
-  if (m_queueInterface)
-    {
-      NS_ASSERT_MSG (m_queue != 0, "A Queue object has not been attached to the device");
-
-      // connect the traced callbacks of m_queue to the static methods provided by
-      // the NetDeviceQueue class to support flow control and dynamic queue limits.
-      // This could not be done in NotifyNewAggregate because at that time we are
-      // not guaranteed that a queue has been attached to the netdevice
-      m_queueInterface->ConnectQueueTraces (m_queue, 0);
-    }
-
-  NetDevice::DoInitialize ();
-}
-
-void
-PointToPointNetDevice::NotifyNewAggregate (void)
-{
-  NS_LOG_FUNCTION (this);
-  if (m_queueInterface == 0)
-    {
-      Ptr<NetDeviceQueueInterface> ndqi = this->GetObject<NetDeviceQueueInterface> ();
-      //verify that it's a valid netdevice queue interface and that
-      //the netdevice queue interface was not set before
-      if (ndqi != 0)
-        {
-          m_queueInterface = ndqi;
-        }
-    }
-  NetDevice::NotifyNewAggregate ();
-}
-
 void
 PointToPointNetDevice::DoDispose ()
 {
@@ -250,7 +215,6 @@ PointToPointNetDevice::DoDispose ()
   m_receiveErrorModel = 0;
   m_currentPkt = 0;
   m_queue = 0;
-  m_queueInterface = 0;
   NetDevice::DoDispose ();
 }
 
