@@ -124,7 +124,7 @@ SetupPacketReceive (Ptr<Node> node)
 
 int main (int argc, char** argv)
 {
-  CommandLine cmd;
+  CommandLine cmd (__FILE__);
   cmd.AddValue ("verbose", "Print trace information if true", g_verbose);
   cmd.Parse (argc, argv);
 
