@@ -271,20 +271,19 @@ UanNetDevice::GetBroadcast () const
 bool
 UanNetDevice::IsMulticast () const
 {
-  return false;
+  return true;
 }
 
 Address
 UanNetDevice::GetMulticast (Ipv4Address multicastGroup) const
 {
-  NS_FATAL_ERROR ("UanNetDevice does not support multicast");
+  NS_UNUSED (multicastGroup);
   return m_mac->GetBroadcast ();
 }
 
 Address
 UanNetDevice::GetMulticast (Ipv6Address addr) const
 {
-  NS_FATAL_ERROR ("UanNetDevice does not support multicast");
   return m_mac->GetBroadcast ();
 }
 
@@ -302,12 +301,19 @@ UanNetDevice::IsPointToPoint () const
 bool
 UanNetDevice::Send (Ptr<Packet> packet, const Address &dest, uint16_t protocolNumber)
 {
-  return m_mac->Enqueue (packet, dest, protocolNumber);
+  uint8_t tmp [6];
+  dest.CopyTo (tmp);
+  Mac8Address udest (tmp[0]);
+
+  return m_mac->Enqueue (packet, protocolNumber, udest);
 }
 
 bool
 UanNetDevice::SendFrom (Ptr<Packet> packet, const Address& source, const Address& dest, uint16_t protocolNumber)
 {
+  NS_UNUSED (source);
+  NS_UNUSED (dest);
+  NS_UNUSED (protocolNumber);
   // Not yet implemented
   NS_ASSERT_MSG (0, "Not yet implemented");
   return false;
@@ -327,7 +333,7 @@ UanNetDevice::SetNode (Ptr<Node> node)
 bool
 UanNetDevice::NeedsArp () const
 {
-  return false;
+  return true;
 }
 
 void
@@ -337,11 +343,11 @@ UanNetDevice::SetReceiveCallback (NetDevice::ReceiveCallback cb)
 }
 
 void
-UanNetDevice::ForwardUp (Ptr<Packet> pkt, const UanAddress &src)
+UanNetDevice::ForwardUp (Ptr<Packet> pkt, uint16_t protocolNumber, const Mac8Address &src)
 {
   NS_LOG_DEBUG ("Forwarding packet up to application");
   m_rxLogger (pkt, src);
-  m_forwardUp (this, pkt, 0, src);
+  m_forwardUp (this, pkt, protocolNumber, src);
 
 }
 
@@ -397,8 +403,8 @@ UanNetDevice::SupportsSendFrom (void) const
 void
 UanNetDevice::SetAddress (Address address)
 {
-  NS_ASSERT_MSG (0, "Tried to set MAC address with no MAC");
-  m_mac->SetAddress (UanAddress::ConvertFrom (address));
+  NS_ASSERT_MSG (NULL != m_mac, "Tried to set MAC address with no MAC");
+  m_mac->SetAddress (Mac8Address::ConvertFrom (address));
 }
 
 void
@@ -407,5 +413,17 @@ UanNetDevice::SetSleepMode (bool sleep)
   m_phy->SetSleepMode (sleep);
 }
 
+void
+UanNetDevice::SetTxModeIndex (uint32_t txModeIndex)
+{
+  m_mac->SetTxModeIndex (txModeIndex);
+}
+
+uint32_t
+UanNetDevice::GetTxModeIndex ()
+{
+  return m_mac->GetTxModeIndex ();
+}
+
 } // namespace ns3
 
