@@ -124,7 +124,7 @@ public:
    * dequeued as soon as the channel access function determines that
    * access is granted to this MAC.
    */
-  virtual void Enqueue (Ptr<const Packet> packet, Mac48Address to);
+  virtual void Enqueue (Ptr<Packet> packet, Mac48Address to);
   /**
     * \param cwmin the min contention window
     * \param cwmax the max contention window
@@ -176,7 +176,7 @@ public:
 protected:
   virtual void FinishConfigureStandard (enum WifiPhyStandard standard);
 private:
-  virtual void Receive (Ptr<Packet> packet, const WifiMacHeader *hdr);
+  virtual void Receive (Ptr<WifiMacQueueItem> mpdu);
 
   VendorSpecificContentManager m_vscManager; ///< VSC manager
 };
