@@ -43,7 +43,6 @@ struct AarfcdWifiRemoteStation : public WifiRemoteStation
   uint32_t m_failed; ///< failed
   bool m_recovery; ///< recovery
   bool m_justModifyRate; ///< just modify rate
-  uint32_t m_retry; ///< retry
   uint32_t m_successThreshold; ///< success threshold
   uint32_t m_timerTimeout; ///< timer timeout
   uint8_t m_rate; ///< rate
@@ -87,12 +86,12 @@ AarfcdWifiManager::GetTypeId (void)
                    MakeUintegerAccessor (&AarfcdWifiManager::m_minSuccessThreshold),
                    MakeUintegerChecker<uint32_t> ())
     .AddAttribute ("MinRtsWnd",
-                   "Minimum value for Rts window of Aarf-CD",
+                   "Minimum value for RTS window of AARF-CD",
                    UintegerValue (1),
                    MakeUintegerAccessor (&AarfcdWifiManager::m_minRtsWnd),
                    MakeUintegerChecker<uint32_t> ())
     .AddAttribute ("MaxRtsWnd",
-                   "Maximum value for Rts window of Aarf-CD",
+                   "Maximum value for RTS window of AARF-CD",
                    UintegerValue (40),
                    MakeUintegerAccessor (&AarfcdWifiManager::m_maxRtsWnd),
                    MakeUintegerChecker<uint32_t> ())
@@ -150,17 +149,16 @@ AarfcdWifiManager::DoCreateStation (void) const
   NS_LOG_FUNCTION (this);
   AarfcdWifiRemoteStation *station = new AarfcdWifiRemoteStation ();
 
-  //aarf fields below
+  //AARF fields below
   station->m_successThreshold = m_minSuccessThreshold;
   station->m_timerTimeout = m_minTimerThreshold;
   station->m_rate = 0;
   station->m_success = 0;
   station->m_failed = 0;
   station->m_recovery = false;
-  station->m_retry = 0;
   station->m_timer = 0;
 
-  //aarf-cd specific fields below
+  //AARF-CD specific fields below
   station->m_rtsOn = false;
   station->m_rtsWnd = m_minRtsWnd;
   station->m_rtsCounter = 0;
@@ -180,10 +178,9 @@ void
 AarfcdWifiManager::DoReportDataFailed (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  AarfcdWifiRemoteStation *station = (AarfcdWifiRemoteStation *)st;
+  AarfcdWifiRemoteStation *station = static_cast<AarfcdWifiRemoteStation*> (st);
   station->m_timer++;
   station->m_failed++;
-  station->m_retry++;
   station->m_success = 0;
 
   if (!station->m_rtsOn)
@@ -198,17 +195,17 @@ AarfcdWifiManager::DoReportDataFailed (WifiRemoteStation *st)
           ResetRtsWnd (station);
         }
       station->m_rtsCounter = station->m_rtsWnd;
-      if (station->m_retry >= 2)
+      if (station->m_failed >= 2)
         {
           station->m_timer = 0;
         }
     }
   else if (station->m_recovery)
     {
-      NS_ASSERT (station->m_retry >= 1);
+      NS_ASSERT (station->m_failed >= 1);
       station->m_justModifyRate = false;
       station->m_rtsCounter = station->m_rtsWnd;
-      if (station->m_retry == 1)
+      if (station->m_failed == 1)
         {
           //need recovery fallback
           if (m_turnOffRtsAfterRateDecrease)
@@ -229,10 +226,10 @@ AarfcdWifiManager::DoReportDataFailed (WifiRemoteStation *st)
     }
   else
     {
-      NS_ASSERT (station->m_retry >= 1);
+      NS_ASSERT (station->m_failed >= 1);
       station->m_justModifyRate = false;
       station->m_rtsCounter = station->m_rtsWnd;
-      if (((station->m_retry - 1) % 2) == 1)
+      if (((station->m_failed - 1) % 2) == 1)
         {
           //need normal fallback
           if (m_turnOffRtsAfterRateDecrease)
@@ -247,7 +244,7 @@ AarfcdWifiManager::DoReportDataFailed (WifiRemoteStation *st)
               station->m_rate--;
             }
         }
-      if (station->m_retry >= 2)
+      if (station->m_failed >= 2)
         {
           station->m_timer = 0;
         }
@@ -267,22 +264,21 @@ AarfcdWifiManager::DoReportRtsOk (WifiRemoteStation *st,
                                   double ctsSnr, WifiMode ctsMode, double rtsSnr)
 {
   NS_LOG_FUNCTION (this << st << ctsSnr << ctsMode << rtsSnr);
-  AarfcdWifiRemoteStation *station = (AarfcdWifiRemoteStation *) st;
+  AarfcdWifiRemoteStation *station = static_cast<AarfcdWifiRemoteStation*> (st);
   NS_LOG_DEBUG ("station=" << station << " rts ok");
   station->m_rtsCounter--;
 }
 
 void
-AarfcdWifiManager::DoReportDataOk (WifiRemoteStation *st,
-                                   double ackSnr, WifiMode ackMode, double dataSnr)
+AarfcdWifiManager::DoReportDataOk (WifiRemoteStation *st, double ackSnr, WifiMode ackMode,
+                                   double dataSnr, uint16_t dataChannelWidth, uint8_t dataNss)
 {
-  NS_LOG_FUNCTION (this << st << ackSnr << ackMode << dataSnr);
-  AarfcdWifiRemoteStation *station = (AarfcdWifiRemoteStation *) st;
+  NS_LOG_FUNCTION (this << st << ackSnr << ackMode << dataSnr << dataChannelWidth << +dataNss);
+  AarfcdWifiRemoteStation *station = static_cast<AarfcdWifiRemoteStation*> (st);
   station->m_timer++;
   station->m_success++;
   station->m_failed = 0;
   station->m_recovery = false;
-  station->m_retry = 0;
   station->m_justModifyRate = false;
   station->m_haveASuccess = true;
   NS_LOG_DEBUG ("station=" << station << " data ok success=" << station->m_success << ", timer=" << station->m_timer);
@@ -322,11 +318,10 @@ WifiTxVector
 AarfcdWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  AarfcdWifiRemoteStation *station = (AarfcdWifiRemoteStation *) st;
+  AarfcdWifiRemoteStation *station = static_cast<AarfcdWifiRemoteStation*> (st);
   uint16_t channelWidth = GetChannelWidth (station);
   if (channelWidth > 20 && channelWidth != 22)
     {
-      //avoid to use legacy rate adaptation algorithms for IEEE 802.11n/ac
       channelWidth = 20;
     }
   WifiMode mode = GetSupported (station, station->m_rate);
@@ -342,13 +337,12 @@ WifiTxVector
 AarfcdWifiManager::DoGetRtsTxVector (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  /// \todo we could/should implement the Aarf algorithm for
+  /// \todo we could/should implement the AARF algorithm for
   /// RTS only by picking a single rate within the BasicRateSet.
-  AarfcdWifiRemoteStation *station = (AarfcdWifiRemoteStation *) st;
+  AarfcdWifiRemoteStation *station = static_cast<AarfcdWifiRemoteStation*> (st);
   uint16_t channelWidth = GetChannelWidth (station);
   if (channelWidth > 20 && channelWidth != 22)
     {
-      //avoid to use legacy rate adaptation algorithms for IEEE 802.11n/ac
       channelWidth = 20;
     }
   WifiTxVector rtsTxVector;
@@ -367,21 +361,15 @@ AarfcdWifiManager::DoGetRtsTxVector (WifiRemoteStation *st)
 
 bool
 AarfcdWifiManager::DoNeedRts (WifiRemoteStation *st,
-                              Ptr<const Packet> packet, bool normally)
+                              uint32_t size, bool normally)
 {
-  NS_LOG_FUNCTION (this << st << packet << normally);
-  AarfcdWifiRemoteStation *station = (AarfcdWifiRemoteStation *) st;
+  NS_LOG_FUNCTION (this << st << size << normally);
+  AarfcdWifiRemoteStation *station = static_cast<AarfcdWifiRemoteStation*> (st);
   NS_LOG_INFO ("" << station << " rate=" << station->m_rate << " rts=" << (station->m_rtsOn ? "RTS" : "BASIC") <<
                " rtsCounter=" << station->m_rtsCounter);
   return station->m_rtsOn;
 }
 
-bool
-AarfcdWifiManager::IsLowLatency (void) const
-{
-  return true;
-}
-
 void
 AarfcdWifiManager::CheckRts (AarfcdWifiRemoteStation *station)
 {
