@@ -30,7 +30,7 @@ namespace ns3 {
 /**
  * \ingroup wifi
  *
- *
+ * \brief Wifi MAC high model for an ad-hoc Wifi MAC
  */
 class AdhocWifiMac : public RegularWifiMac
 {
@@ -44,29 +44,13 @@ public:
   AdhocWifiMac ();
   virtual ~AdhocWifiMac ();
 
-  /**
-   * \param address the current address of this MAC layer.
-   */
+  // Implementations of pure virtual methods, or overridden from base class.
   void SetAddress (Mac48Address address);
-
-  /**
-   * \param linkUp the callback to invoke when the link becomes up.
-   */
   void SetLinkUpCallback (Callback<void> linkUp);
-
-  /**
-   * \param packet the packet to send.
-   * \param to the address to which the packet should be sent.
-   *
-   * The packet should be enqueued in a tx queue, and should be
-   * dequeued as soon as the channel access function determines that
-   * access is granted to this MAC.
-   */
-  void Enqueue (Ptr<const Packet> packet, Mac48Address to);
-
+  void Enqueue (Ptr<Packet> packet, Mac48Address to);
 
 private:
-  void Receive (Ptr<Packet> packet, const WifiMacHeader *hdr);
+  void Receive (Ptr<WifiMacQueueItem> mpdu);
 };
 
 } //namespace ns3
