@@ -37,9 +37,9 @@ struct AmrrWifiRemoteStation;
  * A Practical Approach</i>, by M. Lacage, M.H. Manshaei, and
  * T. Turletti.
  *
- * This RAA does not support HT, VHT nor HE modes and will error
+ * This RAA does not support HT modes and will error
  * exit if the user tries to configure this RAA with a Wi-Fi MAC
- * that has VhtSupported, HtSupported or HeSupported set.
+ * that supports 802.11n or higher.
  */
 class AmrrWifiManager : public WifiRemoteStationManager
 {
@@ -64,43 +64,42 @@ private:
   void DoReportDataFailed (WifiRemoteStation *station);
   void DoReportRtsOk (WifiRemoteStation *station,
                       double ctsSnr, WifiMode ctsMode, double rtsSnr);
-  void DoReportDataOk (WifiRemoteStation *station,
-                       double ackSnr, WifiMode ackMode, double dataSnr);
+  void DoReportDataOk (WifiRemoteStation *station, double ackSnr, WifiMode ackMode,
+                       double dataSnr, uint16_t dataChannelWidth, uint8_t dataNss);
   void DoReportFinalRtsFailed (WifiRemoteStation *station);
   void DoReportFinalDataFailed (WifiRemoteStation *station);
   WifiTxVector DoGetDataTxVector (WifiRemoteStation *station);
   WifiTxVector DoGetRtsTxVector (WifiRemoteStation *station);
-  bool IsLowLatency (void) const;
 
   /**
    * Update the mode used to send to the given station.
    *
-   * \param station
+   * \param station the remote station state
    */
   void UpdateMode (AmrrWifiRemoteStation *station);
   /**
    * Reset transmission statistics of the given station.
    *
-   * \param station
+   * \param station the remote station state
    */
   void ResetCnt (AmrrWifiRemoteStation *station);
   /**
    * Increase the transmission rate to the given station.
    *
-   * \param station
+   * \param station the remote station state
    */
   void IncreaseRate (AmrrWifiRemoteStation *station);
   /**
    * Decrease the transmission rate to the given station.
    *
-   * \param station
+   * \param station the remote station state
    */
   void DecreaseRate (AmrrWifiRemoteStation *station);
   /**
    * Check if the current rate for the given station is the
    * minimum rate.
    *
-   * \param station
+   * \param station the remote station state
    *
    * \return true if the current rate is the minimum rate,
    *         false otherwise
@@ -110,7 +109,7 @@ private:
    * Check if the current rate for the given station is the
    * maximum rate.
    *
-   * \param station
+   * \param station the remote station state
    *
    * \return true if the current rate is the maximum rate,
    *         false otherwise
@@ -120,7 +119,7 @@ private:
    * Check if the number of retransmission and transmission error
    * is less than the number of successful transmission (times ratio).
    *
-   * \param station
+   * \param station the remote station state
    *
    * \return true if the number of retransmission and transmission error
    *              is less than the number of successful transmission
@@ -131,7 +130,7 @@ private:
    * Check if the number of retransmission and transmission error
    * is greater than the number of successful transmission (times ratio).
    *
-   * \param station
+   * \param station the remote station state
    *
    * \return true if the number of retransmission and transmission error
    *              is less than the number of successful transmission
@@ -142,18 +141,18 @@ private:
    * Check if the number of retransmission, transmission error,
    * and successful transmission are greater than 10.
    *
-   * \param station
+   * \param station the remote station state
    * \return true if the number of retransmission, transmission error,
    *         and successful transmission are greater than 10,
    *         false otherwise
    */
   bool IsEnough (AmrrWifiRemoteStation *station) const;
 
-  Time m_updatePeriod; ///< update period
-  double m_failureRatio; ///< failure ratio
-  double m_successRatio; ///< success ratio
+  Time m_updatePeriod;            ///< update period
+  double m_failureRatio;          ///< failure ratio
+  double m_successRatio;          ///< success ratio
   uint32_t m_maxSuccessThreshold; ///< maximum success threshold
-  uint32_t m_minSuccessThreshold; ///< mnimum success threshold
+  uint32_t m_minSuccessThreshold; ///< minimum success threshold
 
   TracedValue<uint64_t> m_currentRate; //!< Trace rate changes
 };
