@@ -40,7 +40,6 @@ struct ArfWifiRemoteStation : public WifiRemoteStation
   uint32_t m_success; ///< success count
   uint32_t m_failed; ///< failed count
   bool m_recovery; ///< recovery
-  uint32_t m_retry; ///< retry count
   uint32_t m_timerTimeout; ///< timer timeout
   uint32_t m_successThreshold; ///< success threshold
   uint8_t m_rate; ///< rate
@@ -114,7 +113,6 @@ ArfWifiManager::DoCreateStation (void) const
   station->m_success = 0;
   station->m_failed = 0;
   station->m_recovery = false;
-  station->m_retry = 0;
   station->m_timer = 0;
 
   return station;
@@ -135,22 +133,21 @@ ArfWifiManager::DoReportRtsFailed (WifiRemoteStation *station)
  * The fundamental reason for this is that there is a backoff between each data
  * transmission, be it an initial transmission or a retransmission.
  *
- * \param st the station that we failed to send DATA
+ * \param st the station that we failed to send Data
  */
 void
 ArfWifiManager::DoReportDataFailed (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  ArfWifiRemoteStation *station = (ArfWifiRemoteStation *)st;
+  ArfWifiRemoteStation *station = static_cast<ArfWifiRemoteStation*> (st);
   station->m_timer++;
   station->m_failed++;
-  station->m_retry++;
   station->m_success = 0;
 
   if (station->m_recovery)
     {
-      NS_ASSERT (station->m_retry >= 1);
-      if (station->m_retry == 1)
+      NS_ASSERT (station->m_failed >= 1);
+      if (station->m_failed == 1)
         {
           //need recovery fallback
           if (station->m_rate != 0)
@@ -162,8 +159,8 @@ ArfWifiManager::DoReportDataFailed (WifiRemoteStation *st)
     }
   else
     {
-      NS_ASSERT (station->m_retry >= 1);
-      if (((station->m_retry - 1) % 2) == 1)
+      NS_ASSERT (station->m_failed >= 1);
+      if (((station->m_failed - 1) % 2) == 1)
         {
           //need normal fallback
           if (station->m_rate != 0)
@@ -171,7 +168,7 @@ ArfWifiManager::DoReportDataFailed (WifiRemoteStation *st)
               station->m_rate--;
             }
         }
-      if (station->m_retry >= 2)
+      if (station->m_failed >= 2)
         {
           station->m_timer = 0;
         }
@@ -192,16 +189,15 @@ void ArfWifiManager::DoReportRtsOk (WifiRemoteStation *station,
   NS_LOG_DEBUG ("station=" << station << " rts ok");
 }
 
-void ArfWifiManager::DoReportDataOk (WifiRemoteStation *st,
-                                     double ackSnr, WifiMode ackMode, double dataSnr)
+void ArfWifiManager::DoReportDataOk (WifiRemoteStation *st, double ackSnr, WifiMode ackMode,
+                                     double dataSnr, uint16_t dataChannelWidth, uint8_t dataNss)
 {
-  NS_LOG_FUNCTION (this << st << ackSnr << ackMode << dataSnr);
-  ArfWifiRemoteStation *station = (ArfWifiRemoteStation *) st;
+  NS_LOG_FUNCTION (this << st << ackSnr << ackMode << dataSnr << dataChannelWidth << +dataNss);
+  ArfWifiRemoteStation *station = static_cast<ArfWifiRemoteStation*> (st);
   station->m_timer++;
   station->m_success++;
   station->m_failed = 0;
   station->m_recovery = false;
-  station->m_retry = 0;
   NS_LOG_DEBUG ("station=" << station << " data ok success=" << station->m_success << ", timer=" << station->m_timer);
   if ((station->m_success == m_successThreshold
        || station->m_timer == m_timerThreshold)
@@ -231,11 +227,10 @@ WifiTxVector
 ArfWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  ArfWifiRemoteStation *station = (ArfWifiRemoteStation *) st;
+  ArfWifiRemoteStation *station = static_cast<ArfWifiRemoteStation*> (st);
   uint16_t channelWidth = GetChannelWidth (station);
   if (channelWidth > 20 && channelWidth != 22)
     {
-      //avoid to use legacy rate adaptation algorithms for IEEE 802.11n/ac
       channelWidth = 20;
     }
   WifiMode mode = GetSupported (station, station->m_rate);
@@ -251,13 +246,12 @@ WifiTxVector
 ArfWifiManager::DoGetRtsTxVector (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  /// \todo we could/should implement the Arf algorithm for
+  /// \todo we could/should implement the ARF algorithm for
   /// RTS only by picking a single rate within the BasicRateSet.
-  ArfWifiRemoteStation *station = (ArfWifiRemoteStation *) st;
+  ArfWifiRemoteStation *station = static_cast<ArfWifiRemoteStation*> (st);
   uint16_t channelWidth = GetChannelWidth (station);
   if (channelWidth > 20 && channelWidth != 22)
     {
-      //avoid to use legacy rate adaptation algorithms for IEEE 802.11n/ac
       channelWidth = 20;
     }
   WifiTxVector rtsTxVector;
@@ -274,10 +268,4 @@ ArfWifiManager::DoGetRtsTxVector (WifiRemoteStation *st)
   return rtsTxVector;
 }
 
-bool
-ArfWifiManager::IsLowLatency (void) const
-{
-  return true;
-}
-
 } //namespace ns3
