@@ -27,6 +27,7 @@
 #include "wifi-mac-queue.h"
 #include "mac-tx-middle.h"
 #include "qos-utils.h"
+#include "wifi-tx-vector.h"
 
 namespace ns3 {
 
@@ -37,13 +38,12 @@ Bar::Bar ()
   NS_LOG_FUNCTION (this);
 }
 
-Bar::Bar (Ptr<const Packet> bar, Mac48Address recipient, uint8_t tid, bool immediate)
+Bar::Bar (Ptr<const WifiMacQueueItem> bar, uint8_t tid, bool skipIfNoDataQueued)
   : bar (bar),
-    recipient (recipient),
     tid (tid),
-    immediate (immediate)
+    skipIfNoDataQueued (skipIfNoDataQueued)
 {
-  NS_LOG_FUNCTION (this << bar << recipient << +tid << immediate);
+  NS_LOG_FUNCTION (this << *bar << +tid << skipIfNoDataQueued);
 }
 
 NS_OBJECT_ENSURE_REGISTERED (BlockAckManager);
@@ -122,7 +122,6 @@ BlockAckManager::CreateAgreement (const MgtAddBaRequestHeader *reqHdr, Mac48Addr
   /* For now we assume that originator doesn't use this field. Use of this field
      is mandatory only for recipient */
   agreement.SetBufferSize (reqHdr->GetBufferSize());
-  agreement.SetWinEnd ((agreement.GetStartingSequence () + agreement.GetBufferSize () - 1) % SEQNO_SPACE_SIZE);
   agreement.SetTimeout (reqHdr->GetTimeout ());
   agreement.SetAmsduSupport (reqHdr->IsAmsduSupported ());
   agreement.SetHtSupported (m_stationManager->GetHtSupported ());
@@ -168,10 +167,10 @@ BlockAckManager::DestroyAgreement (Mac48Address recipient, uint8_t tid)
             }
         }
       m_agreements.erase (it);
-      //remove scheduled bar
+      //remove scheduled BAR
       for (std::list<Bar>::const_iterator i = m_bars.begin (); i != m_bars.end (); )
         {
-          if (i->recipient == recipient && i->tid == tid)
+          if (i->bar->GetHeader ().GetAddr1 () == recipient && i->tid == tid)
             {
               i = m_bars.erase (i);
             }
@@ -195,9 +194,23 @@ BlockAckManager::UpdateAgreement (const MgtAddBaResponseHeader *respHdr, Mac48Ad
       agreement.SetBufferSize (respHdr->GetBufferSize () + 1);
       agreement.SetTimeout (respHdr->GetTimeout ());
       agreement.SetAmsduSupport (respHdr->IsAmsduSupported ());
-      // update the starting sequence number because some frames may have been sent
-      // under Normal Ack policy after the transmission of the ADDBA Request frame
-      agreement.SetStartingSequence (m_txMiddle->GetNextSeqNumberByTidAndAddress (tid, recipient));
+      // When the Add BA Response is received, there may be a packet transmitted
+      // under the normal ack policy that needs to be retransmitted. If so, such
+      // packet is placed in the retransmit queue. If this is the case, the starting
+      // sequence number is the sequence number of such packet. Otherwise, it is
+      // the sequence number that will be assigned to the next packet to be transmitted.
+      uint16_t startSeq;
+      WifiMacQueue::ConstIterator mpduIt = m_retryPackets->PeekByTidAndAddress (tid, recipient);
+      if (mpduIt != m_retryPackets->end ())
+        {
+          startSeq = (*mpduIt)->GetHeader ().GetSequenceNumber ();
+        }
+      else
+        {
+          startSeq = m_txMiddle->GetNextSeqNumberByTidAndAddress (tid, recipient);
+        }
+      agreement.SetStartingSequence (startSeq);
+      agreement.InitTxWindow ();
       if (respHdr->IsImmediateBlockAck ())
         {
           agreement.SetImmediateBlockAck ();
@@ -241,8 +254,7 @@ BlockAckManager::StorePacket (Ptr<WifiMacQueueItem> mpdu)
   AgreementsI agreementIt = m_agreements.find (std::make_pair (recipient, tid));
   NS_ASSERT (agreementIt != m_agreements.end ());
 
-  uint16_t startingSeq = agreementIt->second.first.GetStartingSequence ();
-  uint16_t mpduDist = (mpdu->GetHeader ().GetSequenceNumber () - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE;
+  uint16_t mpduDist = agreementIt->second.first.GetDistance (mpdu->GetHeader ().GetSequenceNumber ());
 
   if (mpduDist >= SEQNO_SPACE_HALF_SIZE)
     {
@@ -261,7 +273,7 @@ BlockAckManager::StorePacket (Ptr<WifiMacQueueItem> mpdu)
           return;
         }
 
-      uint16_t dist = ((*it)->GetHeader ().GetSequenceNumber () - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE;
+      uint16_t dist = agreementIt->second.first.GetDistance ((*it)->GetHeader ().GetSequenceNumber ());
 
       if (mpduDist < dist ||
           (mpduDist == dist && mpdu->GetHeader ().GetFragmentNumber () < (*it)->GetHeader ().GetFragmentNumber ()))
@@ -272,28 +284,80 @@ BlockAckManager::StorePacket (Ptr<WifiMacQueueItem> mpdu)
       it++;
     }
   agreementIt->second.second.insert (it, mpdu);
+  agreementIt->second.first.NotifyTransmittedMpdu (mpdu);
 }
 
-bool
-BlockAckManager::HasBar (Bar &bar, bool remove)
+Ptr<const WifiMacQueueItem>
+BlockAckManager::GetBar (bool remove)
 {
-  if (m_bars.size () > 0)
+  Ptr<const WifiMacQueueItem> bar;
+  // remove all expired MPDUs in the retransmission queue, so that Block Ack Requests
+  // (if needed) are scheduled
+  m_retryPackets->Remove (WifiMacQueue::EMPTY, true);
+
+  auto nextBar = m_bars.begin ();
+
+  while (nextBar != m_bars.end ())
     {
-      bar = m_bars.front ();
+      if (nextBar->bar->GetHeader ().IsBlockAckReq ())
+        {
+          Mac48Address recipient = nextBar->bar->GetHeader ().GetAddr1 ();
+          AgreementsI it = m_agreements.find (std::make_pair (recipient, nextBar->tid));
+          if (it == m_agreements.end ())
+            {
+              // BA agreement was torn down; remove this BAR and continue
+              nextBar = m_bars.erase (nextBar);
+              continue;
+            }
+          if (nextBar->skipIfNoDataQueued
+              && m_retryPackets->PeekByTidAndAddress (nextBar->tid, recipient) == m_retryPackets->end ()
+              && m_queue->PeekByTidAndAddress (nextBar->tid, recipient) == m_queue->end ())
+            {
+              // skip this BAR as there is no data queued
+              nextBar++;
+              continue;
+            }
+          // remove expired outstanding MPDUs and update the starting sequence number
+          for (auto mpduIt = it->second.second.begin (); mpduIt != it->second.second.end (); )
+            {
+              if ((*mpduIt)->GetTimeStamp () + m_queue->GetMaxDelay () <= Simulator::Now ())
+                {
+                  // MPDU expired
+                  it->second.first.NotifyDiscardedMpdu (*mpduIt);
+                  mpduIt = it->second.second.erase (mpduIt);
+                }
+              else
+                {
+                  mpduIt++;
+                }
+            }
+          // update BAR if the starting sequence number changed
+          CtrlBAckRequestHeader reqHdr;
+          nextBar->bar->GetPacket ()->PeekHeader (reqHdr);
+          if (reqHdr.GetStartingSequence () != it->second.first.GetStartingSequence ())
+            {
+              reqHdr.SetStartingSequence (it->second.first.GetStartingSequence ());
+              Ptr<Packet> packet = Create<Packet> ();
+              packet->AddHeader (reqHdr);
+              nextBar->bar = Create<const WifiMacQueueItem> (packet, nextBar->bar->GetHeader ());
+            }
+        }
+
+      bar = nextBar->bar;
       if (remove)
         {
-          m_bars.pop_front ();
+          m_bars.erase (nextBar);
         }
-      return true;
+      break;
     }
-  return false;
+  return bar;
 }
 
 bool
-BlockAckManager::HasPackets (void) const
+BlockAckManager::HasPackets (void)
 {
   NS_LOG_FUNCTION (this);
-  return (!m_retryPackets->IsEmpty () || m_bars.size () > 0);
+  return (!m_retryPackets->IsEmpty () || GetBar (false) != 0);
 }
 
 uint32_t
@@ -361,12 +425,7 @@ BlockAckManager::NotifyGotAck (Ptr<const WifiMacQueueItem> mpdu)
       }
     }
 
-  uint16_t startingSeq = it->second.first.GetStartingSequence ();
-  if (mpdu->GetHeader ().GetSequenceNumber () == startingSeq)
-    {
-      // make the transmit window advance
-      it->second.first.SetStartingSequence ((startingSeq + 1) % SEQNO_SPACE_SIZE);
-    }
+  it->second.first.NotifyAckedMpdu (mpdu);
 }
 
 void
@@ -402,9 +461,9 @@ BlockAckManager::NotifyMissedAck (Ptr<WifiMacQueueItem> mpdu)
 }
 
 void
-BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac48Address recipient, double rxSnr, WifiMode txMode, double dataSnr)
+BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac48Address recipient, double rxSnr, double dataSnr, WifiTxVector dataTxVector)
 {
-  NS_LOG_FUNCTION (this << blockAck << recipient << rxSnr << txMode.GetUniqueName () << dataSnr);
+  NS_LOG_FUNCTION (this << blockAck << recipient << rxSnr << dataSnr << dataTxVector);
   if (!blockAck->IsMultiTid ())
     {
       uint8_t tid = blockAck->GetTidInfo ();
@@ -418,7 +477,7 @@ BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac4
 
           if (it->second.first.m_inactivityEvent.IsRunning ())
             {
-              /* Upon reception of a block ack frame, the inactivity timer at the
+              /* Upon reception of a BlockAck frame, the inactivity timer at the
                  originator must be reset.
                  For more details see section 11.5.3 in IEEE802.11e standard */
               it->second.first.m_inactivityEvent.Cancel ();
@@ -447,7 +506,7 @@ BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac4
                       if (!foundFirstLost)
                         {
                           foundFirstLost = true;
-                          SetStartingSequence (recipient, tid, currentSeq);
+                          RemoveOldPackets (recipient, tid, currentSeq);
                         }
                       nFailedMpdus++;
                       InsertInRetryQueue (*queueIt);
@@ -458,7 +517,7 @@ BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac4
               // If all frames were acknowledged, move the transmit window past the last one
               if (!foundFirstLost && currentSeq != SEQNO_SPACE_SIZE)
                 {
-                  SetStartingSequence (recipient, tid, (currentSeq + 1) % SEQNO_SPACE_SIZE);
+                  RemoveOldPackets (recipient, tid, (currentSeq + 1) % SEQNO_SPACE_SIZE);
                 }
             }
           else if (blockAck->IsCompressed () || blockAck->IsExtendedCompressed ())
@@ -468,6 +527,7 @@ BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac4
                   currentSeq = (*queueIt)->GetHeader ().GetSequenceNumber ();
                   if (blockAck->IsPacketReceived (currentSeq))
                     {
+                      it->second.first.NotifyAckedMpdu (*queueIt);
                       nSuccessfulMpdus++;
                       if (!m_txOkCallback.IsNull ())
                         {
@@ -476,11 +536,6 @@ BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac4
                     }
                   else if (!QosUtilsIsOldPacket (currentStartingSeq, currentSeq))
                     {
-                      if (!foundFirstLost)
-                        {
-                          foundFirstLost = true;
-                          SetStartingSequence (recipient, tid, currentSeq);
-                        }
                       nFailedMpdus++;
                       if (!m_txFailedCallback.IsNull ())
                         {
@@ -491,13 +546,8 @@ BlockAckManager::NotifyGotBlockAck (const CtrlBAckResponseHeader *blockAck, Mac4
                   // in any case, this packet is no longer outstanding
                   queueIt = it->second.second.erase (queueIt);
                 }
-              // If all frames were acknowledged, move the transmit window past the last one
-              if (!foundFirstLost && currentSeq != SEQNO_SPACE_SIZE)
-                {
-                  SetStartingSequence (recipient, tid, (currentSeq + 1) % SEQNO_SPACE_SIZE);
-                }
             }
-          m_stationManager->ReportAmpduTxStatus (recipient, tid, nSuccessfulMpdus, nFailedMpdus, rxSnr, dataSnr);
+          m_stationManager->ReportAmpduTxStatus (recipient, nSuccessfulMpdus, nFailedMpdus, rxSnr, dataSnr, dataTxVector);
         }
     }
   else
@@ -532,7 +582,19 @@ BlockAckManager::DiscardOutstandingMpdus (Mac48Address recipient, uint8_t tid)
   if (ExistsAgreementInState (recipient, tid, OriginatorBlockAckAgreement::ESTABLISHED))
     {
       AgreementsI it = m_agreements.find (std::make_pair (recipient, tid));
-      it->second.second.clear ();
+      while (!it->second.second.empty ())
+        {
+          Ptr<WifiMacQueueItem> mpdu = it->second.second.front ();
+          if (it->second.first.GetDistance (mpdu->GetHeader ().GetSequenceNumber ()) >= SEQNO_SPACE_HALF_SIZE)
+            {
+              // old packet
+              it->second.second.pop_front ();
+            }
+          else
+            {
+              NotifyDiscardedMpdu (mpdu);
+            }
+        }
     }
 }
 
@@ -570,43 +632,74 @@ BlockAckManager::NotifyDiscardedMpdu (Ptr<const WifiMacQueueItem> mpdu)
       return;
     }
 
-  // advance the transmit window past the discarded mpdu
-  SetStartingSequence (recipient, tid, (mpdu->GetHeader ().GetSequenceNumber () + 1) % SEQNO_SPACE_SIZE);
+  // remove outstanding frames and frames in the retransmit queue with a sequence
+  // number less than or equal to the discarded MPDU
+  RemoveOldPackets (recipient, tid, (mpdu->GetHeader ().GetSequenceNumber () + 1) % SEQNO_SPACE_SIZE);
+  // actually advance the transmit window
+  it->second.first.NotifyDiscardedMpdu (mpdu);
 
-  // schedule a block ack request
+  // schedule a BlockAckRequest
   NS_LOG_DEBUG ("Schedule a Block Ack Request for agreement (" << recipient << ", " << +tid << ")");
-  ScheduleBlockAckReq (recipient, tid);
+  Ptr<Packet> bar = Create<Packet> ();
+  bar->AddHeader (GetBlockAckReqHeader (recipient, tid));
+
+  WifiMacHeader hdr;
+  hdr.SetType (WIFI_MAC_CTL_BACKREQ);
+  hdr.SetAddr1 (recipient);
+  hdr.SetAddr2 (mpdu->GetHeader ().GetAddr2 ());
+  hdr.SetAddr3 (mpdu->GetHeader ().GetAddr3 ());
+  hdr.SetDsNotTo ();
+  hdr.SetDsNotFrom ();
+  hdr.SetNoRetry ();
+  hdr.SetNoMoreFragments ();
+
+  ScheduleBar (Create<const WifiMacQueueItem> (bar, hdr));
 }
 
-void
-BlockAckManager::ScheduleBlockAckReq (Mac48Address recipient, uint8_t tid)
+CtrlBAckRequestHeader
+BlockAckManager::GetBlockAckReqHeader (Mac48Address recipient, uint8_t tid) const
 {
   NS_LOG_FUNCTION (this << recipient << +tid);
-  AgreementsI it = m_agreements.find (std::make_pair (recipient, tid));
+  AgreementsCI it = m_agreements.find (std::make_pair (recipient, tid));
   NS_ASSERT (it != m_agreements.end ());
 
-  OriginatorBlockAckAgreement &agreement = (*it).second.first;
-
   CtrlBAckRequestHeader reqHdr;
   reqHdr.SetType (m_blockAckType);
-  reqHdr.SetTidInfo (agreement.GetTid ());
-  reqHdr.SetStartingSequence (agreement.GetStartingSequence ());
+  reqHdr.SetTidInfo (tid);
+  reqHdr.SetStartingSequence ((*it).second.first.GetStartingSequence ());
+  return reqHdr;
+}
 
-  Ptr<Packet> bar = Create<Packet> ();
-  bar->AddHeader (reqHdr);
-  Bar request (bar, recipient, tid, it->second.first.IsImmediateBlockAck ());
+void
+BlockAckManager::ScheduleBar (Ptr<const WifiMacQueueItem> bar, bool skipIfNoDataQueued)
+{
+  NS_LOG_FUNCTION (this << *bar);
+  NS_ASSERT (bar->GetHeader ().IsBlockAckReq ());
+
+  CtrlBAckRequestHeader reqHdr;
+  bar->GetPacket ()->PeekHeader (reqHdr);
+  uint8_t tid = reqHdr.GetTidInfo ();
+  Bar request (bar, tid, skipIfNoDataQueued);
 
   // if a BAR for the given agreement is present, replace it with the new one
   for (std::list<Bar>::const_iterator i = m_bars.begin (); i != m_bars.end (); i++)
     {
-      if (i->recipient == recipient && i->tid == tid)
+      if (i->bar->GetHeader ().GetAddr1 () == bar->GetHeader ().GetAddr1 () && i->tid == tid)
         {
           i = m_bars.erase (i);
           m_bars.insert (i, request);
           return;
         }
     }
-  m_bars.push_back (request);
+
+  if (bar->GetHeader ().IsRetry ())
+    {
+      m_bars.push_front (request);
+    }
+  else
+    {
+      m_bars.push_back (request);
+    }
 }
 
 void
@@ -670,18 +763,6 @@ BlockAckManager::NotifyAgreementReset (Mac48Address recipient, uint8_t tid)
   it->second.first.SetState (OriginatorBlockAckAgreement::RESET);
 }
 
-void
-BlockAckManager::NotifyMpduTransmission (Mac48Address recipient, uint8_t tid, uint16_t nextSeqNumber, WifiMacHeader::QosAckPolicy policy)
-{
-  NS_LOG_FUNCTION (this << recipient << +tid << nextSeqNumber);
-  AgreementsI it = m_agreements.find (std::make_pair (recipient, tid));
-  NS_ASSERT (it != m_agreements.end ());
-  if (policy == WifiMacHeader::BLOCK_ACK)
-    {
-      ScheduleBlockAckReq (recipient, tid);
-    }
-}
-
 void
 BlockAckManager::SetQueue (const Ptr<WifiMacQueue> queue)
 {
@@ -707,33 +788,26 @@ BlockAckManager::SwitchToBlockAckIfNeeded (Mac48Address recipient, uint8_t tid,
   return false;
 }
 
-bool BlockAckManager::NeedBarRetransmission (uint8_t tid, uint16_t seqNumber, Mac48Address recipient)
+bool BlockAckManager::NeedBarRetransmission (uint8_t tid, Mac48Address recipient)
 {
-  //The standard says the BAR gets discarded when all MSDUs lifetime expires
-  AgreementsI it = m_agreements.find (std::make_pair (recipient, tid));
-  NS_ASSERT (it != m_agreements.end ());
-  if (QosUtilsIsOldPacket (it->second.first.GetStartingSequence (), seqNumber))
+  if (ExistsAgreementInState (recipient, tid, OriginatorBlockAckAgreement::ESTABLISHED))
     {
-      return false;
-    }
-  else if (it->second.first.GetTimeout () > 0 && it->second.first.m_inactivityEvent.IsExpired ())
-    {
-      /*
-       * According to "11.5.4 Error recovery upon a peer failure",
-       * DELBA should be issued after inactivity timeout,
-       * so block ack request should not be retransmitted anymore.
-       *
-       * Otherwise we risk retransmitting BAR forever if condition
-       * above is never met and the STA is not available.
-       *
-       * See https://www.nsnam.org/bugzilla/show_bug.cgi?id=2928 for details.
-       */
-      return false;
-    }
-  else
-    {
-      return true;
+      AgreementsI it = m_agreements.find (std::make_pair (recipient, tid));
+      NS_ASSERT (it != m_agreements.end ());
+
+      // A BAR needs to be retransmitted if there is at least a non-expired outstanding MPDU
+      for (auto& mpdu : it->second.second)
+        {
+          if (mpdu->GetTimeStamp () + m_queue->GetMaxDelay () > Simulator::Now ())
+            {
+              return true;
+            }
+        }
     }
+
+  // If the inactivity timer has expired, QosTxop::SendDelbaFrame has been called and
+  // has destroyed the agreement, hence we get here and correctly return false
+  return false;
 }
 
 void
@@ -749,7 +823,6 @@ BlockAckManager::RemoveFromRetryQueue (Mac48Address address, uint8_t tid, uint16
 
   AgreementsI agreementIt = m_agreements.find (std::make_pair (address, tid));
   NS_ASSERT (agreementIt != m_agreements.end ());
-  uint16_t startingSeq = agreementIt->second.first.GetStartingSequence ();
 
   /* remove retry packet iterators if they are present in retry queue */
   WifiMacQueue::ConstIterator it = m_retryPackets->PeekByTidAndAddress (tid, address);
@@ -758,10 +831,8 @@ BlockAckManager::RemoveFromRetryQueue (Mac48Address address, uint8_t tid, uint16
     {
       uint16_t itSeq = (*it)->GetHeader ().GetSequenceNumber ();
 
-      if ((itSeq - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE
-           >= (startSeq - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE
-          && (itSeq - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE
-              <= (endSeq - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE)
+      if (agreementIt->second.first.GetDistance (itSeq) >= agreementIt->second.first.GetDistance (startSeq)
+          && agreementIt->second.first.GetDistance (itSeq) <= agreementIt->second.first.GetDistance (endSeq))
         {
           NS_LOG_DEBUG ("Removing frame with seqnum = " << itSeq);
           it = m_retryPackets->Remove (it);
@@ -775,7 +846,7 @@ BlockAckManager::RemoveFromRetryQueue (Mac48Address address, uint8_t tid, uint16
 }
 
 void
-BlockAckManager::SetStartingSequence (Mac48Address recipient, uint8_t tid, uint16_t startingSeq)
+BlockAckManager::RemoveOldPackets (Mac48Address recipient, uint8_t tid, uint16_t startingSeq)
 {
   NS_LOG_FUNCTION (this << recipient << +tid << startingSeq);
 
@@ -783,7 +854,7 @@ BlockAckManager::SetStartingSequence (Mac48Address recipient, uint8_t tid, uint1
   NS_ASSERT (agreementIt != m_agreements.end ());
   uint16_t currStartingSeq = agreementIt->second.first.GetStartingSequence ();
 
-  NS_ABORT_MSG_IF ((startingSeq - currStartingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE >= SEQNO_SPACE_HALF_SIZE,
+  NS_ABORT_MSG_IF (agreementIt->second.first.GetDistance (startingSeq) >= SEQNO_SPACE_HALF_SIZE,
                    "The new starting sequence number is an old sequence number");
 
   if (startingSeq == currStartingSeq)
@@ -801,8 +872,7 @@ BlockAckManager::SetStartingSequence (Mac48Address recipient, uint8_t tid, uint1
     {
       uint16_t itSeq = (*it)->GetHeader ().GetSequenceNumber ();
 
-      if ((itSeq - currStartingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE
-           <= (lastRemovedSeq - currStartingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE)
+      if (agreementIt->second.first.GetDistance (itSeq) <= agreementIt->second.first.GetDistance (lastRemovedSeq))
         {
           NS_LOG_DEBUG ("Removing frame with seqnum = " << itSeq);
           it = agreementIt->second.second.erase (it);
@@ -812,9 +882,6 @@ BlockAckManager::SetStartingSequence (Mac48Address recipient, uint8_t tid, uint1
           it++;
         }
     }
-
-  // update the starting sequence number
-  agreementIt->second.first.SetStartingSequence (startingSeq);
 }
 
 void
@@ -869,8 +936,7 @@ BlockAckManager::InsertInRetryQueue (Ptr<WifiMacQueueItem> mpdu)
   AgreementsI agreementIt = m_agreements.find (std::make_pair (recipient, tid));
   NS_ASSERT (agreementIt != m_agreements.end ());
 
-  uint16_t startingSeq = agreementIt->second.first.GetStartingSequence ();
-  uint16_t mpduDist = (mpdu->GetHeader ().GetSequenceNumber () - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE;
+  uint16_t mpduDist = agreementIt->second.first.GetDistance (mpdu->GetHeader ().GetSequenceNumber ());
 
   if (mpduDist >= SEQNO_SPACE_HALF_SIZE)
     {
@@ -888,7 +954,7 @@ BlockAckManager::InsertInRetryQueue (Ptr<WifiMacQueueItem> mpdu)
           return;
         }
 
-      uint16_t dist = ((*it)->GetHeader ().GetSequenceNumber () - startingSeq + SEQNO_SPACE_SIZE) % SEQNO_SPACE_SIZE;
+      uint16_t dist = agreementIt->second.first.GetDistance ((*it)->GetHeader ().GetSequenceNumber ());
 
       if (mpduDist < dist ||
           (mpduDist == dist && mpdu->GetHeader ().GetFragmentNumber () < (*it)->GetHeader ().GetFragmentNumber ()))
@@ -898,6 +964,7 @@ BlockAckManager::InsertInRetryQueue (Ptr<WifiMacQueueItem> mpdu)
 
       it = m_retryPackets->PeekByTidAndAddress (tid, recipient, ++it);
     }
+  mpdu->GetHeader ().SetRetry ();
   m_retryPackets->Insert (it, mpdu);
 }
 
