@@ -55,21 +55,21 @@ public:
   virtual ~ChannelAccessManager ();
 
   /**
-   * Set up listener for Phy events.
+   * Set up listener for PHY events.
    *
-   * \param phy
+   * \param phy the WifiPhy to listen to
    */
   void SetupPhyListener (Ptr<WifiPhy> phy);
   /**
-   * Remove current registered listener for Phy events.
+   * Remove current registered listener for PHY events.
    *
-   * \param phy
+   * \param phy the WifiPhy to listen to
    */
   void RemovePhyListener (Ptr<WifiPhy> phy);
   /**
    * Set up listener for MacLow events.
    *
-   * \param low
+   * \param low the MacLow to listen to
    */
   void SetupLow (Ptr<MacLow> low);
 
@@ -101,7 +101,7 @@ public:
   Time GetEifsNoDifs (void) const;
 
   /**
-   * \param dcf a new Txop.
+   * \param txop a new Txop.
    *
    * The ChannelAccessManager does not take ownership of this pointer so, the callee
    * must make sure that the Txop pointer will stay valid as long
@@ -110,10 +110,19 @@ public:
    * has the highest priority, the second Txop added, has the second
    * highest priority, etc.
    */
-  void Add (Ptr<Txop> dcf);
+  void Add (Ptr<Txop> txop);
 
   /**
-   * \param state a Txop
+   * Determine if a new backoff needs to be generated when a packet is queued
+   * for transmission.
+   *
+   * \param txop the Txop requesting to generate a backoff
+   * \return true if backoff needs to be generated, false otherwise
+   */
+  bool NeedBackoffUponAccess (Ptr<Txop> txop);
+
+  /**
+   * \param txop a Txop
    * \param isCfPeriod flag whether it is called during the CF period
    *
    * Notify the ChannelAccessManager that a specific Txop needs access to the
@@ -121,89 +130,89 @@ public:
    * timer and, invoking Txop::DoNotifyAccessGranted when the access
    * is granted if it ever gets granted.
    */
-  void RequestAccess (Ptr<Txop> state, bool isCfPeriod = false);
+  void RequestAccess (Ptr<Txop> txop, bool isCfPeriod = false);
 
   /**
    * \param duration expected duration of reception
    *
-   * Notify the DCF that a packet reception started
+   * Notify the Txop that a packet reception started
    * for the expected duration.
    */
   void NotifyRxStartNow (Time duration);
   /**
-   * Notify the DCF that a packet reception was just
+   * Notify the Txop that a packet reception was just
    * completed successfully.
    */
   void NotifyRxEndOkNow (void);
   /**
-   * Notify the DCF that a packet reception was just
+   * Notify the Txop that a packet reception was just
    * completed unsuccessfully.
    */
   void NotifyRxEndErrorNow (void);
   /**
    * \param duration expected duration of transmission
    *
-   * Notify the DCF that a packet transmission was
+   * Notify the Txop that a packet transmission was
    * just started and is expected to last for the specified
    * duration.
    */
   void NotifyTxStartNow (Time duration);
   /**
-   * \param duration expected duration of cca busy period
+   * \param duration expected duration of CCA busy period
    *
-   * Notify the DCF that a CCA busy period has just started.
+   * Notify the Txop that a CCA busy period has just started.
    */
   void NotifyMaybeCcaBusyStartNow (Time duration);
   /**
    * \param duration expected duration of channel switching period
    *
-   * Notify the DCF that a channel switching period has just started.
+   * Notify the Txop that a channel switching period has just started.
    * During switching state, new packets can be enqueued in Txop/QosTxop
    * but they won't access to the medium until the end of the channel switching.
    */
   void NotifySwitchingStartNow (Time duration);
   /**
-   * Notify the DCF that the device has been put in sleep mode.
+   * Notify the Txop that the device has been put in sleep mode.
    */
   void NotifySleepNow (void);
   /**
-   * Notify the DCF that the device has been put in off mode.
+   * Notify the Txop that the device has been put in off mode.
    */
   void NotifyOffNow (void);
   /**
-   * Notify the DCF that the device has been resumed from sleep mode.
+   * Notify the Txop that the device has been resumed from sleep mode.
    */
   void NotifyWakeupNow (void);
   /**
-   * Notify the DCF that the device has been resumed from off mode.
+   * Notify the Txop that the device has been resumed from off mode.
    */
   void NotifyOnNow (void);
   /**
    * \param duration the value of the received NAV.
    *
-   * Called at end of rx
+   * Called at end of RX
    */
   void NotifyNavResetNow (Time duration);
   /**
    * \param duration the value of the received NAV.
    *
-   * Called at end of rx
+   * Called at end of RX
    */
   void NotifyNavStartNow (Time duration);
   /**
-   * Notify that ACK timer has started for the given duration.
+   * Notify that ack timer has started for the given duration.
    *
-   * \param duration
+   * \param duration the duration of the timer
    */
   void NotifyAckTimeoutStartNow (Time duration);
   /**
-   * Notify that ACK timer has reset.
+   * Notify that ack timer has reset.
    */
   void NotifyAckTimeoutResetNow (void);
   /**
    * Notify that CTS timer has started for the given duration.
    *
-   * \param duration
+   * \param duration the duration of the timer
    */
   void NotifyCtsTimeoutStartNow (Time duration);
   /**
@@ -252,20 +261,20 @@ private:
    * Return the time when the backoff procedure
    * started for the given Txop.
    *
-   * \param state
+   * \param txop the Txop
    *
    * \return the time when the backoff procedure started
    */
-  Time GetBackoffStartFor (Ptr<Txop> state);
+  Time GetBackoffStartFor (Ptr<Txop> txop);
   /**
    * Return the time when the backoff procedure
    * ended (or will ended) for the given Txop.
    *
-   * \param state
+   * \param txop the Txop
    *
    * \return the time when the backoff procedure ended (or will ended)
    */
-  Time GetBackoffEndFor (Ptr<Txop> state);
+  Time GetBackoffEndFor (Ptr<Txop> txop);
 
   void DoRestartAccessTimeoutIfNeeded (void);
 
@@ -275,36 +284,29 @@ private:
    */
   void AccessTimeout (void);
   /**
-   * Grant access to DCF
+   * Grant access to Txop using DCF/EDCF contention rules
    */
   void DoGrantDcfAccess (void);
   /**
-   * Check if the device is between frames (in DIFS or AIFS interval)
+   * Grant access to Txop using PCF preemption
    *
-   * \param state the state to check
-   * \return true if the device is within AIFS,
-   *         false otherwise
+   * \param txop the Txop
    */
-  bool IsWithinAifs (Ptr<Txop> state) const;
-  /**
-   * Grant access to PCF
-   */
-  void DoGrantPcfAccess (Ptr<Txop> state);
+  void DoGrantPcfAccess (Ptr<Txop> txop);
 
   /**
    * typedef for a vector of Txops
    */
-  typedef std::vector<Ptr<Txop> > States;
+  typedef std::vector<Ptr<Txop>> Txops;
 
-  States m_states;              //!< the DCF states
-  Time m_lastAckTimeoutEnd;     //!< the last ACK timeout end time
+  Txops m_txops;                //!< the vector of managed Txops
+  Time m_lastAckTimeoutEnd;     //!< the last Ack timeout end time
   Time m_lastCtsTimeoutEnd;     //!< the last CTS timeout end time
   Time m_lastNavStart;          //!< the last NAV start time
   Time m_lastNavDuration;       //!< the last NAV duration time
   Time m_lastRxStart;           //!< the last receive start time
   Time m_lastRxDuration;        //!< the last receive duration time
   bool m_lastRxReceivedOk;      //!< the last receive OK
-  Time m_lastRxEnd;             //!< the last receive end time
   Time m_lastTxStart;           //!< the last transmit start time
   Time m_lastTxDuration;        //!< the last transmit duration time
   Time m_lastBusyStart;         //!< the last busy start time
@@ -317,8 +319,8 @@ private:
   EventId m_accessTimeout;      //!< the access timeout ID
   Time m_slot;                  //!< the slot time
   Time m_sifs;                  //!< the SIFS time
-  PhyListener* m_phyListener;   //!< the phy listener
-  Ptr<WifiPhy> m_phy;           //!< Ptr to the PHY
+  PhyListener* m_phyListener;   //!< the PHY listener
+  Ptr<WifiPhy> m_phy;           //!< pointer to the PHY
 };
 
 } //namespace ns3
