@@ -34,38 +34,25 @@ class HeCapabilities : public WifiInformationElement
 {
 public:
   HeCapabilities ();
+
+  // Implementations of pure virtual methods of WifiInformationElement
+  WifiInformationElementId ElementId () const;
+  WifiInformationElementId ElementIdExt () const;
+  uint8_t GetInformationFieldSize () const;
+  void SerializeInformationField (Buffer::Iterator start) const;
+  uint8_t DeserializeInformationField (Buffer::Iterator start, uint8_t length);
+  /* This information element is a bit special in that it is only
+     included if the STA is an HE STA. To support this we
+     override the Serialize and GetSerializedSize methods of
+     WifiInformationElement. */
+  Buffer::Iterator Serialize (Buffer::Iterator start) const;
+  uint16_t GetSerializedSize () const;
+
   /**
    * Set HE supported
-   * \param hesupported the HE supported indicator
+   * \param heSupported the HE supported indicator
    */
-  void SetHeSupported (uint8_t hesupported);
-  /**
-   * Get the wifi information element ID
-   * \returns the wifi information element ID
-   */
-  WifiInformationElementId ElementId () const;
-  /**
-   * Get the wifi information element ID extension
-   * \returns the wifi information element ID extension
-   */
-  WifiInformationElementId ElementIdExt () const;
-  /**
-   * Get information field size
-   * \returns the information field size
-   */
-  uint8_t GetInformationFieldSize () const;
-  /**
-   * Serialize information field
-   * \param start the information field iterator
-   */
-  void SerializeInformationField (Buffer::Iterator start) const;
-  /**
-   * Deserialize information field
-   * \param start the information field iterator
-   * \param length the length
-   * \returns the information field size
-   */
-  uint8_t DeserializeInformationField (Buffer::Iterator start, uint8_t length);
+  void SetHeSupported (uint8_t heSupported);
 
   /**
    * Set the HE MAC Capabilities Info field in the HE Capabilities information element.
@@ -161,9 +148,9 @@ public:
   /**
    * Set the maximum AMPDU length.
    *
-   * \param maxampdulength 2^(20 + x) - 1, x in the range 0 to 3
+   * \param maxAmpduLength 2^(20 + x) - 1, x in the range 0 to 3
    */
-  void SetMaxAmpduLength (uint32_t maxampdulength);
+  void SetMaxAmpduLength (uint32_t maxAmpduLength);
 
   // MCS and NSS field information
   /**
@@ -201,102 +188,87 @@ public:
    */
   uint32_t GetMaxAmpduLength (void) const;
 
-  /*
-   * This information element is a bit special in that it is only
-   * included if the STA is an HE STA. To support this we
-   * override the Serialize and GetSerializedSize methods of
-   * WifiInformationElement.
-   */
-
-  /**
-   * Serialize function.
-   *
-   * \param start the information element iterator
-   * \returns true if MCS transmit supported
-   */
-  Buffer::Iterator Serialize (Buffer::Iterator start) const;
-  /**
-   * Set serialize size function.
-   *
-   * \returns the serialized size
-   */
-  uint16_t GetSerializedSize () const;
-
 
 private:
   //MAC Capabilities Info fields
-  uint8_t m_plusHtcHeSupport; //!< HTC HE support
-  uint8_t m_twtRequesterSupport; //!< TWT requester support
-  uint8_t m_twtResponderSupport; //!< TWT responder support
-  uint8_t m_fragmentationSupport; //!< fragmentation support
-  uint8_t m_maximumNumberOfFragmentedMsdus; //!< maximum number of fragmentation MSDUs
-  uint8_t m_minimumFragmentSize; //!< minimum fragment size
-  uint8_t m_triggerFrameMacPaddingDuration; //!< trigger frame MAC padding duration
-  uint8_t m_multiTidAggregationSupport; //!< multi TID aggregation support
-  uint8_t m_heLinkAdaptation; //!< HE link adaptation
-  uint8_t m_allAckSupport; //!< ack support
-  uint8_t m_ulMuResponseSchedulingSupport; //!< UL MU response scheduling support
-  uint8_t m_aBsrSupport; //!< BSR support
-  uint8_t m_broadcastTwtSupport; //!< broadcast TXT support
-  uint8_t m_32bitBaBitmapSupport; //!< 32bit BA bitmap support
-  uint8_t m_muCascadeSupport; //!< MU cascade support
-  uint8_t m_ackEnabledMultiTidAggregationSupport; //!< ack enabled multi TID aggregation support
-  uint8_t m_groupAddressedMultiStaBlockAckInDlMuSupport; //!< group addressed multi STA block ack in DL support
-  uint8_t m_omiAcontrolSupport; //!< OMI A control support
-  uint8_t m_ofdmaRaSupport; //!< OFDM RA support
-  uint8_t m_maxAmpduLengthExponent; //!< maximum AMPDU length exponenet
-  uint8_t m_amsduFragmentationSupport; //!< AMSDU fragmentation support
-  uint8_t m_flexibleTwtScheduleSupport; //!< flexible TWT schedule support
-  uint8_t m_rxControlFrameToMultiBss; //!< receive control frame to multi bias
-  uint8_t m_bsrpAmpduAggregation; //!< BSRP AMPDU aggregation
-  uint8_t m_qtpSupport; //!< QTP support
-  uint8_t m_aBqrSupport; //!< ABQR support
+  uint8_t m_plusHtcHeSupport;                            //!< HTC HE support
+  uint8_t m_twtRequesterSupport;                         //!< TWT requester support
+  uint8_t m_twtResponderSupport;                         //!< TWT responder support
+  uint8_t m_fragmentationSupport;                        //!< fragmentation support
+  uint8_t m_maximumNumberOfFragmentedMsdus;              //!< maximum number of fragmentation MSDUs
+  uint8_t m_minimumFragmentSize;                         //!< minimum fragment size
+  uint8_t m_triggerFrameMacPaddingDuration;              //!< trigger frame MAC padding duration
+  uint8_t m_multiTidAggregationSupport;                  //!< multi-TID aggregation support
+  uint8_t m_heLinkAdaptation;                            //!< HE link adaptation
+  uint8_t m_allAckSupport;                               //!< all Ack support
+  uint8_t m_ulMuResponseSchedulingSupport;               //!< UL MU response scheduling support
+  uint8_t m_aBsrSupport;                                 //!< BSR support
+  uint8_t m_broadcastTwtSupport;                         //!< broadcast TXT support
+  uint8_t m_32bitBaBitmapSupport;                        //!< 32-bit BA bitmap support
+  uint8_t m_muCascadeSupport;                            //!< MU cascade support
+  uint8_t m_ackEnabledMultiTidAggregationSupport;        //!< ack enabled multi-TID aggregation support
+  uint8_t m_groupAddressedMultiStaBlockAckInDlMuSupport; //!< group addressed multi-STA BlockAck in DL support
+  uint8_t m_omControlSupport;                            //!< operation mode control support
+  uint8_t m_ofdmaRaSupport;                              //!< OFDMA RA support
+  uint8_t m_maxAmpduLengthExponent;                      //!< maximum A-MPDU length exponent
+  uint8_t m_amsduFragmentationSupport;                   //!< A-MSDU fragmentation support
+  uint8_t m_flexibleTwtScheduleSupport;                  //!< flexible TWT schedule support
+  uint8_t m_rxControlFrameToMultiBss;                    //!< receive control frame to multi-BSS
+  uint8_t m_bsrpAmpduAggregation;                        //!< BSRP A-MPDU aggregation
+  uint8_t m_qtpSupport;                                  //!< QTP support
+  uint8_t m_aBqrSupport;                                 //!< ABQR support
 
   //PHY Capabilities Info fields
-  uint8_t m_dualBandSupport; //!< dual band support
-  uint8_t m_channelWidthSet; //!< channel width set
-  uint8_t m_preamblePuncturingRx; //!< preamble puncturing receive
-  uint8_t m_deviceClass; //!< device class
-  uint8_t m_ldpcCodingInPayload; //!< LDPC coding in payload
-  uint8_t m_heLtfAndGiForHePpdus; //!< HE LTF and GI for HE PDUs
-  uint8_t m_heLtfAndGiForNdp; //!< HE LTF and GI for NDP
-  uint8_t m_stbcTxAndRx; //!< STBC transmit and receive
-  uint8_t m_doppler; //!< doppler
-  uint8_t m_ulMu; //!< UL MU
-  uint8_t m_dcmEncodingTx; //!< DCM encoding transmit
-  uint8_t m_dcmEncodingRx; //!< DCM encoding receive
-  uint8_t m_ulHeMuPpduPayloadSupport; //!< UL HE MU PDPU payload support
-  uint8_t m_suBeamformer; //!< SU beam former
-  uint8_t m_suBeamformee; //!< SU beam formee
-  uint8_t m_muBeamformer; //!< MU beam former
+  uint8_t m_dualBandSupport;                         //!< dual band support
+  uint8_t m_channelWidthSet;                         //!< channel width set
+  uint8_t m_preamblePuncturingRx;                    //!< preamble puncturing receive
+  uint8_t m_deviceClass;                             //!< device class
+  uint8_t m_ldpcCodingInPayload;                     //!< LDPC coding in payload
+  uint8_t m_heLtfAndGiForHePpdus;                    //!< HE-LTF and GI for HE-PPDUs
+  uint8_t m_heLtfAndGiForNdp;                        //!< HE-LTF and GI for NDP
+  uint8_t m_stbcTxAndRx;                             //!< STBC transmit and receive
+  uint8_t m_doppler;                                 //!< Doppler
+  uint8_t m_ulMu;                                    //!< UL MU
+  uint8_t m_dcmEncodingTx;                           //!< DCM encoding transmit
+  uint8_t m_dcmEncodingRx;                           //!< DCM encoding receive
+  uint8_t m_ulHeMuPpduPayloadSupport;                //!< UL HE-MU-PDPU payload support
+  uint8_t m_suBeamformer;                            //!< SU beamformer
+  uint8_t m_suBeamformee;                            //!< SU beamformee
+  uint8_t m_muBeamformer;                            //!< MU beamformer
   uint8_t m_beamformeeStsForSmallerOrEqualThan80Mhz; //!< beam formee STS for < 80 MHz
-  uint8_t m_nstsTotalForSmallerOrEqualThan80Mhz; //!< STS total for < 80 MHz
-  uint8_t m_beamformeeStsForLargerThan80Mhz; //!< beam formee STS for > 80MHz
-  uint8_t m_nstsTotalForLargerThan80Mhz; //!< STS total for > 80 MHz
-  uint8_t m_numberOfSoundingDimensionsForSmallerOrEqualThan80Mhz; //!< # of sounding diemnsions for < 80 MHz
-  uint8_t m_numberOfSoundingDimensionsForLargerThan80Mhz; //!< # of sounding dimensions for > 80 MHz
-  uint8_t m_ngEqual16ForSuFeedbackSupport; //!< equal 16 for SU feedback
-  uint8_t m_ngEqual16ForMuFeedbackSupport; //!< equal 16 for MU feedback
-  uint8_t m_codebookSize42ForSuSupport; //!< codebook size 42 for SU
-  uint8_t m_codebookSize75ForSuSupport; //!< codebook size 75 for SU
-  uint8_t m_beamformingFeedbackWithTriggerFrame; //!< beam forming feedback with trigger frame
-  uint8_t m_heErSuPpduPayload; //!< HE ER SU PPDU payload
-  uint8_t m_dlMuMimoOnPartialBandwidth; //!< DL MU MIMO on partial bandwidth
-  uint8_t m_ppeThresholdPresent; //!< PPE threshold present
-  uint8_t m_srpBasedSrSupport; //!< SRP based SR support
-  uint8_t m_powerBoostFactorAlphaSupport; //!< power boost factor alpha support
-  uint8_t m_4TimesHeLtfAnd800NsGiSupportForHePpdus; //!< 4 times HE LFT and 800 HS GI support for HE PPDUs
+  uint8_t m_nstsTotalForSmallerOrEqualThan80Mhz;     //!< STS total for < 80 MHz
+  uint8_t m_beamformeeStsForLargerThan80Mhz;         //!< beamformee STS for > 80MHz
+  uint8_t m_nstsTotalForLargerThan80Mhz;             //!< STS total for > 80 MHz
+  uint8_t m_numberOfSoundingDimensionsForSmallerOrEqualThan80Mhz; //!< # of sounding dimensions for < 80 MHz
+  uint8_t m_numberOfSoundingDimensionsForLargerThan80Mhz;         //!< # of sounding dimensions for > 80 MHz
+  uint8_t m_ngEqual16ForSuFeedbackSupport;          //!< equal 16 for SU feedback
+  uint8_t m_ngEqual16ForMuFeedbackSupport;          //!< equal 16 for MU feedback
+  uint8_t m_codebookSize42ForSuSupport;             //!< codebook size 42 for SU
+  uint8_t m_codebookSize75ForSuSupport;             //!< codebook size 75 for SU
+  uint8_t m_beamformingFeedbackWithTriggerFrame;    //!< beamforming feedback with trigger frame
+  uint8_t m_heErSuPpduPayload;                      //!< HE-ER-SU-PPDU payload
+  uint8_t m_dlMuMimoOnPartialBandwidth;             //!< DL MU-MIMO on partial bandwidth
+  uint8_t m_ppeThresholdPresent;                    //!< PPE threshold present
+  uint8_t m_srpBasedSrSupport;                      //!< SRP based SR support
+  uint8_t m_powerBoostFactorAlphaSupport;           //!< power boost factor alpha support
+  uint8_t m_4TimesHeLtfAnd800NsGiSupportForHePpdus; //!< 4 times HE-LFT and 800ns GI support for HE-PPDUs
 
   //MCS and NSS field information
   uint8_t m_highestNssSupportedM1; //!< highest NSS support M1
-  uint8_t m_highestMcsSupported; //!< highest MCS support
-  std::vector<uint8_t> m_txBwMap; //!< transmit BW map
-  std::vector<uint8_t> m_rxBwMap; //!< receive BW map
+  uint8_t m_highestMcsSupported;   //!< highest MCS support
+  std::vector<uint8_t> m_txBwMap;  //!< transmit BW map
+  std::vector<uint8_t> m_rxBwMap;  //!< receive BW map
 
   /// This is used to decide if this element should be added to the frame or not
   uint8_t m_heSupported;
 };
 
+/**
+ * output stream output operator
+ * \param os the output stream
+ * \param HeCapabilities the HE capabilities
+ * \returns the output stream
+ */
 std::ostream &operator << (std::ostream &os, const HeCapabilities &HeCapabilities);
 
 } //namespace ns3
