@@ -18,6 +18,7 @@
  * Author: Mathieu Lacage <mathieu.lacage@sophia.inria.fr>
  */
 
+#include <algorithm>
 #include "ns3/log.h"
 #include "ideal-wifi-manager.h"
 #include "wifi-phy.h"
@@ -32,10 +33,13 @@ namespace ns3 {
  */
 struct IdealWifiRemoteStation : public WifiRemoteStation
 {
-  double m_lastSnrObserved;  //!< SNR of most recently reported packet sent to the remote station
-  double m_lastSnrCached;    //!< SNR most recently used to select a rate
-  uint8_t m_nss;             //!< Number of spatial streams
-  WifiMode m_lastMode;       //!< Mode most recently used to the remote station
+  double m_lastSnrObserved;            //!< SNR of most recently reported packet sent to the remote station
+  uint16_t m_lastChannelWidthObserved; //!< Channel width (in MHz) of most recently reported packet sent to the remote station
+  uint16_t m_lastNssObserved;          //!<  Number of spatial streams of most recently reported packet sent to the remote station
+  double m_lastSnrCached;              //!< SNR most recently used to select a rate
+  uint8_t m_lastNss;                   //!< Number of spatial streams most recently used to the remote station
+  WifiMode m_lastMode;                 //!< Mode most recently used to the remote station
+  uint16_t m_lastChannelWidth;         //!< Channel width (in MHz) most recently used to the remote station
 };
 
 /// To avoid using the cache before a valid value has been cached
@@ -84,7 +88,7 @@ IdealWifiManager::SetupPhy (const Ptr<WifiPhy> phy)
 }
 
 uint16_t
-IdealWifiManager::GetChannelWidthForMode (WifiMode mode) const
+IdealWifiManager::GetChannelWidthForNonHtMode (WifiMode mode) const
 {
   NS_ASSERT (mode.GetModulationClass () != WIFI_MOD_CLASS_HT
              && mode.GetModulationClass () != WIFI_MOD_CLASS_VHT
@@ -104,6 +108,13 @@ void
 IdealWifiManager::DoInitialize ()
 {
   NS_LOG_FUNCTION (this);
+  BuildSnrThresholds ();
+}
+
+void
+IdealWifiManager::BuildSnrThresholds (void)
+{
+  m_thresholds.clear ();
   WifiMode mode;
   WifiTxVector txVector;
   uint8_t nss = 1;
@@ -111,14 +122,14 @@ IdealWifiManager::DoInitialize ()
   for (uint8_t i = 0; i < nModes; i++)
     {
       mode = GetPhy ()->GetMode (i);
-      txVector.SetChannelWidth (GetChannelWidthForMode (mode));
+      txVector.SetChannelWidth (GetChannelWidthForNonHtMode (mode));
       txVector.SetNss (nss);
       txVector.SetMode (mode);
-      NS_LOG_DEBUG ("Initialize, adding mode = " << mode.GetUniqueName ());
+      NS_LOG_DEBUG ("Adding mode = " << mode.GetUniqueName ());
       AddSnrThreshold (txVector, GetPhy ()->CalculateSnr (txVector, m_ber));
     }
-  // Add all HT, VHT and HE MCSes
-  if (GetHtSupported () || GetVhtSupported () || GetHeSupported ())
+  // Add all MCSes
+  if (GetHtSupported ())
     {
       nModes = GetPhy ()->GetNMcs ();
       for (uint8_t i = 0; i < nModes; i++)
@@ -133,11 +144,10 @@ IdealWifiManager::DoInitialize ()
                   txVector.SetGuardInterval (guardInterval);
                   //derive NSS from the MCS index
                   nss = (mode.GetMcsValue () / 8) + 1;
-                  NS_LOG_DEBUG ("Initialize, adding mode = " << mode.GetUniqueName () <<
+                  NS_LOG_DEBUG ("Adding mode = " << mode.GetUniqueName () <<
                                 " channel width " << j <<
                                 " nss " << +nss <<
                                 " GI " << guardInterval);
-                  NS_LOG_DEBUG ("In SetupPhy, adding mode = " << mode.GetUniqueName ());
                   txVector.SetNss (nss);
                   txVector.SetMode (mode);
                   AddSnrThreshold (txVector, GetPhy ()->CalculateSnr (txVector, m_ber));
@@ -156,20 +166,19 @@ IdealWifiManager::DoInitialize ()
                   txVector.SetGuardInterval (guardInterval);
                   for (uint8_t k = 1; k <= GetPhy ()->GetMaxSupportedTxSpatialStreams (); k++)
                     {
-                      NS_LOG_DEBUG ("Initialize, adding mode = " << mode.GetUniqueName () <<
-                                    " channel width " << j <<
-                                    " nss " << +k <<
-                                    " GI " << guardInterval);
                       if (mode.IsAllowed (j, k))
                         {
-                          NS_LOG_DEBUG ("In SetupPhy, adding mode = " << mode.GetUniqueName ());
+                          NS_LOG_DEBUG ("Adding mode = " << mode.GetUniqueName () <<
+                                        " channel width " << j <<
+                                        " nss " << +k <<
+                                        " GI " << guardInterval);
                           txVector.SetNss (k);
                           txVector.SetMode (mode);
                           AddSnrThreshold (txVector, GetPhy ()->CalculateSnr (txVector, m_ber));
                         }
                       else
                         {
-                          NS_LOG_DEBUG ("In SetupPhy, mode = " << mode.GetUniqueName () << " disallowed");
+                          NS_LOG_DEBUG ("Mode = " << mode.GetUniqueName () << " disallowed");
                         }
                     }
                 }
@@ -179,34 +188,32 @@ IdealWifiManager::DoInitialize ()
 }
 
 double
-IdealWifiManager::GetSnrThreshold (WifiTxVector txVector) const
+IdealWifiManager::GetSnrThreshold (WifiTxVector txVector)
 {
-  NS_LOG_FUNCTION (this << txVector.GetMode ().GetUniqueName ());
-  for (Thresholds::const_iterator i = m_thresholds.begin (); i != m_thresholds.end (); i++)
+  NS_LOG_FUNCTION (this << txVector);
+  auto it = std::find_if (m_thresholds.begin (), m_thresholds.end (),
+      [&txVector] (const std::pair<double, WifiTxVector>& p) -> bool {
+          return ((txVector.GetMode () == p.second.GetMode ()) && (txVector.GetNss () == p.second.GetNss ()) && (txVector.GetChannelWidth () == p.second.GetChannelWidth ()));
+      }
+  );
+  if (it == m_thresholds.end ())
     {
-      NS_LOG_DEBUG ("Checking " << i->second.GetMode ().GetUniqueName () <<
-                    " nss " << +i->second.GetNss () <<
-                    " GI " << i->second.GetGuardInterval () <<
-                    " width " << i->second.GetChannelWidth ());
-      NS_LOG_DEBUG ("against TxVector " << txVector.GetMode ().GetUniqueName () <<
-                    " nss " << +txVector.GetNss () <<
-                    " GI " << txVector.GetGuardInterval () <<
-                    " width " << txVector.GetChannelWidth ());
-      if (txVector.GetMode () == i->second.GetMode ()
-          && txVector.GetNss () == i->second.GetNss ()
-          && txVector.GetChannelWidth () == i->second.GetChannelWidth ())
-        {
-          return i->first;
-        }
-    }
-  NS_ASSERT (false);
-  return 0.0;
+      //This means capabilities have changed in runtime, hence rebuild SNR thresholds
+      BuildSnrThresholds ();
+      it = std::find_if (m_thresholds.begin (), m_thresholds.end (),
+          [&txVector] (const std::pair<double, WifiTxVector>& p) -> bool {
+              return ((txVector.GetMode () == p.second.GetMode ()) && (txVector.GetNss () == p.second.GetNss ()) && (txVector.GetChannelWidth () == p.second.GetChannelWidth ()));
+          }
+      );
+      NS_ASSERT_MSG (it != m_thresholds.end (), "SNR threshold not found");
+  }
+  return it->first;
 }
 
 void
 IdealWifiManager::AddSnrThreshold (WifiTxVector txVector, double snr)
 {
-  NS_LOG_FUNCTION (this << txVector.GetMode ().GetUniqueName () << snr);
+  NS_LOG_FUNCTION (this << txVector.GetMode ().GetUniqueName () << txVector.GetChannelWidth () << snr);
   m_thresholds.push_back (std::make_pair (snr, txVector));
 }
 
@@ -215,13 +222,23 @@ IdealWifiManager::DoCreateStation (void) const
 {
   NS_LOG_FUNCTION (this);
   IdealWifiRemoteStation *station = new IdealWifiRemoteStation ();
-  station->m_lastSnrObserved = 0.0;
-  station->m_lastSnrCached = CACHE_INITIAL_VALUE;
-  station->m_lastMode = GetDefaultMode ();
-  station->m_nss = 1;
+  Reset (station);
   return station;
 }
 
+void
+IdealWifiManager::Reset (WifiRemoteStation *station) const
+{
+  NS_LOG_FUNCTION (this << station);
+  IdealWifiRemoteStation *st = static_cast<IdealWifiRemoteStation*> (station);
+  st->m_lastSnrObserved = 0.0;
+  st->m_lastChannelWidthObserved = 0;
+  st->m_lastNssObserved = 1;
+  st->m_lastSnrCached = CACHE_INITIAL_VALUE;
+  st->m_lastMode = GetDefaultMode ();
+  st->m_lastChannelWidth = 0;
+  st->m_lastNss = 1;
+}
 
 void
 IdealWifiManager::DoReportRxOk (WifiRemoteStation *station, double rxSnr, WifiMode txMode)
@@ -246,57 +263,65 @@ IdealWifiManager::DoReportRtsOk (WifiRemoteStation *st,
                                  double ctsSnr, WifiMode ctsMode, double rtsSnr)
 {
   NS_LOG_FUNCTION (this << st << ctsSnr << ctsMode.GetUniqueName () << rtsSnr);
-  IdealWifiRemoteStation *station = (IdealWifiRemoteStation *)st;
+  IdealWifiRemoteStation *station = static_cast<IdealWifiRemoteStation*> (st);
   station->m_lastSnrObserved = rtsSnr;
+  station->m_lastChannelWidthObserved = GetPhy ()->GetChannelWidth () >= 40 ? 20 : GetPhy ()->GetChannelWidth ();
+  station->m_lastNssObserved = 1;
 }
 
 void
-IdealWifiManager::DoReportDataOk (WifiRemoteStation *st,
-                                  double ackSnr, WifiMode ackMode, double dataSnr)
+IdealWifiManager::DoReportDataOk (WifiRemoteStation *st, double ackSnr, WifiMode ackMode,
+                                  double dataSnr, uint16_t dataChannelWidth, uint8_t dataNss)
 {
-  NS_LOG_FUNCTION (this << st << ackSnr << ackMode.GetUniqueName () << dataSnr);
-  IdealWifiRemoteStation *station = (IdealWifiRemoteStation *)st;
+  NS_LOG_FUNCTION (this << st << ackSnr << ackMode.GetUniqueName () << dataSnr << dataChannelWidth << +dataNss);
+  IdealWifiRemoteStation *station = static_cast<IdealWifiRemoteStation*> (st);
   if (dataSnr == 0)
     {
       NS_LOG_WARN ("DataSnr reported to be zero; not saving this report.");
       return;
     }
   station->m_lastSnrObserved = dataSnr;
+  station->m_lastChannelWidthObserved = dataChannelWidth;
+  station->m_lastNssObserved = dataNss;
 }
 
 void
-IdealWifiManager::DoReportAmpduTxStatus (WifiRemoteStation *st, uint8_t nSuccessfulMpdus, uint8_t nFailedMpdus, double rxSnr, double dataSnr)
+IdealWifiManager::DoReportAmpduTxStatus (WifiRemoteStation *st, uint8_t nSuccessfulMpdus, uint8_t nFailedMpdus,
+                                         double rxSnr, double dataSnr, uint16_t dataChannelWidth, uint8_t dataNss)
 {
-  NS_LOG_FUNCTION (this << st << +nSuccessfulMpdus << +nFailedMpdus << rxSnr << dataSnr);
-  IdealWifiRemoteStation *station = (IdealWifiRemoteStation *)st;
+  NS_LOG_FUNCTION (this << st << +nSuccessfulMpdus << +nFailedMpdus << rxSnr << dataSnr << dataChannelWidth << +dataNss);
+  IdealWifiRemoteStation *station = static_cast<IdealWifiRemoteStation*> (st);
   if (dataSnr == 0)
     {
       NS_LOG_WARN ("DataSnr reported to be zero; not saving this report.");
       return;
     }
   station->m_lastSnrObserved = dataSnr;
+  station->m_lastChannelWidthObserved = dataChannelWidth;
+  station->m_lastNssObserved = dataNss;
 }
 
-
 void
 IdealWifiManager::DoReportFinalRtsFailed (WifiRemoteStation *station)
 {
   NS_LOG_FUNCTION (this << station);
+  Reset (station);
 }
 
 void
 IdealWifiManager::DoReportFinalDataFailed (WifiRemoteStation *station)
 {
   NS_LOG_FUNCTION (this << station);
+  Reset (station);
 }
 
 WifiTxVector
 IdealWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  IdealWifiRemoteStation *station = (IdealWifiRemoteStation *)st;
+  IdealWifiRemoteStation *station = static_cast<IdealWifiRemoteStation*> (st);
   //We search within the Supported rate set the mode with the
-  //highest data rate for which the snr threshold is smaller than m_lastSnr
+  //highest data rate for which the SNR threshold is smaller than m_lastSnr
   //to ensure correct packet delivery.
   WifiMode maxMode = GetDefaultMode ();
   WifiTxVector txVector;
@@ -306,21 +331,20 @@ IdealWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
   uint16_t guardInterval;
   uint16_t channelWidth = std::min (GetChannelWidth (station), GetPhy ()->GetChannelWidth ());
   txVector.SetChannelWidth (channelWidth);
-  if (station->m_lastSnrCached != CACHE_INITIAL_VALUE && station->m_lastSnrObserved == station->m_lastSnrCached)
+  if ((station->m_lastSnrCached != CACHE_INITIAL_VALUE) && (station->m_lastSnrObserved == station->m_lastSnrCached) && (channelWidth == station->m_lastChannelWidth))
     {
-      // SNR has not changed, so skip the search and use the last
-      // mode selected
+      // SNR has not changed, so skip the search and use the last mode selected
       maxMode = station->m_lastMode;
-      selectedNss = station->m_nss;
+      selectedNss = station->m_lastNss;
       NS_LOG_DEBUG ("Using cached mode = " << maxMode.GetUniqueName () <<
                     " last snr observed " << station->m_lastSnrObserved <<
                     " cached " << station->m_lastSnrCached <<
+                    " channel width " << station->m_lastChannelWidth <<
                     " nss " << +selectedNss);
     }
   else
     {
-      if ((GetHtSupported () || GetVhtSupported () || GetHeSupported ())
-          && (GetHtSupported (st) || GetVhtSupported (st) || GetHeSupported (st)))
+      if (GetHtSupported () && GetHtSupported (st))
         {
           for (uint8_t i = 0; i < GetNMcsSupported (station); i++)
             {
@@ -358,13 +382,14 @@ IdealWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
                                 " threshold " << threshold  << " last snr observed " <<
                                 station->m_lastSnrObserved << " cached " <<
                                 station->m_lastSnrCached);
-                  if (dataRate > bestRate && threshold < station->m_lastSnrObserved)
+                  double snr = GetLastObservedSnr (station, channelWidth, nss);
+                  if (dataRate > bestRate && threshold < snr)
                     {
                       NS_LOG_DEBUG ("Candidate mode = " << mode.GetUniqueName () <<
                                     " data rate " << dataRate <<
                                     " threshold " << threshold  <<
-                                    " last snr observed " <<
-                                    station->m_lastSnrObserved);
+                                    " channel width " << channelWidth <<
+                                    " snr " << snr);
                       bestRate = dataRate;
                       maxMode = mode;
                       selectedNss = nss;
@@ -401,13 +426,13 @@ IdealWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
                                     " threshold " << threshold << " last snr observed " <<
                                     station->m_lastSnrObserved << " cached " <<
                                     station->m_lastSnrCached);
-                      if (dataRate > bestRate && threshold < station->m_lastSnrObserved)
+                      double snr = GetLastObservedSnr (station, channelWidth, nss);
+                      if (dataRate > bestRate && threshold < snr)
                         {
                           NS_LOG_DEBUG ("Candidate mode = " << mode.GetUniqueName () <<
                                         " data rate " << dataRate <<
-                                        " threshold " << threshold  <<
-                                        " last snr observed " <<
-                                        station->m_lastSnrObserved);
+                                        " channel width " << channelWidth <<
+                                        " snr " << snr);
                           bestRate = dataRate;
                           maxMode = mode;
                           selectedNss = nss;
@@ -440,13 +465,14 @@ IdealWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
                                     " threshold " << threshold  << " last snr observed " <<
                                     station->m_lastSnrObserved << " cached " <<
                                     station->m_lastSnrCached);
-                      if (dataRate > bestRate && threshold < station->m_lastSnrObserved)
+                      double snr = GetLastObservedSnr (station, channelWidth, nss);
+                      if (dataRate > bestRate && threshold < snr)
                         {
                           NS_LOG_DEBUG ("Candidate mode = " << mode.GetUniqueName () <<
                                         " data rate " << dataRate <<
                                         " threshold " << threshold  <<
-                                        " last snr observed " <<
-                                        station->m_lastSnrObserved);
+                                        " channel width " << channelWidth <<
+                                        " snr " << snr);
                           bestRate = dataRate;
                           maxMode = mode;
                           selectedNss = nss;
@@ -464,20 +490,21 @@ IdealWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
               mode = GetSupported (station, i);
               txVector.SetMode (mode);
               txVector.SetNss (selectedNss);
-              txVector.SetChannelWidth (GetChannelWidthForMode (mode));
+              uint16_t channelWidth = GetChannelWidthForNonHtMode (mode);
+              txVector.SetChannelWidth (channelWidth);
               double threshold = GetSnrThreshold (txVector);
               uint64_t dataRate = mode.GetDataRate (txVector.GetChannelWidth (), txVector.GetGuardInterval (), txVector.GetNss ());
               NS_LOG_DEBUG ("mode = " << mode.GetUniqueName () <<
                             " threshold " << threshold  <<
                             " last snr observed " <<
                             station->m_lastSnrObserved);
-              if (dataRate > bestRate && threshold < station->m_lastSnrObserved)
+              double snr = GetLastObservedSnr (station, channelWidth, 1);
+              if (dataRate > bestRate && threshold < snr)
                 {
                   NS_LOG_DEBUG ("Candidate mode = " << mode.GetUniqueName () <<
                                 " data rate " << dataRate <<
                                 " threshold " << threshold  <<
-                                " last snr observed " <<
-                                station->m_lastSnrObserved);
+                                " snr " << snr);
                   bestRate = dataRate;
                   maxMode = mode;
                 }
@@ -486,9 +513,10 @@ IdealWifiManager::DoGetDataTxVector (WifiRemoteStation *st)
       NS_LOG_DEBUG ("Updating cached values for station to " <<  maxMode.GetUniqueName () << " snr " << station->m_lastSnrObserved);
       station->m_lastSnrCached = station->m_lastSnrObserved;
       station->m_lastMode = maxMode;
-      station->m_nss = selectedNss;
+      station->m_lastNss = selectedNss;
     }
-  NS_LOG_DEBUG ("Found maxMode: " << maxMode << " channelWidth: " << channelWidth);
+  NS_LOG_DEBUG ("Found maxMode: " << maxMode << " channelWidth: " << channelWidth << " nss: " << +selectedNss);
+  station->m_lastChannelWidth = channelWidth;
   if (maxMode.GetModulationClass () == WIFI_MOD_CLASS_HE)
     {
       guardInterval = std::max (GetGuardInterval (station), GetGuardInterval ());
@@ -513,23 +541,22 @@ WifiTxVector
 IdealWifiManager::DoGetRtsTxVector (WifiRemoteStation *st)
 {
   NS_LOG_FUNCTION (this << st);
-  IdealWifiRemoteStation *station = (IdealWifiRemoteStation *)st;
+  IdealWifiRemoteStation *station = static_cast<IdealWifiRemoteStation*> (st);
   //We search within the Basic rate set the mode with the highest
-  //snr threshold possible which is smaller than m_lastSnr to
+  //SNR threshold possible which is smaller than m_lastSnr to
   //ensure correct packet delivery.
   double maxThreshold = 0.0;
   WifiTxVector txVector;
   WifiMode mode;
   uint8_t nss = 1;
   WifiMode maxMode = GetDefaultMode ();
-  //avoid to use legacy rate adaptation algorithms for IEEE 802.11n/ac/ax
-  //RTS is sent in a legacy frame; RTS with HT/VHT/HE is not yet supported
+  //RTS is sent in a non-HT frame
   for (uint8_t i = 0; i < GetNBasicModes (); i++)
     {
       mode = GetBasicMode (i);
       txVector.SetMode (mode);
       txVector.SetNss (nss);
-      txVector.SetChannelWidth (GetChannelWidthForMode (mode));
+      txVector.SetChannelWidth (GetChannelWidthForNonHtMode (mode));
       double threshold = GetSnrThreshold (txVector);
       if (threshold > maxThreshold && threshold < station->m_lastSnrObserved)
         {
@@ -537,13 +564,28 @@ IdealWifiManager::DoGetRtsTxVector (WifiRemoteStation *st)
           maxMode = mode;
         }
     }
-  return WifiTxVector (maxMode, GetDefaultTxPowerLevel (), GetPreambleForTransmission (maxMode.GetModulationClass (), GetShortPreambleEnabled (), UseGreenfieldForDestination (GetAddress (station))), 800, GetNumberOfAntennas (), nss, 0, GetChannelWidthForMode (maxMode), GetAggregation (station), false);
+  return WifiTxVector (maxMode, GetDefaultTxPowerLevel (), GetPreambleForTransmission (maxMode.GetModulationClass (), GetShortPreambleEnabled (), UseGreenfieldForDestination (GetAddress (station))), 800, GetNumberOfAntennas (), nss, 0, GetChannelWidthForNonHtMode (maxMode), GetAggregation (station), false);
 }
 
-bool
-IdealWifiManager::IsLowLatency (void) const
+double
+IdealWifiManager::GetLastObservedSnr (IdealWifiRemoteStation *station, uint16_t channelWidth, uint8_t nss) const
 {
-  return true;
+  double snr = station->m_lastSnrObserved;
+  if (channelWidth != station->m_lastChannelWidthObserved)
+    {
+      snr /= (static_cast<double> (channelWidth) / station->m_lastChannelWidthObserved);
+    }
+  if (nss != station->m_lastNssObserved)
+    {
+      snr /= (static_cast<double> (nss) / station->m_lastNssObserved);
+    }
+  NS_LOG_DEBUG ("Last observed SNR is " << station->m_lastSnrObserved <<
+                " for channel width " << station->m_lastChannelWidthObserved <<
+                " and nss " << +station->m_lastNssObserved <<
+                "; computed SNR is " << snr <<
+                " for channel width " << channelWidth <<
+                " and nss " << +nss);
+  return snr;
 }
 
 } //namespace ns3
