@@ -48,12 +48,6 @@ MgtProbeRequestHeader::GetSsid (void) const
   return m_ssid;
 }
 
-void
-MgtAssocResponseHeader::SetAssociationId (uint16_t aid)
-{
-  m_aid = aid;
-}
-
 void
 MgtProbeRequestHeader::SetSupportedRates (SupportedRates rates)
 {
@@ -61,9 +55,9 @@ MgtProbeRequestHeader::SetSupportedRates (SupportedRates rates)
 }
 
 void
-MgtProbeRequestHeader::SetExtendedCapabilities (ExtendedCapabilities extendedcapabilities)
+MgtProbeRequestHeader::SetExtendedCapabilities (ExtendedCapabilities extendedCapabilities)
 {
-  m_extendedCapability = extendedcapabilities;
+  m_extendedCapability = extendedCapabilities;
 }
 
 ExtendedCapabilities
@@ -73,9 +67,9 @@ MgtProbeRequestHeader::GetExtendedCapabilities (void) const
 }
 
 void
-MgtProbeRequestHeader::SetHtCapabilities (HtCapabilities htcapabilities)
+MgtProbeRequestHeader::SetHtCapabilities (HtCapabilities htCapabilities)
 {
-  m_htCapability = htcapabilities;
+  m_htCapability = htCapabilities;
 }
 
 HtCapabilities
@@ -85,9 +79,9 @@ MgtProbeRequestHeader::GetHtCapabilities (void) const
 }
 
 void
-MgtProbeRequestHeader::SetVhtCapabilities (VhtCapabilities vhtcapabilities)
+MgtProbeRequestHeader::SetVhtCapabilities (VhtCapabilities vhtCapabilities)
 {
-  m_vhtCapability = vhtcapabilities;
+  m_vhtCapability = vhtCapabilities;
 }
 
 VhtCapabilities
@@ -97,9 +91,9 @@ MgtProbeRequestHeader::GetVhtCapabilities (void) const
 }
 
 void
-MgtProbeRequestHeader::SetHeCapabilities (HeCapabilities hecapabilities)
+MgtProbeRequestHeader::SetHeCapabilities (HeCapabilities heCapabilities)
 {
-  m_heCapability = hecapabilities;
+  m_heCapability = heCapabilities;
 }
 
 HeCapabilities
@@ -235,9 +229,9 @@ MgtProbeResponseHeader::GetCapabilities (void) const
 }
 
 void
-MgtProbeResponseHeader::SetExtendedCapabilities (ExtendedCapabilities extendedcapabilities)
+MgtProbeResponseHeader::SetExtendedCapabilities (ExtendedCapabilities extendedCapabilities)
 {
-  m_extendedCapability = extendedcapabilities;
+  m_extendedCapability = extendedCapabilities;
 }
 
 ExtendedCapabilities
@@ -247,9 +241,9 @@ MgtProbeResponseHeader::GetExtendedCapabilities (void) const
 }
 
 void
-MgtProbeResponseHeader::SetHtCapabilities (HtCapabilities htcapabilities)
+MgtProbeResponseHeader::SetHtCapabilities (HtCapabilities htCapabilities)
 {
-  m_htCapability = htcapabilities;
+  m_htCapability = htCapabilities;
 }
 
 HtCapabilities
@@ -259,9 +253,9 @@ MgtProbeResponseHeader::GetHtCapabilities (void) const
 }
 
 void
-MgtProbeResponseHeader::SetHtOperation (HtOperation htoperation)
+MgtProbeResponseHeader::SetHtOperation (HtOperation htOperation)
 {
-  m_htOperation = htoperation;
+  m_htOperation = htOperation;
 }
 
 HtOperation
@@ -271,9 +265,9 @@ MgtProbeResponseHeader::GetHtOperation (void) const
 }
 
 void
-MgtProbeResponseHeader::SetVhtCapabilities (VhtCapabilities vhtcapabilities)
+MgtProbeResponseHeader::SetVhtCapabilities (VhtCapabilities vhtCapabilities)
 {
-  m_vhtCapability = vhtcapabilities;
+  m_vhtCapability = vhtCapabilities;
 }
 
 VhtCapabilities
@@ -283,9 +277,9 @@ MgtProbeResponseHeader::GetVhtCapabilities (void) const
 }
 
 void
-MgtProbeResponseHeader::SetVhtOperation (VhtOperation vhtoperation)
+MgtProbeResponseHeader::SetVhtOperation (VhtOperation vhtOperation)
 {
-  m_vhtOperation = vhtoperation;
+  m_vhtOperation = vhtOperation;
 }
 
 VhtOperation
@@ -295,9 +289,9 @@ MgtProbeResponseHeader::GetVhtOperation (void) const
 }
 
 void
-MgtProbeResponseHeader::SetHeCapabilities (HeCapabilities hecapabilities)
+MgtProbeResponseHeader::SetHeCapabilities (HeCapabilities heCapabilities)
 {
-  m_heCapability = hecapabilities;
+  m_heCapability = heCapabilities;
 }
 
 HeCapabilities
@@ -307,9 +301,9 @@ MgtProbeResponseHeader::GetHeCapabilities (void) const
 }
 
 void
-MgtProbeResponseHeader::SetHeOperation (HeOperation heoperation)
+MgtProbeResponseHeader::SetHeOperation (HeOperation heOperation)
 {
-  m_heOperation = heoperation;
+  m_heOperation = heOperation;
 }
 
 HeOperation
@@ -319,9 +313,9 @@ MgtProbeResponseHeader::GetHeOperation (void) const
 }
 
 void
-MgtProbeResponseHeader::SetCfParameterSet (CfParameterSet cfparameterset)
+MgtProbeResponseHeader::SetCfParameterSet (CfParameterSet cfParameterSet)
 {
-  m_cfParameterSet = cfparameterset;
+  m_cfParameterSet = cfParameterSet;
 }
 
 CfParameterSet
@@ -373,9 +367,9 @@ MgtProbeResponseHeader::GetErpInformation (void) const
 }
 
 void
-MgtProbeResponseHeader::SetEdcaParameterSet (EdcaParameterSet edcaparameters)
+MgtProbeResponseHeader::SetEdcaParameterSet (EdcaParameterSet edcaParameters)
 {
-  m_edcaParameterSet = edcaparameters;
+  m_edcaParameterSet = edcaParameters;
 }
 
 EdcaParameterSet
@@ -446,12 +440,12 @@ MgtProbeResponseHeader::Serialize (Buffer::Iterator start) const
   //timestamp
   //beacon interval
   //capability information
-  //ssid
+  //SSID
   //supported rates
-  //fh parameter set
-  //ds parameter set
-  //cf parameter set
-  //ibss parameter set
+  //FH parameter set
+  //DS parameter set
+  //CF parameter set
+  //IBSS parameter set
   Buffer::Iterator i = start;
   i.WriteHtolsbU64 (Simulator::Now ().GetMicroSeconds ());
   i.WriteHtolsbU16 (static_cast<uint16_t> (m_beaconInterval / 1024));
@@ -563,9 +557,9 @@ MgtAssocRequestHeader::GetCapabilities (void) const
 }
 
 void
-MgtAssocRequestHeader::SetExtendedCapabilities (ExtendedCapabilities extendedcapabilities)
+MgtAssocRequestHeader::SetExtendedCapabilities (ExtendedCapabilities extendedCapabilities)
 {
-  m_extendedCapability = extendedcapabilities;
+  m_extendedCapability = extendedCapabilities;
 }
 
 ExtendedCapabilities
@@ -575,9 +569,9 @@ MgtAssocRequestHeader::GetExtendedCapabilities (void) const
 }
 
 void
-MgtAssocRequestHeader::SetHtCapabilities (HtCapabilities htcapabilities)
+MgtAssocRequestHeader::SetHtCapabilities (HtCapabilities htCapabilities)
 {
-  m_htCapability = htcapabilities;
+  m_htCapability = htCapabilities;
 }
 
 HtCapabilities
@@ -587,9 +581,9 @@ MgtAssocRequestHeader::GetHtCapabilities (void) const
 }
 
 void
-MgtAssocRequestHeader::SetVhtCapabilities (VhtCapabilities vhtcapabilities)
+MgtAssocRequestHeader::SetVhtCapabilities (VhtCapabilities vhtCapabilities)
 {
-  m_vhtCapability = vhtcapabilities;
+  m_vhtCapability = vhtCapabilities;
 }
 
 VhtCapabilities
@@ -599,9 +593,9 @@ MgtAssocRequestHeader::GetVhtCapabilities (void) const
 }
 
 void
-MgtAssocRequestHeader::SetHeCapabilities (HeCapabilities hecapabilities)
+MgtAssocRequestHeader::SetHeCapabilities (HeCapabilities heCapabilities)
 {
-  m_heCapability = hecapabilities;
+  m_heCapability = heCapabilities;
 }
 
 HeCapabilities
@@ -750,9 +744,9 @@ MgtReassocRequestHeader::GetCapabilities (void) const
 }
 
 void
-MgtReassocRequestHeader::SetExtendedCapabilities (ExtendedCapabilities extendedcapabilities)
+MgtReassocRequestHeader::SetExtendedCapabilities (ExtendedCapabilities extendedCapabilities)
 {
-  m_extendedCapability = extendedcapabilities;
+  m_extendedCapability = extendedCapabilities;
 }
 
 ExtendedCapabilities
@@ -762,9 +756,9 @@ MgtReassocRequestHeader::GetExtendedCapabilities (void) const
 }
 
 void
-MgtReassocRequestHeader::SetHtCapabilities (HtCapabilities htcapabilities)
+MgtReassocRequestHeader::SetHtCapabilities (HtCapabilities htCapabilities)
 {
-  m_htCapability = htcapabilities;
+  m_htCapability = htCapabilities;
 }
 
 HtCapabilities
@@ -774,9 +768,9 @@ MgtReassocRequestHeader::GetHtCapabilities (void) const
 }
 
 void
-MgtReassocRequestHeader::SetVhtCapabilities (VhtCapabilities vhtcapabilities)
+MgtReassocRequestHeader::SetVhtCapabilities (VhtCapabilities vhtCapabilities)
 {
-  m_vhtCapability = vhtcapabilities;
+  m_vhtCapability = vhtCapabilities;
 }
 
 VhtCapabilities
@@ -786,9 +780,9 @@ MgtReassocRequestHeader::GetVhtCapabilities (void) const
 }
 
 void
-MgtReassocRequestHeader::SetHeCapabilities (HeCapabilities hecapabilities)
+MgtReassocRequestHeader::SetHeCapabilities (HeCapabilities heCapabilities)
 {
-  m_heCapability = hecapabilities;
+  m_heCapability = heCapabilities;
 }
 
 HeCapabilities
@@ -953,9 +947,9 @@ MgtAssocResponseHeader::GetCapabilities (void) const
 }
 
 void
-MgtAssocResponseHeader::SetExtendedCapabilities (ExtendedCapabilities extendedcapabilities)
+MgtAssocResponseHeader::SetExtendedCapabilities (ExtendedCapabilities extendedCapabilities)
 {
-  m_extendedCapability = extendedcapabilities;
+  m_extendedCapability = extendedCapabilities;
 }
 
 ExtendedCapabilities
@@ -965,9 +959,9 @@ MgtAssocResponseHeader::GetExtendedCapabilities (void) const
 }
 
 void
-MgtAssocResponseHeader::SetHtCapabilities (HtCapabilities htcapabilities)
+MgtAssocResponseHeader::SetHtCapabilities (HtCapabilities htCapabilities)
 {
-  m_htCapability = htcapabilities;
+  m_htCapability = htCapabilities;
 }
 
 HtCapabilities
@@ -977,9 +971,9 @@ MgtAssocResponseHeader::GetHtCapabilities (void) const
 }
 
 void
-MgtAssocResponseHeader::SetHtOperation (HtOperation htoperation)
+MgtAssocResponseHeader::SetHtOperation (HtOperation htOperation)
 {
-  m_htOperation = htoperation;
+  m_htOperation = htOperation;
 }
 
 HtOperation
@@ -989,9 +983,9 @@ MgtAssocResponseHeader::GetHtOperation (void) const
 }
 
 void
-MgtAssocResponseHeader::SetVhtCapabilities (VhtCapabilities vhtcapabilities)
+MgtAssocResponseHeader::SetVhtCapabilities (VhtCapabilities vhtCapabilities)
 {
-  m_vhtCapability = vhtcapabilities;
+  m_vhtCapability = vhtCapabilities;
 }
 
 VhtCapabilities
@@ -1001,9 +995,9 @@ MgtAssocResponseHeader::GetVhtCapabilities (void) const
 }
 
 void
-MgtAssocResponseHeader::SetVhtOperation (VhtOperation vhtoperation)
+MgtAssocResponseHeader::SetVhtOperation (VhtOperation vhtOperation)
 {
-  m_vhtOperation = vhtoperation;
+  m_vhtOperation = vhtOperation;
 }
 
 VhtOperation
@@ -1013,9 +1007,9 @@ MgtAssocResponseHeader::GetVhtOperation (void) const
 }
 
 void
-MgtAssocResponseHeader::SetHeCapabilities (HeCapabilities hecapabilities)
+MgtAssocResponseHeader::SetHeCapabilities (HeCapabilities heCapabilities)
 {
-  m_heCapability = hecapabilities;
+  m_heCapability = heCapabilities;
 }
 
 HeCapabilities
@@ -1025,9 +1019,9 @@ MgtAssocResponseHeader::GetHeCapabilities (void) const
 }
 
 void
-MgtAssocResponseHeader::SetHeOperation (HeOperation heoperation)
+MgtAssocResponseHeader::SetHeOperation (HeOperation heOperation)
 {
-  m_heOperation = heoperation;
+  m_heOperation = heOperation;
 }
 
 HeOperation
@@ -1036,6 +1030,18 @@ MgtAssocResponseHeader::GetHeOperation (void) const
   return m_heOperation;
 }
 
+void
+MgtAssocResponseHeader::SetAssociationId (uint16_t aid)
+{
+  m_aid = aid;
+}
+
+uint16_t
+MgtAssocResponseHeader::GetAssociationId (void) const
+{
+  return m_aid;
+}
+
 void
 MgtAssocResponseHeader::SetErpInformation (ErpInformation erpInformation)
 {
